#!/bin/bash
#

### BEGIN INIT INFO
# Provides:          zend-server
# Required-Start:    $local_fs $remote_fs $network $syslog
# Required-Stop:     $local_fs $remote_fs $network $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start/stop ZendServer daemons
### END INIT INFO

# For RHEL:

# chkconfig: 345 95 05
# description: Zend CE control script. Used to control Apache, lighttpd and Jave bridge.




JB_EN="false";
if [ -f /etc/zce.rc ];then
    . /etc/zce.rc
else
    echo "/etc/zce.rc doesn't exist!"
    exit 1;
fi
if [ -f $ZCE_PREFIX/bin/shell_functions.rc ];then
    . $ZCE_PREFIX/bin/shell_functions.rc
else
    echo "$ZCE_PREFIX/bin/shell_functions.rc doesn't exist!"
    exit 1;
fi
check_root_privileges

usage()
{
    $ECHO_CMD "Usage: $0 <action>"
    $ECHO_CMD ""
    $ECHO_CMD "	start               Start all $PRODUCT_NAME daemons"
    $ECHO_CMD "	start-apache        Start Apache only"
    $ECHO_CMD "	start-lighttpd      Start lighttpd only"
    $JB_EN &&   $ECHO_CMD  "        start-jb            Start Java bridge only"
    $ECHO_CMD "\n"
    $ECHO_CMD "	stop                Stop all $PRODUCT_NAME daemons"
    $ECHO_CMD "	stop-apache         Stop Apache only"
    $ECHO_CMD "	stop-lighttpd       Stop lighttpd only"
    $JB_EN &&   $ECHO_CMD  "        stop-jb             Stop Java bridge only"
    $ECHO_CMD "\n"
    $ECHO_CMD "	restart             Restart all $PRODUCT_NAME daemons"
    $ECHO_CMD "	restart-apache      Restart Apache only"
    $ECHO_CMD "	graceful-apache     Call Apache with graceful"
    $ECHO_CMD "	restart-lighttpd    Restart lighttpd only"
    $JB_EN &&   $ECHO_CMD  "        restart-jb          Restart Java bridge only"
    $ECHO_CMD "\n"
    $ECHO_CMD "	setup-jb            Setup Java bridge"
    $ECHO_CMD "	version             Print $PRODUCT_NAME version"
    $ECHO_CMD "	status              Get $PRODUCT_NAME status"
}
case $1 in
	"start")
		$ECHO_CMD "Starting $PRODUCT_NAME $PRODUCT_VERSION ..\n"

		$0 start-apache %
		$0 start-lighttpd %
		$JB_EN && $0 start-jb %
		$ECHO_CMD "\n$PRODUCT_NAME started..."
		;;

	"restart")
		$0 restart-apache
		$0 restart-lighttpd
		$0 restart-jb
		;;

	"start-apache")
                if [ -x $ZCE_PREFIX/bin/apachectl ];then
                    $ZCE_PREFIX/bin/apachectl start
                fi
		;;

	"graceful-apache")
                if [ -x $ZCE_PREFIX/bin/apachectl ];then
                    $ZCE_PREFIX/bin/apachectl graceful
                fi
		;;


	"start-lighttpd")
                $ZCE_PREFIX/bin/lighttpdctl.sh start
		;;
		
	"start-jb")
                if [ "$JB_EN" = 'true'  -a -x $ZCE_PREFIX/bin/java_bridge.sh ];then
                    $ZCE_PREFIX/bin/java_bridge.sh start
		fi
		;;

	"stop")
		$ECHO_CMD "Stopping $PRODUCT_NAME $PRODUCT_VERSION ..\n"

		$0 stop-apache %
		sleep 2
		$ZCE_PREFIX/bin/clean_semaphores.sh
	        $0 stop-lighttpd %
		if [ -n "$JB_EN" ];then $0 stop-jb %;fi

		$ECHO_CMD "\n$PRODUCT_NAME stopped."
		;;

	"stop-apache")
            if [ -x $ZCE_PREFIX/bin/apachectl ];then
                $ZCE_PREFIX/bin/apachectl stop
            fi
		;;


	"stop-lighttpd")
                $ZCE_PREFIX/bin/lighttpdctl.sh stop
		;;

	"restart-lighttpd")
                $ZCE_PREFIX/bin/lighttpdctl.sh restart
		;;


	"stop-jb")
                if [ "$JB_EN" = 'true'  -a -x $ZCE_PREFIX/bin/java_bridge.sh ];then
                    $ZCE_PREFIX/bin/java_bridge.sh stop
		fi
		;;

	"restart-jb")
                if [ "$JB_EN" = 'true'  -a -x $ZCE_PREFIX/bin/java_bridge.sh ];then
                    $ZCE_PREFIX/bin/java_bridge.sh restart
		fi
		;;

	"setup-jb")
                if [ -x $ZCE_PREFIX/bin/setup_jb.sh ];then
                    $ZCE_PREFIX/bin/setup_jb.sh
                else
                    echo "Java bridge is not installed, please install the java-bridge-zend-$DIST package."
                fi
		;;

	"restart-apache")
		$0 stop-apache
		sleep 2
		$0 start-apache
		;;

	"restart")
		$0 stop
		sleep 2 
		$0 start
		;;

	"status")
                apache_status $APACHE_PID_FILE
                $ZCE_PREFIX/bin/lighttpdctl.sh status
		if $JB_EN;then 
                    $ZCE_PREFIX/bin/java_bridge.sh status
		fi
		;;


        "version")
                $ECHO_CMD "$PRODUCT_NAME version: $PRODUCT_VERSION"
                ;;

	*)	
                usage
                exit 1
		;;
esac
