<?php

class ConfigurationController extends Zwas_Controller_MainContent {
	
	/**
	 * Get the data and display the Zend Products page
	 */
	public function zendServerComponentsAction() {
		$zendServerComponentsModel = ZwasComponents_Model_Factory::getModel();
		$zendServerComponents = $zendServerComponentsModel->getAvailableComponents();
		$this->view->components = $zendServerComponentsModel->convertToDisplayObjects($zendServerComponents);
		if (empty($this->view->components)) {
			$this->setMessagePane(new MessagePane_Notice(
						Zwas_Translate::_('No Zend Server components were found.  If you weren\'t expecting this behavior, go to the Zend Support Center at: http://www.zend.com/support-center')));
		}
		
	}
	
	/**
	 * Restart the webserver
	 */
	public function webserverRestartAction() {
		if (Context_Api::getUtilAPI()->restartPhp()) {
			Context_Db::getCacheTimestamps()->removeAllTableTimestamps();
		}
		$this->_helper->viewRenderer->setNoRender();
	}
	
    public function indexAction() {
    	$this->forward('Extensions');
    }
    
	/**
	 * Fetch the data and display the extensions page
	 */
	public function extensionsAction() {
		try {
			$extensionsModel = new Extensions_Model();
			$this->view->extensions = $extensionsModel->getDisplayList();
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			$this->view->extensions = array();
		}
	}

	/**
	 * Load an extension which name was passed through GET
	 */
	public function loadExtensionAction() {
		$extensionName = $this->getTrimmedParam('name');
		if (! is_null($extensionName)) {
			try {
				$extensionModel = new Extensions_Model();
				if ($extensionModel->loadExtension($extensionName)) {
					$zwasText = new Zwas_Text(Zwas_Translate::_('The extension \'%s\' will be turned on after the PHP is restarted'), array($extensionName));
					$this->setMessagePane(new MessagePane_Notice($zwasText));
				} else {
					$zwasText = new Zwas_Text(Zwas_Translate::_('The extension \'%s\' was turned on'), array($extensionName));
					$this->setMessagePane(new MessagePane_Success($zwasText));
				}
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
		}
		$this->afterActionForward('Extensions','Configuration');
	}
	 
	/**
	 * Unload an extension which name was passed through GET
	 */
	public function unloadExtensionAction() {
		$extensionName = $this->getTrimmedParam('name');
		if (! is_null($extensionName)) {
			try {
				$extensionModel = new Extensions_Model();
				if ($extensionModel->unloadExtension($extensionName)) {
					$zwasText = new Zwas_Text(Zwas_Translate::_('The extension \'%s\' will be turned off after restarting your PHP'), array($extensionName));
					$this->setMessagePane(new MessagePane_Notice($zwasText));
				} else {
					$zwasText = new Zwas_Text(Zwas_Translate::_('The extension \'%s\' was turned off'), array($extensionName));
					$this->setMessagePane(new MessagePane_Success($zwasText));
				}
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
		}
		$this->afterActionForward('Extensions','Configuration');
	}
	
	/**
	 * Fix a problematic extension configuration, which is actually the same as unloading it
	 * according to the states map
	 */
	public function fixExtensionAction() {
		$extensionName = $this->getTrimmedParam('name');
		if (! is_null($extensionName)) {
			try {
				$extensionModel = new Extensions_Model();
				$extensionModel->unloadExtension($extensionName);
				$zwasText = new Zwas_Text(Zwas_Translate::_('The extension \'%s\' will be "Turned Off" after restarting your PHP'), array($extensionName));
				$this->setMessagePane(new MessagePane_Notice($zwasText));
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
		}
		$this->afterActionForward('Extensions','Configuration');
	}
}
