<?php
require_once ZEND_SERVER_APP_CE_PATH . '/controllers/ZwasComponentController.php';

class DebuggerController extends ZwasComponentController {

	/**
	 * @var ZwasComponents_Debugger_Model
	 */
	private $debuggerModel;
	
	/**
	 * Initialize the controller's debugger model
	 */
	public function init() {
		parent::init();
		$this->debuggerModel = new ZwasComponents_Debugger_Model();
	}
	
	/**
	 * Turn the Zend Server component on
	 */
	public function activateAction() {
		$this->activateComponent($this->debuggerModel);
	}
	
	/**
	 * Turn the Zend Server component off
	 */
	public function deactivateAction() {
		$this->deactivateComponent($this->debuggerModel);
	}
	
	/**
	 * Turn the Zend Server component off by force
	 */
	public function forceDeactivateAction() {
		$this->forceDeactivateComponent($this->debuggerModel);
	}
			
	/** Add actions **/
	public function addAllowHostAction() {
		try {
			$newHost = $this->getTrimmedParam('addHostMaskedIp');
			$newHost = $this->debuggerModel->addAllowedHosts($newHost);
			$this->setMessagePane(new MessagePane_Notice(new Zwas_Text(Zwas_Translate::_('\'%s\' was added to the allowed hosts list, restart PHP to apply this change'), array($newHost))));
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->afterActionForward('Index', 'Debugger');
	}
	
	public function addDenyHostAction() {
		try {
			$newHost = $this->getTrimmedParam('addHostMaskedIp');
			$newHost = $this->debuggerModel->addDenyHosts($newHost);
			$this->setMessagePane(new MessagePane_Notice(new Zwas_Text(Zwas_Translate::_('\'%s\' was added to the denied hosts list, restart PHP to apply this change'), array($newHost))));
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->afterActionForward('Index', 'Debugger');
	}
	
	/** Remove actions **/
	public function removeAllowedHostsAction() {
		try {
			// IIS is automatically decoding the encoded slash we passed after the ip address.
			// so instead of using a slash, we use a dash in the link, and here we reverse it.
			$this->debuggerModel->removeAllowedHosts(array( $this->decodeDashesToSlashes($this->getTrimmedParam('host')) ));
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('Host was removed from the allowed hosts list, restart PHP to apply changes')));
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->afterActionForward('Index', 'Debugger');
	}

	public function removeDenyHostsAction() {
		try {
			// IIS is automatically decoding the encoded slash we passed after the ip address.
			// so instead of using a slash, we use a dash in the link, and here we reverse it.
			$this->debuggerModel->removeDenyHosts(array( $this->decodeDashesToSlashes($this->getTrimmedParam('host')) ));
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('Host was removed from the denied hosts list, restart PHP to apply changes')));
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->afterActionForward('Index', 'Debugger');
	}
	
	public function indexAction() {
		if ((! $this->isSetMessagePane()) && (! $this->debuggerModel->isLoadedInMemory())) {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('Zend Debugger is not loaded')));
		}
		
	 	//Set the add host forms
		$addHostForm	= new ZwasComponents_Debugger_Forms_AddHost('addAllowHost', 'Add-Allow-Host');
		$denyHostForm	= new ZwasComponents_Debugger_Forms_AddHost('addDenyHost', 'Add-Deny-Host');

		$this->view->addAllowHostForm	= $addHostForm;
		$this->view->addDenyHostForm	= $denyHostForm;
		
		
		//Set the host list forms
		$allowHostListForm = new ZwasComponents_Debugger_Forms_HostList('allowedHosts', 'Remove-Allowed-Hosts', MenuItem::generateId('Debugger', 'Index'));
		$allowHostListForm->setList($this->debuggerModel->getAllowedHosts());
		
		$denyHostListForm = new ZwasComponents_Debugger_Forms_HostList('denyHosts', 'Remove-Deny-Hosts', MenuItem::generateId('Debugger', 'Index'));
		$denyHostListForm->setList($this->debuggerModel->getDeniedHosts());
		
		// translations for the ipParts widget
		$this->view->translations			= array('Add'					=> Zwas_Translate::_('Add'),
													'Exact IP address only'	=> Zwas_Translate::_('Exact IP address only'));
		
		$this->view->allowHostsListForm		= $allowHostListForm;
		$this->view->denyHostsListForm		= $denyHostListForm;
		
		// flag - if local host is in denied list
		$this->view->localHostIsDenied		= $this->debuggerModel->isInDenyHosts('127.0.0.1');
	}
	
	/**
	 * finds dashes in an ip address, and replaces them with slashes.
	 * @param string $param
	 * @return string
	 */
	private function decodeDashesToSlashes($param){
		return str_replace('-', '/', $param);
	}
	
}
