<?php

class DirectivesController extends Zwas_Controller_MainContent {
	
	const DIRECTIVES_SEARCH_COOKIE_NAME			= 'zend_server_directives_search';
	const DIRECTIVES_EXTENSIONS_SEARCH_PREFIX	= 'ext:';
	
	/**
	 * @var Directives_Model
	 */
	private $model;
	/**
	 * @var string
	 */
	private $searchString;
	
	public function init() {
		parent::init();
		$this->model = new Directives_Model();
		$this->view->taskbarViewMarker = '';
	}
	
	public function showAction() {
		$this->render('directives');
	}
	
    public function indexAction() {
    	
   		$this->searchString = $this->getCookie();
    	
    	if (empty($this->searchString)) {
    		$this->forward('Popular');
    		return;
    	}
    	
   		$this->view->searchName = $this->searchString;
    	$this->view->directivesList = $this->model->getAvailableDirectivesList($this->searchString);
    	
    	$this->setSaveUrl('Index');
    	$this->render('directives');
    }
    
	public function popularAction() {
		$this->removeCookie();
		$this->view->taskbarViewMarker = 'popular';
		$this->view->directivesList = $this->model->getPopularDirectives();
		$this->setSaveUrl('Popular');
		$this->render('directives');
	}

	public function allAction() {
		$this->removeCookie();
		$this->view->directivesList = $this->model->getAllDirectiveList();
		$this->view->taskbarViewMarker = 'all';
		$this->setSaveUrl('All');
		$this->render('directives');
	}

	/**
	 * This is just a wrapper for the special search case coming from an extension or component as those
	 * pages should not now the "secret" syntax by themselves
	 */
	public function searchExtensionAction() {
		$extension = base64_decode($this->getTrimmedParam('extension'));
		
		if (! empty($extension)) {
			$this->getRequest()->setParam('searchName', self::DIRECTIVES_EXTENSIONS_SEARCH_PREFIX . $extension);
			$this->forward('Search', null, null, $this->getRequest()->getParams());
			return;
		}
		
		$this->view->directivesList = array();
		$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('The extension directives search must get an extension name')));
		$this->setSaveUrl('Search-Extension');
		$this->render('directives');
	}
	
	public function searchAction() {
		// TODO: (kz) maybe remove the searchString attribute and pass it when needed
		$this->searchString = $this->_getParam('searchName');
		
		// No search string
		if (empty($this->searchString)) {
			$this->view->directivesList = array();
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('You must enter text before clicking search')));
		}
		// Search for extension
		elseif (0 === strpos($this->searchString, self::DIRECTIVES_EXTENSIONS_SEARCH_PREFIX)) {
			$this->populateDirectivesListByExtension();
		}
		// Search for string
		else {
			$this->populateDirectivesListBySearchString();
		}
		
		$this->setSaveUrl('Search');
		$this->view->searchName = $this->searchString;
		$this->render('directives');
	}
	
	public function saveAction() {
		$directives = $this->getTrimmedParam('directives');
		if (! empty($directives)) {
			try {
				if ($this->model->saveDirectives($directives)) {
					$this->setMessagePane(
						new MessagePane_Notice(Zwas_Translate::_('Directives were saved, restart your PHP to apply this change')));
				}
			} catch (Zwas_Exception $e) {
				$text = new Zwas_Text(Zwas_Translate::_('Failed to save directives: %s'), array($e->getMessageObject()));
				$this->setMessagePane(new MessagePane_Error($text));
			}
		}

		// return to the set target action
		if ($this->_hasParam('trgtAction')) {
			$this->forward($this->_getParam('trgtAction'));
		} else {
			$this->forward('Index');
		}
	}
	
	private function removeCookie() {
		$this->setCookie(null, 1);
	}
	
	private function setCookie($value, $ttl=0) {
		setcookie(	self::DIRECTIVES_SEARCH_COOKIE_NAME,
					$value,
					$ttl);
	}
	
	private function getCookie() {
		return $this->getRequest()->getCookie(self::DIRECTIVES_SEARCH_COOKIE_NAME);
	}
	
	/**
	 * Populate the directives list for the view and handle anything related to a search by extension case
	 */
	private function populateDirectivesListByExtension() {
		$extension = str_replace(self::DIRECTIVES_EXTENSIONS_SEARCH_PREFIX, '', $this->searchString);
		$directivesList = $this->model->getDirectivesListByExtension($extension);
		if (count($directivesList) == 0) {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('No directives were found for search term')));
		}
		$this->view->directivesList = $directivesList;
	}
	
	/**
	 * Populate the directives list for the view and handle anything related to a search by string case
	 */
	private function populateDirectivesListBySearchString() {
		$directivesList = $this->model->getAvailableDirectivesList($this->searchString);
		if (count($directivesList) == 0) {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('No directives were found for search term')));
		}
		$this->setCookie($this->searchString);
		
		$this->view->directivesList = $directivesList;
	}
	
	/**
	 * Set the value of the directives' form action url
	 * @param string $trgtAction
	 */
	private function setSaveUrl($trgtAction) {
		$this->view->saveUrl = array('controller' => $this->controllerName, 'action' => 'Save');
		$this->view->targetAction = $trgtAction;
	}
	
}
