<?php

class IndexController extends Zwas_Controller_Authenitcated {
	
	public function indexAction() {
		$layout = new Layout();
		$layouts = $layout->getLayoutDefinitions();
		// The default selected tab is the tab of the first layout
		$selectedTab = $layouts[0]->getTab();
		
		$loadController	= $this->getTrimmedParam('loadCtrl', $selectedTab->getController());
		$loadAction		= $this->getTrimmedParam('loadActn', $selectedTab->getAction());
		$loadSidebar	= $this->getTrimmedParam('loadSidebar', MenuItem::generateId($loadController, $loadAction));
		
		$params = $this->getRequest()->getParams();
		$params['controller']	= $loadController;
		$params['action']		= $loadAction;
		
		$this->view->layoutState = new stdClass();
    	$this->view->layoutState->content = $params;
		$this->view->layoutState->sidebarId = $loadSidebar;
		
		$this->view->layouts = $layouts;
		
		$this->markIfToShowWelcomeDialog();
		
		$this->_helper->layout->setLayout('application');
	}
	
	public function layoutMapAction() {
		$layout = new Layout();
    	$this->view->layouts = $layout->getLayoutDefinitions();
	}
	
	public function layoutStateAction() {
		$params = $this->getRequest()->getParams();
		$this->view->forwardUrl = array(
										'module'		=> $params['module'],
										'controller'	=> $params['controller'],
										'action'		=> $params['action'],
										);
	}
	
	public function aboutAction() {
		$system = SystemModel::getZendServerInfo();
		$this->view->version = $system['version'];
		$this->view->gettingStartedLink = 'http://www.zend.com/en/products/server/getting-started-ce?zsp=gettingstartedce';
	}
    
	public function globalMessageAction() {
		try {
			$this->view->globalMessage = GlobalMessage::getMessage();
		} catch (Exception $e) {
			$this->view->globalMessage = new MessagePane_Null();
		}
	}
	
	public function lockContentAction() {
			
	}
	
	/**
	 * A general service action which purpose is to display a message pane after a redirect
	 * @throws Zwas_Exception
	 */
	public function showMessageAction() {
		$messages = $this->_helper->flashMessenger->getMessages();
		if (1 !== count($messages)) {
			throw new Zwas_Exception(
				Zwas_Translate::_('showMessageAction requires a single message passed through FlashMessenger'), 
				Zwas_Exception::ASSERT
			);
		}
		
		$message = $messages[0];
		 
		if (! ($message instanceof MessagePane_Abstract)) {
			throw new Zwas_Exception(
				Zwas_Translate::_('showMessageAction requires the passed message to be a MessagePane_* object'), 
				Zwas_Exception::ASSERT
			);
		}
		
		$this->setMessagePane($message);
	}
	
	public function welcomeAction() {
		
	}
	
	/**
	 * An AJAX action to stop setting the welcome dialog again after login
	 */
	public function doNotDisplayAgainAction() {
	  $this->getHelper('ViewRenderer')->setNeverRender();
		$dontShow = $this->getTrimmedParam('dontShowAgain');
		
		try {
			ApplicationModel::setDisplayWelcome(('1' != $dontShow));
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException('Could not save the new state for the monitor|displayWelcome directive', $e);
		}
	}
	
	/**
	 * Check if the welcome dialog should be displayed and if so,
	 * set the appropriate view attribute
	 */
	private function markIfToShowWelcomeDialog() {
		if (true === ShowWelcome::getValue()) {
			$this->view->showWelcome = 1;
		}
		ShowWelcome::destroy();
	}
}
