<?php
class LogTailController extends Zwas_Controller_MainContent {
	
	/**
	 * @var LogTail_Model
	 */
	private $model;
	
	public function init() {
		parent::init();
		$this->model = new LogTail_Model();
	}
	
    public function indexAction() {
    	$availableLogFiles = $this->model->getAvailableLogFiles();
    	
    	// get data for the first entry to the page, default is the first file in the XML file
    	$fileId 	= $this->getTrimmedParam('logfile', key($availableLogFiles));
    	$numOfLines	= $this->getTrimmedParam('show-lines', LogTail_Model::DEFAULT_NUM_OF_LINES);
    	$filterBy	= $this->_getParam('filter-by');
    	
    	if (! $this->isInputValid()) {
    		$this->setMessagePane(new MessagePane_Notice(
    			new Zwas_Text(	'The number of lines to show must be a value between %s and %s. The setting has been automatically changed to the default of %s lines',
    							array(	LogTail_Model::MIN_NUM_OF_LINES,
    									LogTail_Model::MAX_NUM_OF_LINES,
    									LogTail_Model::DEFAULT_NUM_OF_LINES))));
    							
			$numOfLines = LogTail_Model::DEFAULT_NUM_OF_LINES;
    	}
    	
    	try {
    		$this->view->data		= $this->model->getLastLines($fileId, $numOfLines, $filterBy);
    	} catch (Zwas_Exception $e) {
    		// If reading the log file fails with ERROR user will see the ERROR message pane,
    		// on WARNING show an INFO msg pane
    		if (Zwas_Exception::WARNING == $e->getCode()) {
    			$this->setMessagePane(new MessagePane_Info((string)$e->getMessageObject()));
    		} else {
    			$this->setMessagePane(new MessagePane_Notice($e->getMessageObject()));
    		}
    	}
    	
    	$this->view->numberOfLines			= $numOfLines;
    	$this->view->logfile				= $fileId;
    	$this->view->filterBy				= $filterBy;
    	$this->view->logFiles				= $availableLogFiles;
    	$this->view->logfileRefreshInterval	= LogTail_Model::getRefreshIntervalValue();
    }

    public static function isNumOfLinesValid($numOfLines) {
    	$numOfLinesValidator = new Zend_Validate();
    	$numOfLinesValidator->addValidator(new Zend_Validate_Between(LogTail_Model::MIN_NUM_OF_LINES, LogTail_Model::MAX_NUM_OF_LINES))
    						->addValidator(new Zend_Validate_Int());
    	
    	return $numOfLinesValidator->isValid($numOfLines);
    }
    
    private function isInputValid() {
    	return self::isNumOfLinesValid($this->getTrimmedParam('show-lines', LogTail_Model::DEFAULT_NUM_OF_LINES));
    }
}