<?php

class LoginController extends Zwas_Controller_Action {

	public function indexAction() {
		try {
			if (! ApplicationModel::isRegistrationComplete()) {
				$this->forward('Index', 'Registration');
				return;
			}
			// welcome page (set password and license)
			if (! ApplicationModel::isPasswordSet()) {
				$this->forward('Index', 'Reset-Password');
				return;
			}
			// login page
		} catch (Zwas_Exception $e) {
			$this->disableLogin();
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->_helper->layout->setLayout('login');
	}
	
	public function tryAction() {
		// Added condition to test for failure of login
		// Otherwise, lack of exit in RedirectAndExit allows successfull
		// authentication flow to overflow into "failed to login" block.
		if( !$this->authenticateAndRedirect($this->_getParam('password'))) {
			// failed to login
			$this->setMessagePane(new MessagePane_Error(Zwas_Translate::_('The password you entered is incorrect')));
			$this->forward('Index');
		}
	}
	
	public function leaveAction() {
		Zend_Auth::getInstance()->clearIdentity();
		$this->forward('Index');
	}
	
	public function jsLeaveAction() {
		// make sure the identity is clear in order to avoid a repeating loop
		Zend_Auth::getInstance()->clearIdentity();
		
		LoginForward::init($this->getRequest()->getParams());
		// this action display template with a redirect js code
	}

	public function unsupportedBrowserAction() {
		$this->_helper->layout->setLayout('noscript');
	}
		
	/**
	 * @param string $password
	 * @return boolean false on failure;  REDIRECTS if authentications was successful
	 */
	protected function authenticateAndRedirect($password) {
		if ($this->authenticate($password)) {
			
		    $params = LoginForward::getValue();
			
			$params['controller']	= 'Index';
			$params['action']		= 'Index';
			
			// delete cookie
            LoginForward::destroy();
			$this->redirect($params);
			return true;
		}
		return false;
	}
	
	/**
	 * @param string $password
	 * @return boolean
	 */
	protected function authenticate($password) {
		$authAdapter = new Authentication_Adapter($password);
		return Zend_Auth::getInstance()->authenticate($authAdapter)->isValid();
	}

	
    /**
     * @param boolean $accepted
     */
    protected function acceptAgreement($accepted) {
    	if(! $accepted) {
    		throw new Zwas_Exception(Zwas_Translate::_('Please accept the EULA to proceed with initialization process'));
    	}
    	return true;
    }
    
    protected function disableLogin() {
    	$this->view->disableLogin = true;
    }

	protected function newsletterRegistration() {
		if ('1' === $this->getTrimmedParam('newsletter-register')) {
			try {
				Newsletter::register($this->getTrimmedParam('email'));
			} catch (Zwas_Exception $e) {
				Zwas_Log::logException('Newsletter registration failure', $e);
			}
		}
	}
}