<?php
class Authentication_Token {
	
	
	const TOKEN_TTL			= 15;	// seconds
	const TOKEN_CACHE_KEY	= 'zcpanel.data';
	 
	/**
	 * Generate an authentication token, save it to a temporary file
	 * @return string - the generated token
	 * @throws Zwas_Exception
	 */
	public static function generateAuthenticationToken() {
		$authToken = md5(rand(100000, 999999));
		
		$store = Context_Cache::getCache()->store(self::TOKEN_CACHE_KEY, sha1($authToken), self::TOKEN_TTL);
		if (! $store) {
			$e = new Zwas_Exception('System was unable to save a temporary authentication key', Zwas_Exception::ASSERT);
			Zwas_Log::logException(__FUNCTION__, $e);
			throw $e;
		}
		return $authToken;
	}
	
	/**
	 * Check if a token is valid
	 * @param string $token
	 * @return boolean
	 */
	public static function validateToken($token) {
		$savedToken = Context_Cache::getCache()->fetch(self::TOKEN_CACHE_KEY);
		
		if (is_null($savedToken)) { // too old or not exist token
			return false;
		}
		
		if ($savedToken === sha1($token)) {
			return true;
		}
		
		// not valid token
		return false;
	}
	
}