<?php

class CacheTimestampsTable extends Zend_Db_Table_Abstract {
	
	protected $_name 	= 'cacheTimestamps';
	protected $_primary = 'tableName';
	
	/**
	 * For each cache table we keep a timestamp in a common timestamps table
	 * @param string $tableName
	 */
	public function updateTableTimestamp($tableName) {
		// Try to find an existing row								
		$row = $this->fetchRow($this->createWhereClause($tableName));
		if (null === $row) {											
			$row = $this->createRow();
			$row->tableName	= $tableName;
		}
		$row->timestamp	= microtime(true); 											
		$row->save();
	}

	/**
	 * Get the table's last changed timestamp
	 *
	 * @param string $tableName
	 * @return double returns 0 if the table has no entry
	 */
	public function getLastChangeTimestamp($tableName) {
		$row = $this->fetchRow($this->createWhereClause($tableName));
		if (null === $row) {
			return 0;
		}
		return $row->timestamp;
	}
	
	/**
	 * @param string $tableName
	 * @return integer
	 */
	public function removeTableTimestamp($tableName) {
		return $this->delete($this->createWhereClause($tableName));											
	}
	
	/**
	 * @return integer
	 */
	public function removeAllTableTimestamps() {
		return $this->delete(true);
	}
	
	/**
	 * @param string $tableName
	 * @return string
	 */
	private function createWhereClause($tableName) {
		return $this->getAdapter()->quoteInto('tableName = ?', $tableName);
	}
}