<?php

class Common_Context_Db {

	/**
	 * @var Context_Db_FactoryInterface
	 */
	private static $factoryObj = null;
	
	/**
	 * @return Context_Db_FactoryInterface
	 * @throws Zwas_Exception
	 */
	static function getInstance() {
		
		if (is_null(self::$factoryObj)) {
			self::setInstance(new Context_Db_Factory());
		}
		return self::$factoryObj;
	}
	
	/**
	 * Set the context class for the application
	 * @param Context_Db_FactoryInterface $factory
	 */
	static function setInstance(Context_Db_FactoryInterface $factory) {
		self::$factoryObj = $factory;
	}
	
    /**
     * Resets all object properties of the singleton instance
     * @return void
     */
    public static function resetInstance() {
    	self::$factoryObj = null;
    }
    	
	/**
	 * @return Zend_Db_Adapter_Abstract
	 */
	public static function getDbAdapter() {
		return self::getInstance()->getDbAdapter();
	}
		
	/**
	 * @return Directives_TableAll
	 */
	public static function getDirectivesAll() {
		return self::getInstance()->getDirectivesAll();
	}
	
	/**
	 * @return Directives_TableCached
	 */
	public static function getDirectivesCached() {
		return self::getInstance()->getDirectivesCached();
	}
	
	/**
	 * @return PhpExtensions_TableAll
	 */
	public static function getPhpExtensionsAll() {
		return self::getInstance()->getPhpExtensionsAll();
	}
	
	/**
	 * @return PhpExtensions_TableCached
	 */
	public static function getPhpExtensionsCached() {
		return self::getInstance()->getPhpExtensionsCached();
	}
	
	/**
	 * @return Zem_TableAll
	 */
	public static function getZemExtensionsAll() {
		return self::getInstance()->getZemExtensionsAll();
	}
	
	/**
	 * @return Zem_TableCached
	 */
	public static function getZemExtensionsCached() {
		return self::getInstance()->getZemExtensionsCached();
	}
	
	/**
	 * @return CacheTimestampsTable
	 */
	public static function getCacheTimestamps() {
		return self::getInstance()->getCacheTimestamps();
	}
	
	/** singleton **/
	private function __construct() {}
	private function __clone() {}
}