<?php

class Common_Context_Os {
	
	/**
	 * @var Common_Context_Os_Interface
	 */
	protected static $factory = null;
	
	/**
	 * @return Common_Context_Os_Interface
	 */
	public static function getInstance() {
		if (is_null(self::$factory)) {
			if (DIRECTORY_SEPARATOR == '\\') {
				self::$factory = new Context_Os_Win();
			} else { 
				if (in_array(PHP_OS, array('AIX', 'OS400'))) {
					self::$factory = new Context_Os_IbmI();
				} else {
					self::$factory = new Context_Os_Nix(); 
				}
			}
		}
		return self::$factory;
	}
	
	public static function setInstance(Common_Context_Os_Interface $instance) {
		self::$factory = $instance;	
	}
	
	
    /**
     * Resets all object properties of the singleton instance
     * @return void
     */
    public static function resetInstance() {
    	self::$factory = null;
    }	
	
	/**
	 * @return int
	 */
	public static function getOsType() {
		return self::getInstance()->getOsType();
	}
	
	/**
	 * @return string
	 */
	public static function getOsName() {
		return self::getInstance()->getOsName();
	}
	
	/**
	 * @return PhpExtensions_Parser
	 */
	public static function getPhpExtensionsParser() {
		return self::getInstance()->getPhpExtensionsParser();
	}
	
	/**
	 * @return int 
	 */
	public static function getServerRestartTimeout() {
		return self::getInstance()->getServerRestartTimeout();
	}
	
	/**
	 * @return string 
	 */
	public static function getZendIniScandir() {
		return self::getInstance()->getZendIniScandir();
	}
	
	public static function getHostname() {
		return self::getInstance()->getHostname();
	}
	
	/** singleton **/
	private function __construct() {}
	private function __clone() {}
}