<?php

abstract class Common_UserServer {
	
	/**
	 * @var Zend_XmlRpc_Server
	 */
	protected $server;
	
	public function __construct() {
		$this->server = new Zend_XmlRpc_Server();
	}
	
	public function run() {
		try {
			$this->setClasses();
			echo $this->server->handle();
		} catch (Exception $e) {
			echo $this->server->fault($e);
		}
	}
	
	/**
	 * Throw a standard exception when missing an extension API function
	 *
	 * @param string $className - __CLASS__
	 * @param string $functionName - __FUNCTION__
	 * @param string $missingApiFunctionName - the missing API function name
	 */
	public static function throwMissingApiFunctionError($className, $functionName, $missingApiFunctionName) {
		$msg = new Zwas_Text(
								"UserServer Error: Call to non-existing function: %s() in %s::%s()",
								array($missingApiFunctionName, $className, $functionName)
							);
		throw new Zwas_XmlRpc_Exception((string)$msg, Zwas_XmlRpc_Exception::MISSING_API_FUNCTION);
	}
		
	abstract protected function setClasses();
	
}