<?php

class Configuration_IniExtendedParser extends Configuration_IniParser {
	
	private $content = null;
	
	/**
	 * Returns the INI file content in an array. Each line is represented by a cell in the array, and the key is the line number
	 * @return array
	 */
	public function getContent() {
		if (!is_array($this->content)) {
			$this->parseIni();
		}
		return $this->content;
	}
	
	/**
	 * Returns an array with the keys as the directive name and the value is the line number in the content array
	 * @return array
	 */
	public function getDirectives() {
		return parent::getDirectives();
	}
	
	/**
	 * Returns an array with the keys as the extension file name and the value is the line number in the content array
	 * @return array
	 */
	public function getExtensions() {
		return parent::getExtensions();
	}
	
	/**
	 * Returns an array with the keys as the zend_extension file name and the value is the line number in the content array
	 * @return array
	 */
	public function getZendExtensions() {
		return parent::getZendExtensions();
	}
	
	
	/**
	 * Return an array where the elements have keys that are the zem extension identifier 
	 * and values that are the line number
	 * @return array
	 */
	public function getZemExtensions() {
		return parent::getZemExtensions();
	}
		
	/**
	 * Goes over the entire INI file, and parse from it a list of directives and extensions
	 */
	protected function parseIni() {
		$this->initLists();
		$lineNumber = 0;
		foreach($this->stream as $line) {			
			$this->content[$lineNumber] = trim($line);
			
			$directiveLine = $this->parseLine($line);
			if (count($directiveLine)) {	// We need to save the line number of the returned 'element'
				if (array_key_exists(self::EXTENSION_DIRECTIVE_NAME, $directiveLine)) {
					$this->addExtensionToList($directiveLine[self::EXTENSION_DIRECTIVE_NAME], $lineNumber);
				} else if (array_key_exists(self::ZEND_EXTENSION_DIRECTIVE_NAME, $directiveLine)) {
					$this->zendExtensions[ $directiveLine[self::ZEND_EXTENSION_DIRECTIVE_NAME] ] = $lineNumber;
				} else {
					$directiveName = key($directiveLine);
					// separate extensions from zend components
					if (false !== strpos($directiveName, Configuration_IniParser::ZEM_DIRECTIVE_PREFIX)) {
						
						$identifier = substr($directiveName, (1 + strrpos($directiveName, '.')));
						$this->zemComponents[$identifier] = $lineNumber;
					} else {
						// if the directive is duplicated in th ini file, we remove it from the content
						if (array_key_exists($directiveName, $this->directiveList)) {
							$this->content[ $this->directiveList[$directiveName] ] = '';
						}
						$this->directiveList[$directiveName] = $lineNumber;
					}
				}
			}
			++$lineNumber;
		}
		// workaround for SPLFileObject bug - foreach returns extra empty line
		if(end($this->content) == '') {
			array_pop($this->content);
		}
		// currently there is no way to close the stream, no support in the SPLFileObject
		//$this->stream->close();
	}

	protected function trimValue($value) {
		return trim($value);
	}
	
	/**
	 * Initiates both directiveList and extensionList to arrays
	 */
	protected function initLists() {
		$this->content = array();
		parent::initLists();
	}

	private function addExtensionToList($extName, $lineNumber) {
		// if the extension appear twice, ignore the second instance (same behavior as PHP) 
		if (array_key_exists($extName, $this->extensionList)) {
			$this->content[ $lineNumber ] = '';
		} else {
			$this->extensionList[ $extName ] = $lineNumber;
		}
	}
}
