<?php

class Configuration_IniFilesScanner {
	
	/**
	 * retrieve extensions directives from all ini files parsed by php.
	 * return value format:
	 * array('ini filename1' => array('extfilename1' => true,
	 * 								  'extfilename2' => true, ...)
	 * 		 'ini filename2' => ...)
	 * 
	 * @return array
	 */
	public function getExtensions() {
		$memory = Context_Api::getPhpMemory();
		$list = array();
		foreach ($memory->getIniScannedFiles() as $iniFile) {
			try {
				$parser = new Configuration_IniParser(Context_FileSystem::getFileObject($iniFile));
				$list[$iniFile] = $parser->getExtensions();
			} catch (Exception $e) {
				/*
				 * the ini file could not be opened, which means the system cant read it
				 * as well --> it has no meaning (other then a probably bad zend_ini_file config)
				 * and can simply be ignored
				 */
			}
			
		}
		return $list;
	}
	
	
	/**
	 * retrieve directives from all ini files parsed by php.
	 * return value format:
	 * array('ini filename1' => array('dirname1' => 'dirvalue',
	 * 								  'dirname2' => 'dirvalue', ...)
	 * 		 'ini filename2' => ...)
	 * 
	 * @return array
	 */
	public function getDirectives() {
		$memory = Context_Api::getPhpMemory();
		$list = array();
		foreach ($memory->getIniScannedFiles() as $iniFile) {
			try {
				$parser = new Configuration_IniParser(Context_FileSystem::getFileObject($iniFile));
				$list[$iniFile] = $parser->getDirectives();
			} catch (Exception $e) {
				/*
				 * the ini file could not be opened, which means the system cant read it
				 * as well --> it has no meaning (other then a probably bad zend_ini_file config)
				 * and can simply be ignored
				 */
			}
		}
		return $list;
	}
	
	/**
	 * retrieve zem directives from all ini files parsed by php.
	 * return value format:
	 * array('ini filename1' => array('dirname1' => 'dirvalue',
	 * 								  'dirname2' => 'dirvalue', ...)
	 * 		 'ini filename2' => ...)
	 * 
	 * @return array
	 */
	public function getZemExtensions() {
		$memory = Context_Api::getPhpMemory();
		$list = array();
		foreach ($memory->getIniScannedFiles() as $iniFile) {
			try {
				$parser = new Configuration_IniParser(Context_FileSystem::getFileObject($iniFile));
				$list[$iniFile] = $parser->getZemExtensions();
			} catch (Exception $e) {
				/*
				 * the ini file could not be opened, which means the system cant read it
				 * as well --> it has no meaning (other then a probably bad zend_ini_file config)
				 * and can simply be ignored
				 */
			}
			
		}
		return $list;
	}
	
}