<?php
class Context_Api {
	
	/**
	 * @var Context_Api_FactoryInterface
	 */
	private static $factory = null;
	
	/**
	 * @return Context_Api_FactoryInterface
	 */
	public static function getInstance() {
		if (is_null(self::$factory)) {
			self::$factory = new Context_Api_FactoryUserServer();
		}
		return self::$factory;
	}
	
	public static function setInstance(Context_Api_FactoryInterface $instance) {
		self::$factory = $instance;
	}
	
	/**
     * Resets all object properties of the singleton instance
     * @return void
     */
    public static function resetInstance() {
    	self::$factory = null;
    }
	
	/**
	 * @return PhpMemory_Interface
	 */
	public static function getPhpMemory() {
		return self::getInstance()->getPhpMemory();
	}
		
	/**
	 * @return ZwasComponents_Accelerator_Api_Interface
	 */
	public static function getAcceleratorAPI() {
		return self::getInstance()->getAcceleratorAPI();
	}
	
	/**
	 * @return ZwasComponents_DataCache_Api_Interface
	 */
	public static function getCacheAPI() {
		return self::getInstance()->getCacheAPI();
	}
	
	/**
	 * @return ZwasComponents_PageCache_Api_Interface
	 */
	public static function getPageCacheAPI() {
		return self::getInstance()->getPageCacheAPI();
	}
	
	/**
	 * @return ZwasComponents_JavaBridge_Api_Interface
	 */
	public static function getJavaBridgeAPI() {
		return self::getInstance()->getJavaBridgeAPI();
	}
	
	/**
	 * @return ZwasComponents_Util_Api_Interface
	 */
	public static function getUtilAPI() {
		return self::getInstance()->getUtilAPI();
	}
	
	/**
	 * @return PhpGlobals_Api_Interface
	 */
	public static function getPhpGlobals() {
		return self::getInstance()->getPhpGlobals();
	}

	/**
	 * @return Webserver_Api
	 */
	public static function getWebserverAPI() {
		return self::getInstance()->getWebserverAPI();
	}
	
	/**
	 * @return ZwasComponents_MonitorUi_Api_Interface
	 */
	public static function getMonitorUiApi() {
		return self::getInstance()->getMonitorUiApi();
	}
	
	/**
	 * @return ZwasComponents_Monitor_Daemon_Api_Interface
	 */
	public static function getMonitorDaemonApi() {
		return self::getInstance()->getMonitorDaemonApi();
	}
	
	/**
	 * @return ZwasComponents_SessionClustering_Api_Interface
	 */
	public static function getSessionClusteringDaemonApi() {
		return self::getInstance()->getSessionClusteringDaemonApi();
	}

	/**
	 * @return ZwasComponents_JobQueue_Api_Interface
	 */
	static public function getJobQueueApi() {
		return self::getInstance()->getJobQueueApi();
	}
	/**
	 * @return ZwasComponents_CodeTracing_Api_Interface
	 */
	static public function getCodeTracingApi() {
		return self::getInstance()->getCodeTracingApi();
	}
		
	/** singleton **/
	private function __construct() {}
	private function __clone() {}
}