<?php

class Context_FileSystem {
	
	/**
	 * @var Context_FileSystem_FactoryInterface
	 */
	private static $factory = null;
	
	/**
	 * @return Context_FileSystem_FactoryInterface
	 */
	public static function getInstance() {
		if (is_null(self::$factory)) {
			self::$factory = new Context_FileSystem_Factory();
		}
		return self::$factory;
	}
	
	public static function setInstance(Context_FileSystem_FactoryInterface $instance) {
		self::$factory = $instance;
	}
	
    /**
     * Resets all object properties of the singleton instance
     * @return void
     */
    public static function resetInstance() {
    	self::$factory = null;
    }
    	
	/**
	 * @param string $path
	 * @param string $openMode
	 * @return Zwas_FileObject
	 */
	public static function getFileObject($path, $openMode = 'r') {
		return self::getInstance()->getFileObject($path, $openMode);
	}

	/**
	 * @param string $path
	 * @param array $options
	 * @return Zend_Config
	 */
	public static function getConfigReader($path, array $options = array()) {
		return self::getInstance()->getConfigReader($path, $options);
	}
	
	/**
	 * @param string $path
	 * @param array $options
	 * @return Zend_Config_Writer
	 */
	public static function getConfigWriter($path, array $options = array()) {
		return self::getInstance()->getConfigWriter($path, $options);
	}
	
	/**
	 * @param string $path
	 * @return Zwas_DirectoryObject
	 */
	public static function getDirectoryObject($path) {
		return self::getInstance()->getDirectoryObject($path);
	}
	
	/**
	 * @see Context_FileSystem_FactoryInterface::copy()
	 *
	 * @param string $source
	 * @param string $dest
	 * @return bool
	 */
	public static function copy($source , $dest){
		return self::getInstance()->copy($source, $dest);
	}
	
	/**
	 * @see Context_FileSystem_FactoryInterface::unlink()
	 *
	 * @param string $filename
	 * @return bool
	 */
	public static function unlink($filename){
		return self::getInstance()->unlink($filename);
	}
	
	/**
	 * @param string $filename
	 * @return boolean
	 */
	public static function touch($filename) {
		return self::getInstance()->touch($filename);
	}
	
	/**
	 * @param string $filename
	 * @return array|false
	 */
	public static function stat($filename) {
		return self::getInstance()->stat($filename);
	}
	
	/**
	 * @param string $filename
	 * @return boolean
	 */
	public static function fileExists($filename) {
		return self::getInstance()->fileExists($filename);
	}
	
	/**
	 * @param string $filename
	 * @param integer $flags
	 * @return Zwas_Zip
	 * @throws Zwas_Exception
	 */
	public static function getZipArchive($zipFilepath, $flags = 0) {
		return self::getInstance()->getZipArchive($zipFilepath, $flags);
	}
	
	/** singleton **/
	private function __construct() {}
	private function __clone() {}
}