<?php
class Context_FileSystem_Factory implements Context_FileSystem_FactoryInterface {

	/**
	 * @param string $path
	 * @param string $openMode
	 * @return Zwas_FileObject
	 */
	public function getFileObject($path, $openMode = 'r') {
		return new Zwas_FileObject($path, $openMode);
	}
	
	/**
	 * @param string $path
	 * @return Zwas_DirectoryObject
	 */
	public function getDirectoryObject($path) {
		return new Zwas_DirectoryObject($path);
	}

	
	/**
	 * @see Context_FileSystem_FactoryInterface::getConfigReader()
	 *
	 * @param string $path
	 * @param array $options
	 * @return Zend_Config
	 * @throws Zwas_Exception
	 */
	public function getConfigReader($path, array $options = null) {
		try {
			return new Zend_Config_Ini($path, null, $options);
		} catch (Exception $e) {
			Zwas_Log::logException('Could not get a config reader in ' . __CLASS__ . '::' . __FUNCTION__,
										$e);
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('An internal error occurred while trying to read %s'), $path));
		}
	}

	/**
	 * @see Context_FileSystem_FactoryInterface::getConfigWriter()
	 *
	 * @param string $path
	 * @param array $options
	 * @return Zend_Config_Writer
	 * @throws Zwas_Exception
	 */
	public function getConfigWriter($path, array $options = null) {
		$options['filename'] = $path;
		try {
			return new Zwas_Config_Writer_Ini($options);
		} catch (Exception $e) {
			Zwas_Log::logException('Could not get a config writer in ' . __CLASS__ . '::' . __FUNCTION__,
										$e);
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('An internal error occurred while trying to open %s'), $path));
		}
	}

	/**
	 * @see Context_FileSystem_FactoryInterface::copy()
	 *
	 * @param string $source
	 * @param string $dest
	 * @return bool
	 */
	public function copy($source , $dest){
		return copy($source, $dest);
	}
	
	/**
	 * @see Context_FileSystem_FactoryInterface::unlink()
	 *
	 * @param string $filename
	 * @return boolean
	 */
	public function unlink($filename){
		return unlink($filename);
	}
	
	/**
	 * @param string $filename
	 * @return boolean
	 */
	public function touch($filename) {
		return touch($filename);
	}
	
	/**
	 * @see Context_FileSystem_FactoryInterface::stat()
	 *
	 * @param string $filename
	 * @return array|false
	 */
	public function stat($filename){
		return $this->fileExists($filename) ? stat($filename) : false;
	}
	/**
	 * @param string $filename
	 * @return boolean
	 */
	public function fileExists($filename) {
		return file_exists($filename);
	}
	
	/**
	 * @param string $filename
	 * @param integer $flags
	 * @return Zwas_Zip
	 * @throws Zwas_Exception
	 * @see Context_FileSystem_FactoryInterface::getZipArchive()
	 */
	public function getZipArchive($zipFilepath, $flags = 0) {
		return new Zwas_ZipArchive($zipFilepath, $flags);
	}
}