<?php
class Context_Version {
	
	const EDITION_COMMUNITY		= 'CE';
	const EDITION_PROFESSIONAL	= 'PE';
	const EDITION_MANAGER		= 'EE';
		
	/**
	 * @var Context_Version_Abstract
	 */
	private static $instance;
	
	/**
	 * @return Context_Version_Abstract
	 */
	public static function getInstance() {
		if (is_null(self::$instance)) {
			switch (ZEND_SERVER_APP_VERSION) {
				case Context_Version::EDITION_COMMUNITY:
					self::$instance = new Context_Version_CE();
					break;
				case Context_Version::EDITION_PROFESSIONAL:
					self::$instance = new Context_Version_PE();
					break;
				case Context_Version::EDITION_MANAGER:
					self::$instance = new Context_Version_EE();
					break;
				default:
					throw new Zwas_Exception(	'Could not locate the appropriate Context_Version for ' . ZEND_SERVER_APP_VERSION,
												Zwas_Exception::ASSERT
											);
			}
		}
		return self::$instance;
	}

	/**
	 * @return License_Control_Interface|null
	 */	
	public static function getLicenseControl() {
		return self::getInstance()->getLicenseControl();
	}
	
	/**
	 * @return StudioIntegration_Model
	 */
	public static function getStudioIntegrationModel() {
		return self::getInstance()->getStudioIntegrationModel();
	}
	
	/**
	 * @return License_Model_Abstract
	 * @throws Zwas_Exception
	 */
	public static function getLicenseModel($licenseInfo = null) {
		return self::getInstance()->getLicenseModel($licenseInfo);
	}
	
	/**
	 * @param Context_Version_Abstract $instance
	 */
	public static function setInstance(Context_Version_Abstract $instance) {
		self::$instance = $instance;
	}
	
	/**
     * Resets all object properties of the singleton instance
     * @return void
     */
    public static function resetInstance() {
    	self::$instance = null;
    }
}