<?php
class Directives_Compare {
	
	/**
	 * Checks if the value passed is the same as the one in the directive, taking
	 * into consideration translation of the value (e.g. 'On' and '1' are the same
	 * for a boolean directive)
	 *
	 * @param Directives_Element $directive
	 * @param mixed $value
	 * @return boolean
	 */
	static public function isValueEqual(Directives_Element $directive, $value) {
		$dummyDirectiveElement = clone $directive;
		$dummyDirectiveElement->setFileValue($value);

		return ((string)Directives_Translator::getRealFileValue($directive) ===
				(string)Directives_Translator::getRealFileValue($dummyDirectiveElement));
	}
	
	/**
	 * Checks if the value passed is the same as the global value in the directive, 
	 * taking into consideration translation of the value (e.g. 'On' and '1' are the 
	 * same for a boolean directive)
	 *
	 * @param Directives_Element $directive
	 * @param mixed $value
	 * @return boolean
	 */
	static public function isGlobalValueEqual(Directives_Element $directive, $value) {
		$dummyDirectiveElement = clone $directive;
		$dummyDirectiveElement->setMemoryValue($value);

		return ((string)Directives_Translator::getRealMemoryValue($directive) ===
				(string)Directives_Translator::getRealMemoryValue($dummyDirectiveElement));
	}

	/**
	 * Check if the directive's value is different from its global value (e.g. for a boolean
	 * directive 1 = on = yes)
	 *
	 * @param Directives_Element $directive
	 * @return boolean
	 */
	static public function isDirectiveChanged(Directives_Element $directive) {
		return (Directives_Translator::getRealFileValue($directive) != Directives_Translator::getRealMemoryValue($directive)); 
	}
}