<?php
class DisplayWidget_ExtensionActionLink extends DisplayWidget_Link {

	const LINK_TYPE_NULL						= 0;	// display no icon
	const LINK_TYPE_NOT_INSTALLED				= 1;
	const LINK_TYPE_LOADED_UNLOADABLE			= 2;
	const LINK_TYPE_LOADED_LOADABLE				= 3;
	const LINK_TYPE_NOT_LOADED_LOADABLE			= 4;
	const LINK_TYPE_BUILT_IN					= 5;	// loaded which can't be unloaded
	const LINK_TYPE_NOT_LOADED_NOT_LOADABLE		= 6;	// rare case
	const LINK_TYPE_NOT_LOADED_UNLOADABLE		= 7;	// rare case, not loaded and enabled
	const LINK_TYPE_NOT_LOADED_NO_ACTION		= 8;	// just an icon with a link to the extensions page without an action
	const LINK_TYPE_NOT_LOADED_ERROR 			= 9;	// some error had happened, not fixable
	const LINK_TYPE_ERROR_FIXABLE				= 10;	// some error had happened and its fixable (usualy by disable the extension)

	/**
	 * One of the LINK_TYPE_* constants which defines which button to display
	 * @var integer
	 */
	private $linkType;

	/**
	 * @param integer $linkType
	 */
	public function __construct($linkType) {
		parent::__construct('', 'Configuration');
		
		$this->linkType = $linkType;
		$this->controller	= 'Configuration';
		
		$this->setLabelByType($this->linkType);
		$this->setActionByType($this->linkType);
	}
	
	/**
	 * @return integer
	 */
	public function getLinkType() {
		return $this->linkType;
	}

	/**
	 * @param integer $linkType
	 */
	private function setLabelByType($linkType) {
		switch ($linkType) {
			case self::LINK_TYPE_LOADED_UNLOADABLE:
			case self::LINK_TYPE_NOT_LOADED_UNLOADABLE:
				$this->label = Zwas_Translate::_('Turn off');
				break;
			case self::LINK_TYPE_ERROR_FIXABLE:
				$this->label = Zwas_Translate::_('Turn off');
				break;
			case self::LINK_TYPE_NOT_LOADED_LOADABLE:
			case self::LINK_TYPE_LOADED_LOADABLE:
				$this->label = Zwas_Translate::_('Turn on');
				break;
			default:
				$this->label = '';
				break;
		}
	}

	/**
	 * @param integer $linkType
	 */
	private function setActionByType($linkType) {
		switch ($linkType) {
			case self::LINK_TYPE_LOADED_UNLOADABLE:
			case self::LINK_TYPE_NOT_LOADED_UNLOADABLE:
				$this->setAction('Unload-Extension');
				break;
			case self::LINK_TYPE_ERROR_FIXABLE:
				$this->setAction('Fix-Extension');
				break;
			case self::LINK_TYPE_NOT_LOADED_LOADABLE:
			case self::LINK_TYPE_LOADED_LOADABLE:
				$this->setAction('Load-Extension');
				break;
			default:
				$this->setAction('');
				break;
		}		
	}
}