<?php
/**
 * This is an extension action which has an icon and a tooltip that appears when standing over it
 * The icon acts like a button
 */
class DisplayWidget_ExtensionIconButton extends DisplayWidget_Link {
	
	const ICON_NULL						= 0;	// display no icon
	const ICON_LOADED_UNLOADABLE		= 1;
	const ICON_NOT_LOADED_LOADABLE		= 2;
	const ICON_BUILT_IN					= 3;	// loaded which can't be unloaded
	const ICON_NOT_LOADED_NOT_LOADABLE	= 4;	// rare case
	const ICON_NOT_LOADED_UNLOADABLE	= 5;	// rare case, not loaded and enabled
	const ICON_NOT_LOADED_NO_ACTION		= 6;	// just an icon with a link to the extensions page without an action
	const ICON_NOT_LOADED_ERROR_FIXABLE	= 7;	// some error had happened and its fixable (usualy by disable the extension)
	const ICON_NOT_LOADED_ERROR 		= 8;	// some error had happened, not fixable
	
	// Zend Server Extensions Icons
	const ICON_STOP		= 11;
	const ICON_START	= 12;
	const ICON_RESTART	= 13;
	const ICON_CLEAN	= 14;
	const ICON_ENABLE	= 21;
	const ICON_DISABLE	= 22;
	
	/**
	 * @var Zwas_Text | string
	 */
	private $tooltipContent;
	/**
	 * One of the ICON_* constants which defines which icon to display
	 * @var integer
	 */
	private $iconType;
	
	/**
	 * @param integer $iconType the type of the icon
	 * @param Zwas_Text | string $tooltipContent The content of the tooltip box
	 */
	public function __construct($iconType, $tooltipContent=null, $targetController = null, $targetAction = null) {
		$this->type				= self::DISPLAY_WIDGET_ICON_BUTTON;
		$this->iconType			= $iconType;
		$this->tooltipContent	= $tooltipContent;
		$this->label			= '';
		$this->targetController	= $targetController;
		$this->targetAction		= $targetAction;
		
		switch($this->iconType) {
			case self::ICON_LOADED_UNLOADABLE:
			case self::ICON_NOT_LOADED_UNLOADABLE:
				$this->controller	= 'Configuration';
				$this->action		= 'Unload-Extension';
				break;
			case self::ICON_NOT_LOADED_LOADABLE: 
				$this->controller	= 'Configuration';
				$this->action		= 'Load-Extension';
				break;
			case self::ICON_NOT_LOADED_NO_ACTION:
				$this->controller	= 'Configuration';
				$this->action		= 'Extensions';
				break;
			case self::ICON_NOT_LOADED_ERROR_FIXABLE:
				$this->controller	= 'Configuration';
				$this->action		= 'Fix-Extension';
				break;
			case self::ICON_NOT_LOADED_ERROR:
			case self::ICON_BUILT_IN:
			case self::ICON_NOT_LOADED_NOT_LOADABLE:
			case self::ICON_NULL:
			default:
				$this->controller	= '';
				$this->action		= '';
				break;
		}
	}

	/**
	 * @return integer
	 */
	public function getIconType() {
		return $this->iconType;
	}

	/**
	 * @return Zwas_Text | string
	 */
	public function getTooltipContent() {
		return $this->tooltipContent;
	}
	
}