<?php

/**
 * This is an extension action which has an icon and a tooltip that appears when standing over it
 */
class DisplayWidget_IconTooltip extends DisplayWidget_Abstract {
	
	const ICON_NULL				= 0;	// display no icon
	
	// General state icons
	const ICON_NOTICE			= 11;
	const ICON_INFO				= 12;
	
	// Zem components state icons
	const ICON_LED_GREEN		= 21;
	const ICON_LED_YELLOW		= 22;
	const ICON_LED_GREY			= 23;
	const ICON_LED_RED			= 24;
	const ICON_LED_GREEN_NOTICE	= 25;
	
	// Updates severity icons
	const ICON_SEVERITY_CRITICAL	= 31;
	const ICON_SEVERITY_IMPORTANT	= 32;
	const ICON_SEVERITY_OPTIONAL	= 33;
	const ICON_SEVERITY_RECOMMENDED	= 34;
	
	/**
	 * @var Zwas_Text | string
	 */
	private $tooltipContent;
	/**
	 * One of the ICON_* constants which defines which icon to display
	 * @var integer
	 */
	private $iconType;
	
	/**
	 * @param string $iconType the type of the icon
	 * @param Zwas_Text | string $tooltipContent The content of the tooltip box
	 * @param Zwas_Text | string $label The label that will appear next to the info icon
	 */
	public function __construct($iconType, $tooltipContent=null, $label=null) {
		$this->type				= self::DISPLAY_WIDGET_ICON_TOOLTIP;
		$this->iconType			= $iconType;
		$this->tooltipContent	= $tooltipContent;
		$this->label			= $label;
	}

	/**
	 * @return integer
	 */
	public function getIconType() {
		return $this->iconType;
	}

	/**
	 * @return Zwas_Text|string
	 */
	public function getTooltipContent() {
		return $this->tooltipContent;
	}
	
	public function setTooltipContent($content) {
		$this->tooltipContent = $content;
	}
}