<?php

/**
 * A class for holding the information for an action on an extension, possibly followed by a controller and 
 * action which will be displayed after the extension action is done
 * For example, we may call JavaBridge/Start and then want to go to JavaBridge/DisplayInformation page, 
 */
class DisplayWidget_Link extends DisplayWidget_Abstract {

	/**
	 * @var string
	 */
	protected $controller;
	/**
	 * @var string
	 */
	protected $action;
	/**
	 * @var string
	 */
	protected $targetController;
	/**
	 * @var string
	 */
	protected $targetAction;
	/**
	 * An array of GET paramters, formatted as key => value
	 * @var array
	 */
	protected $params = array();
	
	private $sidebarIdentifier = '';
	
	/**
	 * Create a new Exte
	 *
	 * @param string $label
	 * @param string $controller
	 * @param string $action
	 * @param string $targetController
	 * @param string $targetAction
	 */
	public function __construct($label, $controller, $action = null, $targetController = null, $targetAction = null) {
		$this->type 			= self::DISPLAY_WIDGET_LINK;
		$this->controller 		= $controller;
		$this->action 			= $action;
		$this->targetController	= $targetController;
		$this->targetAction		= $targetAction;
		$this->label			= $label;
		
		// TODO: maybe auto generate default sidebar id (based on targetController & targetAction, fallback to controller & action)
	}

	/**
	 * @return string
	 */
	public function getAction() {
		return $this->action;
	}

	/**
	 * @return string
	 */
	public function getController() {
		return $this->controller;
	}
	/**
	 * @return string
	 */
	public function getTargetAction() { 
		return $this->targetAction; 
	}

	/**
	 * @return string
	 */
	public function getTargetController() { 
		return $this->targetController; 
	}
	
	/**
	 * The identifier of the item in the sidebar menu which should be marked as selected 
	 * @return string
	 */
	public function getSidbarIdentifier() {
		return $this->sidebarIdentifier;
	}
	
	/**
	 * Get an array of the GET parameters in the format of name => value
	 * @return array
	 */
	public function getParams() {
		return $this->params;
	}
		
	/**
	 * The controller which clicking this link goes to
	 * @param string $controller
	 */
	public function setController($controller) {
		$this->controller = $controller;
	}
	
	/**
	 * The action which clicking this link goes to
	 * @param string $action
	 */
	public function setAction($action) {
		$this->action = $action;
		
	}
	
	/**
	 * Add GET params to the call in the format of name => value
	 * @param array $params
	 * @throw Zwas_Exception if trying to set GET params without having an action
	 */
	public function setParams(array $params) {
		if (is_null($this->action)) {
			throw new Zwas_Exception('GET parameters can not be used if there is no action for the controller', Zwas_Exception::ASSERT);
		}
		$this->params = $params;
	}

	/**
	 * Set which sidebar list item should be selected when clicking this link
	 *
	 * @param string $identifier
	 */
	public function setSidbarIdentifier($identifier) {
		$this->sidebarIdentifier = $identifier;
	}
		
	/**
	 * @param string $targetController
	 * @param string $targetAction
	 */
	public function setTarget($targetController, $targetAction) {
		$this->targetController	= $targetController;
		$this->targetAction		= $targetAction;
	}	
}