<?php
/**
 * A container class that holds data for the view to display later
 */ 
class Extensions_Display {

	const STATUS_LOADED		= 'Loaded';
	const STATUS_NOT_LOADED	= 'Not loaded';
	const STATUS_BUILT_IN	= 'Built-in';
	
	/**
	 * @var string
	 */
	private $name;
	/**
	 * @var string
	 */
	private $shortDescription;
	/**
	 * The configuration link action
	 * @var DisplayWidget_Abstract
	 */
	private $configurationLinkAction;
	
	private $statusActionButton;
	/**
	 * shows the status of the extension
	 *
	 * @var DisplayWidget_IconTooltip
	 */
	private $statusIcon;
	/**
	 * acts as a button to load / unload it
	 *
	 * @var DisplayWidget_ExtensionActionLink
	 */
	private $statusActionLink;
		
	/**
	 * @var DisplayWidget_Info
	 */
	private $statusMessage;
	
	/**
	 * Create a new container for extensions display data
	 *
	 * @param string $name
	 */
	public function __construct($name) {
		$this->name = $name;
	}

	/**
	 * @return DisplayWidget_Abstract
	 */
	public function getConfigurationLinkAction() {
		return $this->configurationLinkAction;
	}

	/**
	 * @return string
	 */
	public function getName() {
		return (string)$this->name;
	}

	/**
	 * @return DisplayWidget_IconTooltip
	 */
	public function getShortDescription() {
		if (! empty($this->shortDescription)) {
			return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_INFO,
													$this->shortDescription);
		}
		return new DisplayWidget_IconTooltip(DisplayWidget_IconTooltip::ICON_NULL);
	}

	/**
	 * @return DisplayWidget_IconTooltip
	 */
	public function getStatusIcon() {
		return $this->statusIcon;
	}
		
	/**
	 * @return DisplayWidget_ExtensionActionLink
	 */
	public function getStatusActionLink() {
		return $this->statusActionLink;
	}
	
	/**
	 * @return DisplayWidget_Info
	 */
	public function getStatusMessage() {
		return $this->statusMessage;
	}
	
	/**
	 * @param DisplayWidget_Abstract $configurationLinkAction
	 */
	public function setConfigurationLinkAction(DisplayWidget_Abstract $configurationLinkAction) {
		$this->configurationLinkAction = $configurationLinkAction;
	}

	/**
	 * @param string $shortDescription
	 */
	public function setShortDescription($shortDescription) {
		$this->shortDescription = $shortDescription;
	}

	public function setStatusIcon(DisplayWidget_IconTooltip $icon) {
		$this->statusIcon = $icon;
	}
		
	public function setStatusActionLink(DisplayWidget_Abstract $link) {
		$this->statusActionLink = $link;
	}

	/**
	 * @param DisplayWidget_Info $message
	 */
	public function setStatusMessage(DisplayWidget_Info $message) {
		$this->statusMessage = $message;
	}
}