<?php

abstract class Extensions_ElementAbstract {
	
	const INI_NOT_EXIST = 0;	// The extension does not appear in the ini file
	const INI_DISABLED	= 1;	// The extension appears in the ini file, but commented out
	const INI_ENABLED 	= 2;	// The extension appears in the ini file
	
	/**
	 * @var boolean
	 */
	protected $loaded = false;
	
	/**
	 * same as 'extension_name' in the zem_get_extension_info() result
	 * @var string
	 */
	protected $extensionName;
		
	/**
	 * Currently php.ini
	 * @var string
	 */
	protected $iniFile = '';

	/**
	 * @var integer
	 */
	protected $iniStatus = self::INI_NOT_EXIST;

	/**
	 * @var string
	 */
	private $shortDescription;
	
	/**
	 * The number of directives associated with this extension
	 * @var integer
	 */
	private $numAssocDirectives = 0;
	/**
	 * A flag to mark if the extension's loaded state awaits a restart to change
	 * @var boolean
	 */
	private $awaitsRestart = false;
	/**
	 * Flag if the file / folder actually exist on the file system
	 * @var boolean
	 */
	private $fileExists = false;
		
	/**
	 * @return string
	 */
	public function getName() {
		return (string)$this->extensionName;
	}
	
	/**
	 * @return string
	 */
	public function getIniFile() {
		return (string)$this->iniFile;
	}
			
	/**
	 * @return boolean
	 */
	public function isLoaded() {
		return (boolean)$this->loaded;
	}

	/**
	 * @return boolean
	 */
	public function isLoadedInMemory() {
		return (boolean)$this->loaded;
	}

	/**
	 * @return boolean
	 */
	public function isLoadedInFile() {
		return (self::INI_ENABLED == $this->iniStatus);
	}

	/**
	 * @return boolean
	 */
	public abstract function isInstalled();
	
	/**
	 * Does this extension awaits a webserver restart before its loaded state will change?
	 * @return boolean
	 */
	public function awaitsRestart() {
		return (boolean)$this->awaitsRestart;
	}
	
	/**
	 * Does the extension appear in the ini file
	 * @return integer
	 */
	public function getIniStatus() {
		return (int)$this->iniStatus;
	}

	/**
	 * @return string
	 */
	public function getShortDescription() {
		return (string)$this->shortDescription;
	}	

	/**
	 * @return integer
	 */
	public function getNumberOfAssociactedDirectives() {
		if ($this->numAssocDirectives == (integer)$this->numAssocDirectives) {
			return (integer)$this->numAssocDirectives;
		}
		return 0;
	}
	
	/**
	 * @param string $description
	 */
	public function setShortDescription($description) {
		$this->shortDescription = (string)$description;
	}
		
	/**
	 * Returns whether the extension has an extension file defined for it, without
	 * checking if the file exists
	 * 
	 * @return boolean
	 */
	public abstract function hasFilename();
	
	/**
	 * Return if the filename defined for the actually exists
	 * @return boolean
	 */
	public function fileExists() {
		return (boolean)$this->fileExists;
	}
	
	/**
	 * @return string
	 */
	public abstract function getErrorString();
		
	/**
	 * @param string $extensionName
	 */
	public function setName($extensionName) {
		$this->extensionName = (string)$extensionName;
	}
	
	/**
	 * @param string $iniFile
	 */
	public function setIniFile($iniFile) {
		$this->iniFile = (string)$iniFile;
	}	

	/**
	 * @param boolean $loaded
	 */
	public function setLoaded($loaded) {
		$this->loaded = (boolean)$loaded;
	}
	
	/**
	 * @param integer $iniStatus
	 */
	public function setIniStatus($iniStatus) {
		$this->iniStatus = (int)$iniStatus;
	}
	
	/**
	 * @param integer $num
	 */
	public function setNumberOfAssociactedDirectives($num) {
		$this->numAssocDirectives = (int)$num;
	}
	
	/**
	 * @param boolean $value
	 */
	public function setAwaitsRestart($value) {
		$this->awaitsRestart = (boolean)$value;
	}

	/**
	 * @param boolean $value
	 */
	public function setFileExists($value) {
		$this->fileExists = (boolean)$value;
	}
}