<?php

class Extensions_Model {
	
	/**
	 * Return list (array) of Extensions_Display elements
	 * @return array
	 */
	public function getDisplayList() {
		$extensionElementList = $this->getExtensionElementsList();
		
		// create an array of extension display objects
		$extensionsDisplayArray = array();
		foreach ($extensionElementList as $extensionElement) { /* @var $extensionElement Extensions_ElementAbstract */
			$extensionsDisplayArray[] = Extensions_DisplayGenerator::getExtensionDisplay($extensionElement);
		}
		return $extensionsDisplayArray;
	}
	
	/**
	 * Return list (array) of extension elements
	 * @return array
	 */
	public function getExtensionElementsList() {
		$phpExtensions = new PhpExtensions_Model();
		$phpList = $phpExtensions->getAvailableExtensionList();
		
		$zemExtensions = new Zem_Model();
		$zemList = $zemExtensions->getAvailableExtensionNames();
		$zemList['zend monitor ui'] = 'Zend Monitor UI'; // MUI extension exist only on non-dedicated Zend Server (bug #25067)
		
		// The order of the array union is important
		$mergedList = array_diff_key($phpList, $zemList);
		ksort($mergedList);
		
		return $mergedList;
	}
		
	/**
	 * @param string $extensionName
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure
	 */
	public function loadExtension($extensionName) {
		$zemModel = new Zem_Model();
		$element = $zemModel->getElement($extensionName);
		
		if ($element instanceof Zem_Element) {
			$zemModel->loadExtension($element);
			return $element->awaitsRestart();
		}
		
		$phpExtensionModel = new PhpExtensions_Model();
		$element = $phpExtensionModel->getElement($extensionName);
		
		if ($element instanceof PhpExtensions_Element) {
			$phpExtensionModel->loadExtension($element);
			return $element->awaitsRestart();
		}
		
		throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Could not find an extension named %s'), $extensionName));
	}

	/**
	 * @param string $extensionName
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure
	 */
	public function unloadExtension($extensionName) {
		$zemModel = new Zem_Model();
		$element = $zemModel->getElement($extensionName);
		
		if ($element instanceof Zem_Element) {
			$zemModel->unloadExtension($element);
			return $element->awaitsRestart();
		}
		
		$phpExtensionModel = new PhpExtensions_Model();
		$element = $phpExtensionModel->getElement($extensionName);
		
		if ($element instanceof PhpExtensions_Element) {
			$phpExtensionModel->unloadExtension($element);
			return $element->awaitsRestart();
		}
		
		throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Could not find an extension named %s'), $extensionName));
	}

	/**
	 * @param string $extensionName
	 * @return Extensions_ElementAbstract
	 */
	public function getElement($extensionName) {
		$zemModel = new Zem_Model();
		$element = $zemModel->getElement($extensionName);
		
		if ($element instanceof Zem_Element) {
			return $element;
		}
		
		$phpExtensionModel = new PhpExtensions_Model();
		$element = $phpExtensionModel->getElement($extensionName);
		
		if ($element instanceof PhpExtensions_Element) {
			return $element;
		}
		
		throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Could not find an extension named %s'), $extensionName));
	}
	
	/**
	 * Get the ini file where the extensions is defined
	 * Cascade from an extension's defined ini file, to an ini file with the same name as the extension,
	 * to the fallback of php.ini
	 *
	 * @param Extensions_ElementAbstract $extensionElement
	 * @return string
	 */
	public function getExtensionIniFile(Extensions_ElementAbstract $extensionElement) {
		$iniFile = $extensionElement->getIniFile();
		
		if (empty($iniFile)) {
			$phpMemory = Context_Api::getPhpMemory();
			
			$extensionName = $extensionElement->getName();
			
			// check if there is a file with the same name as the extension
			foreach($phpMemory->getIniScannedFiles() as $iniEntryFile) {
				if (false !== strpos(strtolower($iniEntryFile), strtolower($extensionName))) {
					$iniFile = $iniEntryFile;
					break;
				}
			}
			// fallback to default php.ini
			if (empty($iniFile)) {
				$iniFile = $phpMemory->getPhpIniFileLocation();
			}
		}
		return $iniFile;
	}
	
}