<?php

abstract class PhpExtensions_Parser {
	
	/**
	 * Retrive array with loaded extensions name (in the array key)
	 * 
	 * @param PhpMemory_Interface $memory
	 * @return array - format: array('extname' => 0..n)
	 */
	public function getLoadedExtensions() {
		return array_flip(Context_Api::getPhpMemory()->getLoadedExtensions());
	}

	/**
	 * Retrieve array with extensions files exist in the extension dir (in the array key).
	 * (with the postfix/prefix, e.g. name.so/php_name.dll)
	 * 
	 * @param string $dir
	 * @return array - format: array('ext-filename.so' => null)
	 */
	public function getDirectoryExtensions($dir) {
		$files 	= array();
		
		try {
			$directory = Context_FileSystem::getDirectoryObject($dir);
			foreach ($directory->getGlob($this->getExtensionFilePattern()) as $filename) {
				$files[ basename($filename) ] = null;
			}
		} catch (Zwas_Exception $e) {
			// do nothing
		}
		return $files;
	}
	
	/**
	 * Retrieve array with extensions data in ini files.
	 * 
	 * @param Configuration_IniFilesScanner $dir
	 * @return array - format: array('ext-filename.so' => 'ini-filename')
	 */
	public function getIniExtensions(Configuration_IniFilesScanner $ini) {
		$list = array();
		
		$extensionsIniFiles = $ini->getExtensions();
		
		if (is_array($extensionsIniFiles)) {
			foreach ($extensionsIniFiles as $iniFile => $iniData) {
				if (is_array($iniData)) {
					foreach ($iniData as $filename => $enable) {
						$list[ basename($filename) ] = $iniFile;
					}
				}
			}
		}
		return $list;
	}
	
	
	/**
	 * convert filename and path to basename without extension.
	 * (/path/to/extension/ext.so => ext)
	 *
	 * @param string $filename
	 * @return string
	 */
	abstract public function getExtensionNameFromFileName($filename);
	
	/**
	 * Should return the filename pattern for your machine
	 * (*.so, php_*.dll, ...)
	 * @return string
	 */
	abstract protected function getExtensionFilePattern();
}