<?php

class PhpMemory_UserServer implements PhpMemory_Interface {
	
	/**
	 * @param string $name
	 * @return string
	 */
	public function iniGet($name) {
		return ini_get($name);
	}
	
	/**
	 * @param string $name
	 * @return string
	 */
	public function getCfgVar($name) {
		if (function_exists('zend_get_cfg_var')) {
			return zend_get_cfg_var($name);
		}
		return get_cfg_var($name);
	}
	
	/**
	 * @param array|struct $names
	 * @return array|struct
	 */
	public function getCfgVars(array $names) {
		$returnList = array();
		foreach ($names as $name) {
			$returnList[$name] = $this->getCfgVar($name);
		}
		return $returnList;
	}
	
	/**
	 * @return array
	 */
	public function getLoadedExtensions() {
		return get_loaded_extensions();
	}
	
	/**
	 * Get an array with all the available ini files scanned by php, starting with the php.ini
	 * elements are numeric key => full ini file path value
	 * @return array
	 */
	public function getIniScannedFiles() {
		$list = array($this->getPhpIniFileLocation());
		
		$phpScannedFiles = php_ini_scanned_files();
		if (strlen($phpScannedFiles) != 0) {
			$phpScannedFiles = str_replace(array("\n", "\r"), '', $phpScannedFiles);
			$list = array_merge($list, explode(",", $phpScannedFiles));
		}

		$zendIniScanDirFiles = $this->getZendIniScandirFiles();
		foreach ($zendIniScanDirFiles as $file) {
			if (! in_array($file, $list)) {
				$list[] = $file;
			}
		}
		
		return array_map('trim', $list);
	}
	
	/**
	 * @return string
	 */
	public function getPhpIniFileLocation() {
		return trim(get_cfg_var('cfg_file_path'));
	}

	/**
	 * @return string
	 */
	public function getZendIniScandir() {
		$zendIniScandir = trim($this->getCfgVar('zend.ini_scandir'));
		$zendConfDir = trim($this->getCfgVar('zend.conf_dir'));
		
		if ($zendIniScandir && $zendConfDir) {
			return Zwas_Path::create($zendConfDir, $zendIniScandir);
	}
		return false;
	}
	
	/**
	 * Return the directory where the extensions' ini files are (compilation --with-config-file-scan-dir)
	 * @return string
	 */
	public function getIniScannedDirectory() {
		$list = php_ini_scanned_files();
		$item = trim(substr($list, 0, strpos($list, ',', 0)));
		return dirname($item);
	}
	
	/**
	 * Get all ini directives values from the memory
	 * 
	 * @return array
	 */
	public function iniGetAll() {
		return ini_get_all();
	}
	
	/**
	 * Wrapper to phpinfo();
	 * @return string
	 */
	public function getPhpInfo() {
		ob_start();
		phpinfo();
		return ob_get_clean();
	}
	
	/**
	 * Get all ini files in the zend.conf_dir
	 * Note it will filter out any file in that folder which doesn't end with .ini
	 * @return array
	 */
	private function getZendIniScandirFiles() {
		$zendIniScanDirFiles = array();
		
		try {
			$iterator = new RegexIterator(
								new DirectoryIterator($this->getZendIniScandir()),
								'#\.ini$#'
							);
	
			foreach ($iterator as $file) { /* @var $file SplFileInfo */
				$zendIniScanDirFiles[] = $file->getPathname();
			}
		} catch (Exception $e) {
			Zwas_Log::logException($e);
		}
		
		return $zendIniScanDirFiles;
	}
	
	/**
	 * @param string $name
	 * @param string $value
	 * @return string the old value on success, false on failure.
	 */
	public function iniSet($name, $value) {
		return ini_set($name, $value);
	}

	
}