<?php
require_once 'Zend/Controller/Plugin/Abstract.php';
require_once 'Zend/Controller/Front.php';
require_once 'Zend/Controller/Request/Abstract.php';
require_once 'Zend/Controller/Action/HelperBroker.php';
require_once 'Zend/Loader/Autoloader.php';

class Plugins_Initializer_CE extends Zend_Controller_Plugin_Abstract {
	
	/**
	 * @var Zend_Controller_Front
	 */
	protected $front;
	
	/**
	 * @param  string $applicationRoot
	 * @return void
	 */
	public function __construct() {
		try {
			Zend_Loader_Autoloader::getInstance()->setFallbackAutoloader(true);
			
			$this->front = Zend_Controller_Front::getInstance();
			
			$this->initConstants();
			$this->initApplicationAutoloaders();
			$this->initPhpConfig();
			$this->initApplication();
			$this->initApplicationName();
			
		} catch (Zwas_Exception $e) {
			$this->handleException('Zend Server Exception Caught:', (string)$e->getMessageObject(), $e->getTraceAsString());
			
		} catch (Zend_Exception $e) {
			$this->handleException('Zend Exception Caught:', $e->getMessage(), $e->getTraceAsString());
			
		} catch (Exception $e) {
			$this->handleException('PHP Exception Caught:', $e->getMessage(), $e->getTraceAsString());
		}
	}
	
	protected function initConstants() {
		// Application paths
		define('ZEND_SERVER_DATA_PATH',					ZEND_SERVER_APP_PATH . '/data');
		define('ZEND_SERVER_APP_CE_PATH',				ZEND_SERVER_APP_PATH . '/CE');
		define('ZEND_SERVER_USER_CONFIGURATION_FILE',	ZEND_SERVER_APP_PATH . '/data/zend-server-user.ini');
		define('ZEND_SERVER_CONFIGURATION_FILE',		ZEND_SERVER_APP_PATH . '/data/zend-server.ini');
		define('ZEND_SERVER_INSTALL_PATH',				$this->getInstallPath());
		define('ZEND_SERVER_TEMP_PATH',					ApplicationModel::getGuiTempDir());
	}
	
	protected function initApplicationAutoloaders() {
		$autoloader = new Zend_Loader_Autoloader_Resource(array(
			'namespace'	=> '',
			'basePath'	=> ZEND_SERVER_APP_PATH,
		));
		$autoloader->setResourceTypes(array(
			'forms' => array('namespace' => 'Form', 'path' => 'CE/forms'),
		));
	}
	
	protected function initApplicationName(){
	    define('ZEND_SERVER_APPLICATION_NAME',  Zwas_Translate::_('Zend Server Community Edition'));
	}
	
	protected function initPhpConfig() {
		// Ugly hack for setting the timezone and avoiding E_STRICTs
		date_default_timezone_set( @date_default_timezone_get());
		
		ini_set('display_errors', 'off');
		ini_set('zend.ze1_compatibility_mode', false);
		set_time_limit(60); // bug 25748 partial workaround
	}
	
	// TODO: can we enter this method into routeStatup?
	protected function initApplication() {
		// Initialize the Zwas_Log
		Zwas_Log::setLoggerWriter(ApplicationModel::getErrorLoggerStream());
		
		// TODO: try-catch this in order to better help the user with info
		Zend_Session::start(array(	'name'				=> 'ZENDSERVERSESSID',
									'save_path'			=> ZEND_SERVER_TEMP_PATH,
									'save_handler'		=> 'files',
									'gc_maxlifetime'	=> 20*60,
									'cookie_path'		=> $this->getCookiePath()));
		
		/**
		 * Disable Zend Framework locale cache
		 * Bug in PHP 5.3/Windows, function: is_writable() return flase on writable directory
		 */
		Zend_Locale::disableCache(true);
		/**
		 * In order to use date() style formatting also in Zend_Date
		 */
		Zend_Date::setOptions(array('format_type' => 'php'));

		// Load application configuration
		ApplicationModel::loadConfiguration();
		
		// setting the log verbosity level can only happen after the configuration has been loaded
		Zwas_Log::setLogVerbosityLevel(ApplicationModel::getLogVerbosityLevel());
		
		// Set dedicated server or not mode
		if (ApplicationModel::isRunningAsDedicatedServer()) {
			Context_Api::setInstance(new Context_Api_FactoryZwasServer());
		}
	}
	
	/**
	 * Route startup
	 * @param Zend_Controller_Request_Abstract $request
	 * @return void
	 */
	public function routeStartup(Zend_Controller_Request_Abstract $request) {
		$this->verifyZendServerBasePath($request->getRequestUri());
		try {
			$this->initDb();
			$this->initHelpers();
			$this->initView($request);
			$this->initRoutes();
			$this->initControllers();
			
		} catch (Zwas_Exception $e) {
			$this->handleException('Zend Server Exception Caught:', (string)$e->getMessageObject(), $e->getTraceAsString());
			
		} catch (Zend_Exception $e) {
			$this->handleException('Zend Exception Caught:', $e->getMessage(), $e->getTraceAsString());
			
		} catch (Exception $e) {
			$this->handleException('PHP Exception Caught:', $e->getMessage(), $e->getTraceAsString());
		}
	}
	
	/**
	 * Initialize data bases
	 *
	 * @return void
	 */
	public function initDb() {
		Context_Db_DefaultAdapter::init();
	}
	
	/**
     * Initialize action helpers
     *
     * @return void
     */
	public function initHelpers() {
		
	}
	
	/**
	 * Initialize view
	 * @param Zend_Controller_Request_Abstract $request
	 * @return void
	 */
	public function initView(Zend_Controller_Request_Abstract $request) {
		// Bootstrap layouts
		$layoutConfig = array(	'layoutPath'	=> ZEND_SERVER_APP_PATH . '/layouts',
								'layout'		=> 'main');
		$view	= Zend_Layout::startMvc($layoutConfig)->getView();
		
		$view->doctype(Zend_View_Helper_Doctype::XHTML1_TRANSITIONAL);
		
		// register view scripts path
		$view->setScriptPath(ZEND_SERVER_APP_CE_PATH . '/views/scripts');
		$view->addHelperPath(ZEND_SERVER_APP_CE_PATH . '/views/helpers/Navigation',	'Zwas_View_Helper_Navigation');		
		
		// register view helpers path
		$view->addHelperPath(ZEND_SERVER_APP_CE_PATH . '/views/helpers', 'Zwas_View_Helper');
	}
	
	
	/**
	 * Initialize routes
	 *
	 * @return void
	 */
	public function initRoutes() {
		/**
		 * Fix routing problem in 2 cases:
		 * 1. When mod rewrite is not working, discover it's working or not using a configuration variable (configuration->zwas->rewriteEnabled)
		 * 	Add a registry variable (zenith_rewrite_enabled) to flag that mod rewrite is disabled
		 * 	All places where URL are being build (i.e. Zend_View_Helper_Url) should consider it and tweak the URLs
		 *
		 * 2. Handle none "pretty" urls to route the request
		 * 	If the request has explicit controller, change the original request URL to be in the form of a pretty URL so routing will handle it properly
		 * 	i.e. if the request was http://localhost/index.php?controller=ctrl&action=actn&param1=value1
		 * 		change it to http://localhost/index.php/ctrl/actn/param1/value1
		 */
		try {
			$rewriteEnabled = ApplicationModel::getIsRewriteEnabled();
		} catch (Zwas_Exception $e) {
			// Ignore exception, default value is rewrite enabled
			$rewriteEnabled = true;
		}
		
		if (!$rewriteEnabled) {
			$this->front->setRouter(new Zwas_Controller_Router_DisabledRewrite());
		}
		
		
		$request = new Zend_Controller_Request_Http();
		
		if ($request->getControllerName() != null) {

			$params = $_GET; // Control only the GET params, not all params
			
			unset($params[$request->getControllerKey()]);
			unset($params[$request->getActionKey()]);
			
			$newPathInfo = ($rewriteEnabled) ? '/' : '?/';
			$newPathInfo .= $request->getControllerName() . '/' . $request->getActionName();
			
			if (! empty($params)) {
				// "http_build_query" convert an array of params to url encoded query string
				// e.g.: foo=bar&boo=gar&too=dar ...
				// the Zend Framework rewrite structure is different, so we convert the "&" and the "=" to "/"
				// so the result is: foo/bar/boo/gar/too/dar ...
				$newPathInfo .= '/' . str_replace('=', '/', http_build_query($params, null, '/'));
			}
			$newRequestUri = $request->getBaseUrl() . $newPathInfo;
			
			$request->setRequestUri($newRequestUri);
			
			$this->front->setRequest($request);
		}
	}
	
	/**
	 * Initialize Controller paths
	 *
	 * @return void
	 */
	public function initControllers() {
		$this->front->setControllerDirectory(array(
			'CE' => ZEND_SERVER_APP_PATH . '/CE/controllers'
		));
		$this->front->setDefaultModule('CE');
	}
	
	/**
	 * @return string
	 */
	protected function getInstallPath() {
		return dirname( ZEND_SERVER_GUI_PATH );
	}
	
	/**
	 * @return string
	 */
	protected function getCookiePath() {
		return '/ZendServer';
	}
	
	protected function handleException($title, $msg, $trace) {
		echo '<h1>An unexpected error has occurred</h1>';
		try {
			if (class_exists('Zwas_Log', true)) {
				Zwas_Log::logMessage($title . PHP_EOL . $msg . PHP_EOL . $trace);
			}
			
		} catch (Exception $e) {
			@error_log("{$title}:{$msg}", E_ERROR);
		}
		die;
	}
	
	/**
	 * checks if the user used another casing for ZendServer path (can occur only on IIS), 
	 * and if so - redirects to the correct casing. otherwise, cookies are set wrongly
	 * @param string $requestUri
	 */
	private function verifyZendServerBasePath($requestUri) {
		$cookiePath = $this->getCookiePath();
		// Note that one strpos is case-insensitive, the other is sensitive - to catch any possibility other than the exace notation 
		if ((false === strpos($requestUri, $cookiePath)) && (false !== stripos($requestUri, $cookiePath))) {
			header('location: ' . $cookiePath);
			exit;
		}
	}
}
