<?php

class Systray_Executer extends Systray_Abstract {
	
	const COMPONENT_OFF				= 'OFF';
	const COMPONENT_ERROR			= 'ERROR';
	const COMPONENT_ON				= 'ON';
	const COMPONENT_NOT_INSTALLED	= 'NOT_INSTALLED';
	
	/**
	 * Execute an action and return Systray response object.
	 * 
	 * @param string $action
	 * @return Systray_Response
	 */
	public function run($action) {
		
		if (!method_exists($this, $action)) {
			return $this->raiseError($action, Zwas_Translate::_('Invalid action'));
		}
		
		try {
			$this->$action();
			$this->response->setAction($action, self::STATUS_SUCCESS);
			$this->addPongData();
			
		} catch (Exception $e) {
			$this->raiseError($action, $e->getMessage());
		}
		
		$this->response->setNeedRestart( Context_Api::getUtilAPI()->isConfigurationChanged() );
		return $this->response;
	}
	
	private function addPongData() {
		$this->addAcceleratorPong();
		$this->addCachePong();
		$this->addDebuggerPong();
		$this->addJavaBridgePong();
	}
	
	/**
	 * ACTIONS:
	 * 
	 * Action function do not return value.
	 * For any kind of error message, throw an exception with a message. 
	 */
	
	private function enableDebugger() {
		$deb = new ZwasComponents_Debugger_Model();
		$deb->activateComponent();
	}
	
	private function disableDebugger() {
		$deb = new ZwasComponents_Debugger_Model();
		$deb->deactivateComponent();
	}
	
	private function enableAccelerator() {
		$acc = new ZwasComponents_Accelerator_Model();
		$acc->activateComponent();
	}
	
	private function disableAccelerator() {
		$acc = new ZwasComponents_Accelerator_Model();
		$acc->deactivateComponent();
	}
	
	private function enableCache() {
		$cache = new ZwasComponents_DataCache_Model();
		$cache->activateComponent();
	}
	
	private function disableCache() {
		$cache = new ZwasComponents_DataCache_Model();
		$cache->deactivateComponent();
	}
	
	private function enableJavaBridge() {
		$jb = new ZwasComponents_JavaBridge_Model();
		$jb->activateComponent();
	}
	
	private function disableJavaBridge() {
		$jb = new ZwasComponents_JavaBridge_Model();
		$jb->deactivateComponent();
	}
	
	private function restartServer() {
		if (! Context_Api::getUtilAPI()->restartPhp()) {
			throw new Zwas_Exception(Zwas_Translate::_('Error restarting the PHP.'));
		}
	}

	private function ping() {
		// dummy action to enable the systray to get a pong without doing a function
	}
	
	/** END OF ACTIONS **/

	/** PING METHODS **/
	
	private function addAcceleratorPong() {
		try {
			$this->addZendServerComponentPong(new ZwasComponents_Accelerator_Model());
		} catch (Exception $e) {
		}
	}
	
	private function addCachePong() {
		try {
			$this->addZendServerComponentPong(new ZwasComponents_DataCache_Model());
		} catch (Exception $e) {
			
		}
	}
	
	private function addDebuggerPong() {
		try {
			$this->addZendServerComponentPong(new ZwasComponents_Debugger_Model());
		} catch (Exception $e) {
			
		}
	}

	private function addJavaBridgePong() {
		try {
			$this->addZendServerComponentPong(new ZwasComponents_JavaBridge_Model());
		} catch (Exception $e) {
				
		}
	}
	
	private function addZendServerComponentPong(ZwasComponents_Abstract $component) {
		$msg = '';
		
		if (! $component->isInstalled()) {
			$status = self::COMPONENT_NOT_INSTALLED;
		} elseif ($component->isLoadedWithError()) {
			$status = self::COMPONENT_ERROR;
			$msg = $component->getLoadedErrorString();
		} elseif ($component->isActivated()) {
			$status = self::COMPONENT_ON;
		} else {
			$status = self::COMPONENT_OFF;
		}
		
		$this->response->addComponent($component->getZemElement()->getName(), $status, $msg);
	}
}