<?php

class Systray_Service extends Systray_Abstract {
	
	/**
	 * Execute an action and return Systray response object.
	 *
	 * @param string $action
	 * @return Systray_Response
	 */
	public function run($action) {
		
		if (!method_exists($this, $action)) {
			return $this->raiseError($action, Zwas_Translate::_('Invalid action'));
		}
		
		try {
			$this->$action();
			$this->response->setAction($action, self::STATUS_SUCCESS);
			
		} catch (Exception $e) {
			$this->raiseError($action, $e->getMessage());
		}
		
		return $this->response;
	}
	
	/**
	 * Set the response object to return failure message.
	 *
	 * @param string $action
	 * @param string $message
	 * @return Systray_Response
	 */
	public function raiseError($action, $message) {
		$this->response->setAction($action, self::STATUS_FAIL, $message);
		return $this->response;
	}
	
	/**
	 * Set an authentication token in the response
	 */
	private function getToken() {
		$this->response->setAuthenticationToken(Authentication_Token::generateAuthenticationToken());
	}
	
}