<?php

abstract class TableCachedBase extends Zend_Db_Table_Abstract {
	/**
     * @param  array  $data  Column-value pairs.
     * @return mixed         The primary key of the row inserted.
     */	
	public function insert(array $data) {
		$insertedRowKey = parent::insert($data);
		if ($insertedRowKey) {
			Context_Db::getCacheTimestamps()->updateTableTimestamp($this->_name);
		}
		return $insertedRowKey;
	}

	/**
     * @param  array        $data  Column-value pairs.
     * @param  array|string $where An SQL WHERE clause, or an array of SQL WHERE clauses.
     * @return int          The number of rows updated.
	 */
	public function update(array $data, $where) {
		$changedRows = parent::update($data, $where);
		if ($changedRows) {
			Context_Db::getCacheTimestamps()->updateTableTimestamp($this->_name);
		}
		return $changedRows;
	}
	
	/**
	 * @return integer
	 */
	public function getLastChangeTimestamp() {
		return Context_Db::getCacheTimestamps()->getLastChangeTimestamp($this->_name);
	}

	/**
	 * Remove the table's timestamp from the database
	 * @return integer
	 */
	public function resetTimestamp() {
		return Context_Db::getCacheTimestamps()->removeTableTimestamp($this->_name);
	}

	/**
	 * Reset all 'awaitsRestart' flags in the cache table.  If any row was changed
	 * there's also a need to regenerate the cache table, so set its timestamp to 0
	 */	
	public function resetCacheTableStatusAfterRestart() {
		if ($this->resetAllWaitingRestart()) {
			$this->resetTimestamp();
		}		
	}
	
	/**
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function fetchAllWaitingRestart() {
		return $this->fetchAll($this->getAdapter()->quoteInto('awaitsRestart = ?', true));
	}
	
	/**
	 * Update a line in the DB without updating the relevant cacheTimestamps table row
	 * Should be used only in very special cases
	 * 
     * @param  array        $data  Column-value pairs.
     * @param  array|string $where An SQL WHERE clause, or an array of SQL WHERE clauses.
     * @return int          The number of rows updated.
	 */	
	protected function updateWithoutCacheTimestamping(array $data, $where) {
		return parent::update($data, $where);
	}
	
	/**
	 * Reset all rows which are marked as 'awaiting restart'
	 * @return integer number of updated rows
	 */
	private function resetAllWaitingRestart() {
		return $this->update(array('awaitsRestart' => false), 'awaitsRestart = 1');
	}
}