<?php

class Zem_Element extends Extensions_ElementAbstract {
	
	/**
	 * The zem identifier
	 * e.g. zend_extension_manager.zend_cache --> zend_cache
	 * @var string
	 */
	protected $identifier = '';
	
	/**
	 * Error string in case of error.
	 * @var string
	 */
	protected $errorString = '';
	
	/**
	 * The subfolder where the extension is
	 * e.g. /usr/local/zend/lib/accelerator --> accelerator
	 * @var string
	 */
	private $folder;
	
	/**
	 * The product's version
	 * @var string
	 */
	private $version = '';
	
	/**
	 * @var boolean
	 */
	private $installed = false;
	
	/**
	 * @param string $name - e.g. 'Zend Accelerator'
	 * @param string $identifier - e.g. if the directive is zend_extension_manager.accelerator = xxx then this is 'accelerator'
	 * @param string $folder - e.g. if the directive is zend_extension_manager.accelerator = /usr/local/zend/lib/acceleratorPath then this is 'acceleratorPath'
	 */
	public function __construct($name, $identifier, $folder) {
		$this->extensionName	= (string)$name;
		$this->identifier		= (string)$identifier;
		$this->folder			= (string)$folder;
		
	}
	
	/**
	 * Create a Zem_Element based on the details from the DB cache!! table
	 *
	 * @param array $dbDetails
	 * @return Zem_Element
	 */
	public static function getElementFromDbDetails(array $dbDetails) {
		$element = new Zem_Element($dbDetails['name'], $dbDetails['identifier'], $dbDetails['folder']);
		$element->setFileExists($dbDetails['folderExists']);
		$element->setInstalled($dbDetails['installed']);
		$element->setIniFile($dbDetails['iniFile']);
		$element->setLoaded($dbDetails['loaded']);
		$element->setVersion($dbDetails['version']);
		$element->setIniStatus($dbDetails['iniStatus']);
		$element->setNumberOfAssociactedDirectives($dbDetails['numOfDirectives']);
		$element->setAwaitsRestart($dbDetails['awaitsRestart']);
		$element->setShortDescription($dbDetails['shortDescription']);
		$element->setErrorString($dbDetails['errorString']);
		return $element;
	}
	
	public function hasFilename() {
		return (! empty($this->folder));
	}
	
	/**
	 * @return string
	 */
	public function getIdentifier() {
		return $this->identifier;
	}

	/**
	 * @return string
	 */
	public function getFolder() {
		return $this->folder;
	}
	
	/**
	 * @return string
	 */
	public function getVersion() {
		return (string)$this->version;
	}
	
	/**
	 * @return string
	 */
	public function getErrorString() {
		return $this->errorString;
	}
	
	/**
	 * @return boolean
	 */
	public function isInstalled() {
		return (boolean)$this->installed;
	}
	
	/**
	 * @param string $identifier
	 */
	public function setIdentifier($identifier) {
		$this->identifier = (string)$identifier;
	}
	
	/**
	 * @param string $folder
	 */
	public function setFolder($folder) {
		$this->folder = (string)$folder;
	}

	/**
	 * @param string $version
	 */
	public function setVersion($version) {
		$this->version = (string)$version;
	}
	
	/**
	 * @param string $errorString
	 */
	public function setErrorString($errorString) {
		$this->errorString = (string)$errorString;
	}

	/**
	 * @param $value boolean
	 */
	public function setInstalled($value) {
		return $this->installed = (boolean)$value;
	}

	public function toArray() {
		return get_object_vars($this);
	}
}
