<?php

class ZwasComponents_DataCache_Model extends ZwasComponents_Enableable {

	/**
	 * @var string
	 */
	protected $directiveEnable = 'zend_datacache.enable';
	
	/**
	 * @return string
	 */
	public function getExtensionName() {
		return 'Zend Data Cache';
	}

	/**
	 * Deactivate the component - make sure it is not enabled
	 * 
	 * Overwrite the ZwasComponents_Enableable::deactivateComponent:
	 * Note that it should not unload the extension, as the user may have
	 *   data_cache api functions in his code, so if the extension is loaded
	 *   it should stay like that
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure  
	 */
	public function deactivateComponent() {
		if ($this->isLoadedInFile() && $this->isEnabledInFile()) {
			if (! $this->disable()) {
				throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('The component %s was partially turned off.  Retry your last action and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'), array($this->getExtensionName())), Zwas_Exception::ERROR);
			}
			return true;
		}
		return false;
	}
	
	/**
	 * Note that it should not unload the extension, as the user may have
	 *   data_cache api functions in his code, so if the extension is loaded
	 *   it should stay like that 
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure  
	 */
	public function forceDeactivateComponent() {
		try {
			return (boolean)$this->disable();
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException('Failed disabling ' . $this->getExtensionName(), $e);
			throw new Zwas_Exception(new Zwas_Text('Could not turn off the \'%s\' component', array($this->getExtensionName())));
		}
	}
		
	/**
	 * @return boolean
	 */
	public function clear() {
		return Context_Api::getCacheAPI()->clear();
	}
	
	/**
	 * Return the controller associated with this component
	 * @return string
	 */
	protected function getController() {
		return 'Data-Cache';
	}
	
	/**
	* Returns an array with appropriate actions inside
	*
	* @param string $targetController
	* @param string $targetAction
	* @return array
	*/
	protected function getDisplayActionContainer($targetController = null, $targetAction = null) {
		$actions = array();
		
		if ((! $this->isLoadedWithError()) && $this->isLoadedInMemory() && $this->isEnabledInMemory()) {
			$clean = new DisplayWidget_Link(Zwas_Translate::_('Clear'), 'Data-Cache', 'Clear', $targetController, $targetAction);
			$actions[] = $clean;
		}
		
		return $actions;
	}

	/**
	 * Service function for reusing this code
	 * @return DisplayWidget_Abstract
	 */
	protected function getErrorLink() {
		return new DisplayWidget_Info('');
	}	
}