<?php

/**
 * 	TODO: To merge: ($extensionAction + $actionContainer) and ($configurationLink + $configureContainer)
 */
class ZwasComponents_Display {
	
	/**
	 * @var string
	 */
	private $name;
	/**
	 * @var string
	 */
	private $version;
	/**
	 * @var integer
	 */
	private $componentStatus;
	/**
	 * @var string
	 */
	private $errorString = '';
	/**
	 * @var DisplayWidget_IconTooltip
	 */
	private $statusIcon;
	/**
	 * @var string
	 */
	private $statusLabel;
	/**
	 * @var array
	 */
	private $actionContainer;
	/**
	 * The action relevant to the component's extension (load / unload)
	 * @var DisplayWidget_ExtensionActionLink | DisplayWidget_Info $action
	 */
	private $extensionAction;
	/**
	 * @var DisplayWidget_Info
	 */
	private $message;
	/**
	 * @var DisplayWidget_Abstract
	 */
	private $configurationLink;
	/**
	 * @var array
	 */
	private $configureContainer;
	/**
	 * @var DisplayWidget_Info
	 */
	private $shortDescription;
	
	/**
	 * @return array
	 */
	public function getActions() {
		return $this->actionContainer;
	}
	
	/**
	 * @param integer $status
	 * @return Zwas_Text
	 * @throws Zwas_Exception
	 */
	public function getStatusText($status) {
		switch ($status) {
			case ZwasComponents_Abstract::STATUS_NOT_INSTALLED:
				return new Zwas_Text(Zwas_Translate::_('Not installed'));
			case ZwasComponents_Abstract::STATUS_OK:
				return new Zwas_Text(Zwas_Translate::_('On'));
			case ZwasComponents_Abstract::STATUS_NOT_ENABLED:
			case ZwasComponents_Abstract::STATUS_NOT_LOADED:
			case ZwasComponents_Abstract::STATUS_NOT_RUNNING:
				return new Zwas_Text(Zwas_Translate::_('Off'));
			case ZwasComponents_Abstract::STATUS_ERROR:
				return new Zwas_Text(Zwas_Translate::_('Error: %s'), array($this->errorString));
			default:
				throw new Zwas_Exception(Zwas_Translate::_('Undefined status of component'), Zwas_Exception::ASSERT);
		}
	}
		
	/**
	 * @return Zwas_Text
	 */
	public function getStatusLabel() {
		return $this->getStatusText($this->componentStatus);
	}
	
	/**
	 * @return DisplayWidget_IconTooltip
	 */
	public function getStatusIcon() {
		switch ($this->componentStatus) {
			case ZwasComponents_Abstract::STATUS_NOT_INSTALLED:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_GREY,
														$this->getStatusLabel($this->componentStatus));
				break;
			case ZwasComponents_Abstract::STATUS_OK:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_GREEN,
														$this->getStatusText($this->componentStatus));
				break;
			case ZwasComponents_Abstract::STATUS_ERROR:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_RED,
														$this->errorString);
				break;
			case ZwasComponents_Abstract::STATUS_NOT_ENABLED:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_GREY,
														$this->getStatusText($this->componentStatus));
				break;
			case ZwasComponents_Abstract::STATUS_NOT_LOADED:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_GREY,
														$this->getStatusText($this->componentStatus));
				break;
			case ZwasComponents_Abstract::STATUS_NOT_RUNNING:
				return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_LED_RED,
														$this->getStatusText($this->componentStatus));
				break;
		}
		return new DisplayWidget_IconTooltip(DisplayWidget_IconTooltip::ICON_NULL);
	}
	
	/**
	 * @return integer
	 */
	public function getStatus() {
		return (int)$this->componentStatus;
	}
	
	/**
	 * @return string
	 */
	public function getName() {
		return $this->name;
	}
	
	/**
	 * @return string
	 */
	public function getVersion() {
		return $this->version;
	}
	
	/**
	 * @return DisplayWidget_ExtensionActionLink | DisplayWidget_Info $action
	 */
	public function getExtensionAction() {
		return $this->extensionAction;
	}
	
	/**
	 * @return DisplayWidget_Info
	 */
	public function getMessage() {
		return $this->message;
	}
	
	/**
	 * @return array
	 */
	public function getConfigureContainer() {
		return $this->configureContainer;
	}
	
	/**
	 * @return DisplayWidget_Abstract
	 */
	public function getConfigurationLink() {
		return $this->configurationLink;
	}
	
	/**
	 * @return string
	 */
	public function getErrorString() {
		// TODO: probably this function can be removed - not used?
		return (string)$this->errorString;
	}
	
	/**
	 * @return DisplayWidget_IconTooltip
	 */
	public function getShortDescription() {
		if (! empty($this->shortDescription)) {
			return new DisplayWidget_IconTooltip(	DisplayWidget_IconTooltip::ICON_INFO,
													$this->shortDescription);
		}
		return new DisplayWidget_IconTooltip(DisplayWidget_IconTooltip::ICON_NULL);
	}
	
	/**
	 * @param integer $status
	 */
	public function setStatus($status) {
		$this->componentStatus = $status;
	}
	
	/**
	 * @param string $name
	 */
	public function setName($name) {
		$this->name = $name;
	}

	/**
	 * @param string $version
	 */
	public function setVersion($version) {
		$this->version = $version;
	}

	/**
	 * @param array $actionContainer
	 */
	public function setActionContainer(array $actionContainer) {
		$this->actionContainer = $actionContainer;
	}
	
	/**
	 * @param DisplayWidget_ExtensionActionLink | DisplayWidget_Info $action
	 */
	public function setExtensionAction(DisplayWidget_Abstract $action) {
		$this->extensionAction = $action;
	}

	/**
	 * @param DisplayWidget_Info $message
	 */
	public function setMessage(DisplayWidget_Info $message) {
		$this->message = $message;
	}

	public function setConfigureContainer(array $actionContainer) {
		$this->configureContainer = $actionContainer;
	}

	/**
	 * @param DisplayWidget_Abstract $configureLink
	 */
	public function setConfigurationLink(DisplayWidget_Abstract $configureLink) {
		$this->configurationLink = $configureLink;
	}
	
	/**
	 * @param string $string
	 */
	public function setErrorString($string) {
		$this->errorString = $string;
	}
	
	/**
	 * @param string $shortDescription
	 */
	public function setShortDescription($shortDescription) {
		$this->shortDescription = $shortDescription;
	}
}