<?php
interface ZwasComponents_Interface {
	
	const STATUS_NOT_INSTALLED	= 1;
	const STATUS_OK				= 2;
	const STATUS_NOT_ENABLED	= 3;	// applies only to some components
	const STATUS_NOT_RUNNING	= 4;	// applies only to some components
	const STATUS_NOT_LOADED		= 5;
	const STATUS_ERROR			= 6;
		
	/**
	 * Activate the component - make sure it is both loaded and enabled
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure
	 */
	public function activateComponent();

	/**
	 * Deactivate the component - only if it is active
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure
	 */
	public function deactivateComponent();
	
	/**
	 * Deactivate the component completely
	 * @return boolean does this action requires a server restart
	 * @throws Zwas_Exception on failure
	 */
	public function forceDeactivateComponent();
		
	/**
	 * @return boolean
	 */
	public function isInstalled();
	
	/**
	 * Returns whether the component's status is supposed to be on or off
	 * taking into consideration possible future restart action
	 *
	 * @return boolean
	 */
	public function isActivated();
}