<?php

class ZwasComponents_JavaBridge_Model extends ZwasComponents_Abstract {
	
	/**
	 * @return string
	 */
	public function getExtensionName() {
		return 'Zend Java Bridge';
	}
	
	/**
	 * Returns whether the component's status is supposed to be on or off
	 * taking into consideration possible future restart action
	 *
	 * @return boolean
	 */
	public function isActivated() {
		if ((! $this->isLoadedWithError()) && $this->isLoadedInFile() && (!$this->isLoadedInMemory() || $this->isRunning())) {
			return true;
		}
		
		return false;
	}
	
	/**
	 * Check if the JavaBridge daemon is running, only when in needs to run
	 * If the JavaBridge extension is not loaded, the daemon does not suppose to run and this function return true as well	 *

	 * @return boolean true if JavaBridge is loaded in memory and the daemon is running
	 */
	public function isRunning() {
		return Context_Api::getJavaBridgeAPI()->isServerRunning();
	}
	
	/**
	 * Overwrite the parent function to check if the JavaBridge server is not running
	 * @return integer
	 */
	protected function getStatusInMemory() {
		// Special case of JavaBridge: not running (loaded in memory but daemon is not running)
		if ((! $this->isLoadedWithError()) && $this->isLoadedInMemory() && !$this->isRunning()) {
			return ZwasComponents_Abstract::STATUS_NOT_RUNNING;
		}
		
		return parent::getStatusInMemory();
	}
	
	/**
	 * Overwrite the parent function to show an error action when JavaBridge server is not running
	 * @return DisplayWidget_ExtensionActionLink | DisplayWidget_Info
	 */
	protected function getComponentActionLink() {
		// Specail case of JavaBridge: Show error only when daemon is not running and component does not await restart
		if ((! $this->isLoadedWithError()) &&
			(! $this->awaitsRestart()) && $this->isLoadedInMemory() && ! $this->isRunning()) {
			return $this->getErrorLink();
		}
		return parent::getComponentActionLink();
	}
	
	/**
	 * @return DisplayWidget_Info
	 */
	protected function getComponentMessage() {
		if (! $this->isInstalled()) {
			return new DisplayWidget_Info(Zwas_Translate::_('This component is not installed, for instructions see the Installation Guide'));
		}
		
		if ($this->isLoadedWithError()) {
			return new DisplayWidget_ErrorInfo(new Zwas_Text(Zwas_Translate::_('Error message: %s'), array($this->zemElement->getErrorString())));
		}
		
		if ($this->awaitsRestart()) {
			if ($this->isLoadedInFile()) {
				return new DisplayWidget_Info(Zwas_Translate::_('This component\'s status will change to "On" after the PHP is restarted'));
			} else {
				return new DisplayWidget_Info(Zwas_Translate::_('This component\'s status will change to "Off" after the PHP is restarted'));
			}
		}
		
		if ($this->isLoadedInMemory() && ! $this->isRunning()) {
			return new DisplayWidget_ErrorInfo(Zwas_Translate::_('The Java Bridge\'s service is not running. See the online help\'s \'Package Setup and Control Scripts\' section to find out how to start the service'));
		}
		
		return new DisplayWidget_Info('');
	}
	
	/**
	 * Return the controller associated with this component
	 * @return string
	 */
	protected function getController() {
		return 'Java-Bridge';
	}
			
}
