<?php

class ZwasComponents_Model_CE implements ZwasComponents_Model_Interface {

	/**
	 * Return array of ZwasComponents objects
	 * TODO: (karnaf) check if we still need the try-catch blocks now that we display not installed components as well
	 * @return array
	 */
	public function getAvailableComponents() {
		$components = array();
		
		try {
			$components[] 	= new ZwasComponents_Accelerator_Model();
		} catch (ZwasComponents_Exception $e) {
			// Do nothing, logging is done when the exception is thrown
		}

		try {
			$components[]	= new ZwasComponents_DataCache_Model();
		} catch (ZwasComponents_Exception $e) {
			// Do nothing, logging is done when the exception is thrown
		}
		
		try {
			$components[]	= new ZwasComponents_Debugger_Model();
		} catch (ZwasComponents_Exception $e) {
			// Do nothing, logging is done when the exception is thrown
		}

		try {
			$components[]	= new ZwasComponents_Loader_Model();
		} catch (ZwasComponents_Exception $e) {
			// Do nothing, logging is done when the exception is thrown
		}
		
		try {
			$components[]	= new ZwasComponents_JavaBridge_Model();
		} catch (ZwasComponents_Exception $e) {
			// Do nothing, logging is done when the exception is thrown
		}
		
		return $components;
    }
    
    /**
     * Return array of ZwasComponents_Display objects
     * @param array $components
     * @return array ordered by extension name
     */
    public function convertToDisplayObjects(array $components) {
    	$displayObjects = array();
    	foreach ($components as $component) { /* @var $component ZwasComponents_Abstract */
    		try {
    			$displayObject = ZwasComponents_Abstract::getZwasComponentDisplayObject($component);
    			$displayObjects[ $displayObject->getName() ] = $displayObject;
    		} catch (Zwas_Exception $e) {
    			// TODO-g: we should not ignore exceptions, (should be investigate), i guess most of the exceptions should make the component in error mode
    			Zwas_Log::logException('Error in display of '. $component->getExtensionName() . ': ', $e);
				// ignore failed component
    		}
    	}
    	ksort($displayObjects);
    	return $displayObjects;
    }
    
}