<?php

class ZwasComponents_Util_Api_UserServer implements ZwasComponents_Util_Api_Interface {
	/**
	 * @return array
	 */
	public function getExtensionsInfo() {
		if (function_exists('zem_get_extensions_info')) {
			$allInfo = zem_get_extensions_info();
			$licenseInfo = $this->getLicenseInfo();
			
			// If license is not ok - overwrite the license error message of the extension info for the necessary extensions
			if ((! empty($licenseInfo)) && (! $licenseInfo['license_ok'])) {
				
				if ($licenseInfo['signature_invalid']) {
					$errorMessage = Zwas_Translate::_('Invalid license key');
					
				} elseif ($licenseInfo['license_expired']) {
					$errorMessage = Zwas_Translate::_('The license has expired');
					
				} else {
					// Generic error message
					$errorMessage = Zwas_Translate::_('Internal license error. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center');
					
				}
				
				foreach ($allInfo as $extensionId => $extensionInfo) {
					if (! $extensionInfo['is_licensed']) {
						$allInfo[$extensionId]['licensed_error_message'] = $errorMessage;
					}
				}
			}
			return $allInfo;
		}
		
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zem_get_extensions_info');
	}
	
	/**
	 * @return array
	 */
	public function getLicenseInfo() {
		if (function_exists('zem_get_license_info')) {
			return zem_get_license_info();
		}
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zem_get_license_info');
	}
	
	/**
	 * @param string $key
	 * @param string $username
	 * @return array
	 */
	public function getSerialNumberInfo($key, $username) {
		if (function_exists('zem_serial_number_info')) {
			return zem_serial_number_info($key, $username);
		}
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zem_serial_number_info');
	}
	
	/**
	 * @return boolean
	 */
	public function isConfigurationChanged() {
		if (function_exists('zend_is_configuration_changed')) {
			return zend_is_configuration_changed();
		}
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zend_is_configuration_changed');
	}
	
	public function setConfigurationChanged() {
		if (function_exists('zend_set_configuration_changed')) {
			return zend_set_configuration_changed();
		}
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zend_set_configuration_changed');		
	}

	/**
	 * Restart the webserver's PHP
	 * @return boolean if the server was signaled for a restart.  Note: it can't tell if the restart went OK
	 */
	public function restartPhp() {
		if (function_exists('zend_restart_php')) {
			// the API function called waits for all PHP scripts to die, so there is a need to set the time limit to something big
			set_time_limit(self::RESTART_TIME_LIMIT);	
			return zend_restart_php();
		}
		UserServer::throwMissingApiFunctionError(__CLASS__, __FUNCTION__, 'zend_restart_php');
	}
	
}
