<?php

abstract class ZwasServer {

	/**
	 * @var Zwas_XmlRpc_CachedClient
	 */
	private static $xmlRpcClient = null;
	
	public function __construct() {
		// Creating the Zend_XmlRpc_Client only once.
		if (is_null(self::$xmlRpcClient)) {
			
			self::$xmlRpcClient = new Zwas_XmlRpc_CachedClient(ApplicationModel::getUserServerUrl());
			// For performance, do not call the system signature before each call
			self::$xmlRpcClient->setSkipSystemLookup(true);
			self::$xmlRpcClient->getHttpClient()->setConfig(array('timeout' => '30'));
		}
	}
	
	/**
	 * Invoke remote action.
	 *
	 * @param string $method - the name of the method to run.
	 * @param string $params - optional parameters for the method.
	 * @param boolean $getFromCache - whether or not to try and read from cached data
	 * @return mixed
	 */
	protected function remoteAction($method, $params = array(), $getFromCache = true) {
		try {
			$call = $this->getNameSpace() . '.' . $method;
			if ($getFromCache) {
				return self::$xmlRpcClient->cachedCall($call, $params);
			} else {
				return self::$xmlRpcClient->call($call, $params);
			}
			
		} catch (Zend_XmlRpc_Client_FaultException $exception) {
			// XmlRpc protocol was OK, error in what it ran
			Zwas_Log::logMessage("Calling $call returned: {$exception->getMessage()}", Zend_Log::ERR);
			
			// The fault response is due to a missing API function that was called
			if (Zwas_XmlRpc_Exception::MISSING_API_FUNCTION == $exception->getCode()) {
				throw new Zwas_Exception('Your Web server is missing a necessary extension.  If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center');
			}
			// Default fault exception
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('The following error was retrieved from the Web server: %s'), array($exception->getMessage())));
			
		} catch (Zend_Http_Client_Adapter_Exception $exception) {
			// server is down / wrong port
			Zwas_Log::logMessage('Failed to connect to \'' . self::$xmlRpcClient->getHttpClient()->getUri(true) . '\': ' . $exception->getMessage(), Zend_Log::ERR);
			
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Failed to access Web server.  Please make sure that the Web server is running and listening to the correct port')));
			
		} catch (Exception $exception) {
			Zwas_Log::logException('General error when trying to connect to \'' . self::$xmlRpcClient->getHttpClient()->getUri(true) . '\'', $exception);
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Failed to access Web server: %s'), array($exception->getMessage())));
		}
	}
	
	/**
	 * Return the class name to use.
	 *
	 * @return string
	 */
	abstract protected function getNameSpace();
}