<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_Directive extends Zend_View_Helper_Abstract {

	public function directive(Directives_DisplayData_Abstract $directive, $lastItem = false) {
		
		if ($lastItem) {
			$string = '<tr class="last">';
		} else {
			$string = '<tr>';
		}
		$string .= "<td><strong>{$directive->getName()}</strong>";
		
		$description = $directive->getDescription();
		if ($description) {
			$string .= " - {$description}";
		}
		$string .= "</td>
					<td class=\"directive-input\">
						<span style=\"white-space:nowrap;\">
						{$this->getInputElement($directive)}
						{$this->view->displayWidget($directive->getChangedIcon())}
						</span>
					</td>
				</tr>";
		
		return $string;
	}

	private function getInputElement(Directives_DisplayData_Abstract $directive) {
		switch ($directive->getType()) {
			case Directives_DisplayData_Abstract::TYPE_STRING:
				return $this->getInputElementString($directive);
				break;
			case Directives_DisplayData_Abstract::TYPE_BOOLEAN:
				return $this->getInputElementBoolean($directive);
				break;
			case Directives_DisplayData_Abstract::TYPE_SELECT:
				return $this->getInputElementSelect($directive);
				break;
			default:
				throw new Zwas_Exception('Unknown type of directive object', Zwas_Exception::ASSERT);
		}
	}
	
	private function getInputElementString(Directives_DisplayData_String $directive) {
		$name = $this->view->escape($directive->getName());
		$value = $this->view->escape($directive->getValue());
		$units = $this->view->escape($directive->getUnits());
		
		$disabled = ($directive->isDisabled()) ? 'disabled="disabled" ' : '';
		
		$output = "<input type=\"text\" name=\"directives[{$name}]\" value=\"{$value}\" size=\"{$directive->getMaxLength()}\" {$disabled} />";
		if ($units) {
			$output .= "&nbsp;$units"; 
		}
		return $output;
	}
	
	private function getInputElementBoolean(Directives_DisplayData_Boolean $directive) {
		$name = $this->view->escape($directive->getName());
		$disabled = ($directive->isDisabled()) ? 'disabled="disabled" ' : '';
		
		if ($directive->getValue()) {
			$checkedOn = 'checked="checked" ';
			$checkedOff = '';
		} else {
			$checkedOn = '';
			$checkedOff = 'checked="checked" ';
		}
		
		return 	"<label class=\"no-wrap\">
					<input type=\"radio\" name=\"directives[{$name}]\" value=\"1\" {$checkedOn}{$disabled} />" . Zwas_Translate::_('On') . 
				"</label>
				<label class=\"no-wrap\">
					<input type=\"radio\" name=\"directives[{$name}]\" value=\"0\" {$checkedOff}{$disabled} />" . Zwas_Translate::_('Off') . 
				"</label>";
	}

	private function getInputElementSelect(Directives_DisplayData_Select $directive) {
		$name = $this->view->escape($directive->getName());
		$disabled = ($directive->isDisabled()) ? 'disabled="disabled" ' : '';
		$value = $directive->getValue();
		
		$element = "<select name=\"directives[{$name}]\" {$disabled}>" . PHP_EOL;
		foreach ($directive->getOptions() as $optionValue => $optionText) {
			$selected = ($optionValue == $value) ? 'selected="selected" ' : '';
			$element .= "\t 
					  <option value=\"{$this->view->escape($optionValue)}\" {$selected} >
					  	{$this->view->escape($optionText)}
					  </option>" . PHP_EOL;
		}
		$element .= '</select>';
		
		return $element;		
	}
}
