<?php
/**
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_DisplayWidget extends Zend_View_Helper_Abstract {
	
	static private $actionId;
	
	public function displayWidget(DisplayWidget_Abstract $action) {
		++self::$actionId;
		
		switch ($action->getType()) {
			case DisplayWidget_Abstract::DISPLAY_WIDGET_LINK:
				return $this->getDisplayWidgetLink($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_INFO:
				return $this->getExtensionInfoActionText($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_INFO_DIALOG:
				return $this->getExtensionInfoDialogActionLink($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_ICON_TOOLTIP:
				return $this->getDisplayWidgetIconTooltip($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_LABEL_TOOLTIP:
				return $this->getDisplayWidgetLabelTooltip($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_ICON_BUTTON:
				return $this->getDisplayWidgetIconButton($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_EXTERNAL_LINK:
				return $this->getDisplayWidgetExternalLink($action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_ACTION_ICON:
				return $this->createDisplayWidgetIconLink(	'/images/icons/help.gif',
															'help-icon',
															$action);
				break;
			case DisplayWidget_Abstract::DISPLAY_WIDGET_ERROR_INFO:
				return $this->getDisplayWidgetErrorInfoActionText($action);
				break;
		}
		return '';
	}
	
	private function getDisplayWidgetLink(DisplayWidget_Link $action) {
		$link = <<<LINK
			<a onclick="{$this->getHrefContent($action)}">
			{$this->view->escape($action->getLabel())}</a>&nbsp;
LINK;

		return $link;
	}
	
	private function getExtensionInfoDialogActionLink(DisplayWidget_InfoDialog $action) {
		$dialogId = 'information' . self::$actionId;
		
		$link = <<<LINK
				<div class="info-modal" onclick="dijit.byId('{$dialogId}').show()">&nbsp;</div>
				{$this->view->escape($action->getLabel())}
				<div dojoType="dijit.Dialog" id="{$dialogId}" title="{$this->view->escape($action->getDialogTitle())}" 
					style="width:300px;">
				{$this->view->escape($action->getDialogContent())}
				</div>
LINK;

		return $link;
	}

	private function getExtensionInfoActionText(DisplayWidget_Info $action) {
		return $this->view->escape($action->getLabel());
	}
	
	private function getDisplayWidgetErrorInfoActionText(DisplayWidget_ErrorInfo $action) {
		return '<span class="red-info">' . $this->getExtensionInfoActionText($action) . '</span>';
	}
	
	private function getDisplayWidgetLabelTooltip(DisplayWidget_LabelTooltip $action) {
		$tooltipId = 'tooltip' . self::$actionId;
		
		$link = "<div id=\"{$tooltipId}\">{$this->view->escape($action->getLabel())}</div>";
		
		$tooltipContent = $action->getTooltipContent();
		if (! empty($tooltipContent)) {
			$link.= <<<LINK
			<span dojoType="dijit.Tooltip" connectId="{$tooltipId}">
				<span>{$tooltipContent}</span>
			</span>
LINK;
		}
		return $link;
	}
	
	private function getDisplayWidgetIconTooltip(DisplayWidget_IconTooltip $action) {
		$tooltipId = 'tooltip' . self::$actionId;
		
		$class = $action->getIconType();
		switch ($action->getIconType()) {
			case DisplayWidget_IconTooltip::ICON_LED_GREEN:
				$class = 'icon-led';
				$image = '/images/icons/led-green.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_LED_YELLOW:
				$class = 'icon-led';
				$image = '/images/icons/led-yellow.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_LED_GREY:
				$class = 'icon-led';
				$image = '/images/icons/led-grey.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_LED_RED:
				$class = 'icon-led';
				$image = '/images/icons/led-red.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_LED_GREEN_NOTICE:
				$class = 'icon-led';
				$image = '/images/icons/led-green-notice.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_SEVERITY_CRITICAL:
				$class = 'icon-led';
				$image = '/images/application/updates/critical.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_SEVERITY_IMPORTANT:
				$class = 'icon-led';
				$image = '/images/application/updates/important.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_SEVERITY_OPTIONAL:
				$class = 'icon-led';
				$image = '/images/application/updates/optional.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_SEVERITY_RECOMMENDED:
				$class = 'icon-led';
				$image = '/images/application/updates/recommended.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_NOTICE:
				$class = 'action-icon';
				$image = '/images/icons/notice.gif';
				break;
			case DisplayWidget_IconTooltip::ICON_INFO:
				$class = 'information-icon';
				$image = '/images/icons/information.gif';
				break;
				
			case DisplayWidget_IconTooltip::ICON_NULL:
			default:
				$class = 'action-icon';
				$image = '';
		}

		return $this->createDisplayWidgetIconTooltip($image, $tooltipId, $class, $action);
	}
	
	/**
	 * @param string $image
	 * @param string $class
	 * @param DisplayWidget_ActionIcon $action
	 * @return string
	 */
	private function createDisplayWidgetIconLink($image, $class, DisplayWidget_ActionIcon $action) {
		
		if ($action->getAction()) {
			$onclick =  "onclick=\"" . $action->getAction() . "\"";
		} else {
			$onclick = '';
		}
		
		return <<<LINK
				<div class="{$class}" title="{$this->view->escape($action->getLabel())}" $onclick>
					<img src="{$this->view->baseurl($image)}" />
				</div>
LINK;
	}
	
	/**
	 * Cretaes and return the html content of icon tooltip
	 *
	 * @param string $image
	 * @param string $tooltipId
	 * @param string $class
	 * @param string $action
	 * @return string
	 */
	private function createDisplayWidgetIconTooltip($image, $tooltipId, $class, $action) {
		$link = '';
		
		if ($image != '') {
			$link = <<<LINK
				<div id="{$tooltipId}" class="{$class}">
					<img src="{$this->view->baseurl($image)}" />
					{$this->view->escape($action->getLabel())}
				</div>
LINK;
		} else {
			$link = <<<LINK
				<div id="{$tooltipId}" class="{$class}">
					{$this->view->escape($action->getLabel())}
				</div>
LINK;
		}
		
		$tooltipContent = $action->getTooltipContent();
		if (! empty($tooltipContent)) {
			$link.= <<<LINK
			<span dojoType="dijit.Tooltip" connectId="{$tooltipId}">
				<div class="limitedTooltip">{$tooltipContent}</div>
			</span>
LINK;
		}
		
		return $link;
	}
	
	private function getDisplayWidgetIconButton(DisplayWidget_Link $action) {
		
		$buttonId = 'button-' . self::$actionId;
		
		switch ($action->getIconType()) {
			case DisplayWidget_MonitorRuleIconButton::ICON_DELETE:
				$class = 'clean-center';
				break;
			case DisplayWidget_MonitorRuleIconButton::ICON_ENABLE:
				$class = 'clean-center';
				break;
			case DisplayWidget_MonitorRuleIconButton::ICON_DISABLE:
				$class = 'clean-center';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_BUILT_IN:
				$class = 'built-in';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_LOADED_UNLOADABLE:
				$class = 'loaded-unloadable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_LOADABLE:
				$class = 'not-loaded-loadable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_NOT_LOADABLE:
				$class = 'not-loaded-unloadable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_UNLOADABLE:
				$class = 'not-loaded-loadable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_NO_ACTION:
				$class = 'not-loaded-no-action';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_ERROR:
				// TODO: change not-loaded-error background image in css to be disabled (not clickable)
				$class = 'not-loaded-error';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NOT_LOADED_ERROR_FIXABLE:
				$class = 'not-loaded-error-fixable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_STOP:
				$class = 'stop';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_START:
				$class = 'start';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_RESTART:
				$class = 'restart';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_CLEAN:
				$class = 'clean';
				break;				
			case DisplayWidget_ExtensionIconButton::ICON_ENABLE:
				$class = 'enable';
				break;				
			case DisplayWidget_ExtensionIconButton::ICON_DISABLE:
				$class = 'disable';
				break;
			case DisplayWidget_ExtensionIconButton::ICON_NULL:
			default:
				$class = '';
		}

		if ('' == $action->getController()) {
			$link = "<div id=\"{$buttonId}\" class=\"action-button {$class}\">&nbsp;</div>";
		} else {
			$link = "<div onclick=\"{$this->getHrefContent($action)}\" id=\"{$buttonId}\" class=\"action-button {$class}\">&nbsp;</div>";
		}
		
		$tooltipContent = $action->getTooltipContent();
		if (! empty($tooltipContent)) {
			$link.= <<<LINK
			<span dojoType="dijit.Tooltip" connectId="{$buttonId}">
				<span>{$this->view->escape($tooltipContent)}</span>
			</span>
LINK;
		}
		
		return $link;
	}
	
	/**
	 * Get the URL for the href="" or the onclick=""
	 * @param DisplayWidget_Link $action
	 * @return string
	 */
	private function getHrefContent(DisplayWidget_Link $action) {
		$params = $action->getParams();
		if ($action->getTargetController()) {
			$params['trgtController'] = $action->getTargetController();
			if ($action->getTargetAction()) {
				$params['trgtAction'] = $action->getTargetAction();
			}
		}
		
		return $this->view->contentLoader($action->getController(), $action->getAction(), $params, $action->getSidbarIdentifier());
	}

	private function getDisplayWidgetExternalLink(DisplayWidget_ExternalLink $action) {
		$link = <<<LINK
			<a href="{$action->getUrl()}" target="{$action->getTarget()}">
				{$this->view->escape($action->getLabel())}
			</a>&nbsp;
LINK;

		return $link;		
	}
	
}