<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_FileSize extends Zend_View_Helper_Abstract {
	
	const AUTO 	= 'AUTO';
	const KB	= 'KB';
	const MB	= 'MB';
	const GB	= 'GB';
	
	protected $sizes = array(Zwas_View_Helper_FileSize::GB		=> 30,
							 Zwas_View_Helper_FileSize::MB		=> 20,
							 Zwas_View_Helper_FileSize::KB 		=> 10);

	/**
	 * Get a filesize label.
	 *
	 * @param int $size				- size in bytes
	 * @param string $outputUnit 	- Zwas_View_Helper_FileSize constant
	 * @return string
	 * @throws Zwas_Exception
	 */
	public function fileSize($size, $outputUnit = Zwas_View_Helper_FileSize::AUTO) {
		if (!defined("Zwas_View_Helper_FileSize::$outputUnit")) {
			throw new Zwas_Exception("Wrong parameter type $outputUnit.", Zwas_Exception::ASSERT);
		}
		if (Zwas_View_Helper_FileSize::AUTO == $outputUnit) {
			$outputUnit = $this->outputSize($size);	
		}
		$size = ( $size / ( 1 << $this->sizes[$outputUnit]) );
		
		// if the number is float, we keep only 2 digits after the decimal point
		if ($size != (int)$size) {
			$size = number_format($size, 2);
		}
		
		// in the previous if we may have gone in it with 2.0000001 and after it ended with 
		// $size = 2.00 so we should trim the 00
		if ($size == (int)$size) {
			$size = (int)$size;
		}
		
		return "$size {$outputUnit}";
	}
	
	/**
	 * Calculate the best output size (KB, MB...)
	 *
	 * @param int $size, size in bytes
	 * @return string - Zwas_View_Helper_FileSize constant
	 */
	private function outputSize($size) {
		foreach ($this->sizes as $type => $mul){
			if ($size >= (1<<$mul)) {
				return $type;
			}
		}
		// return the smallest (last one itarated) size type
		return $type;
	}
}