<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_HostsListForm extends Zend_View_Helper_Abstract {
	
	/**
	 * @var ZwasComponents_Debugger_Forms_HostList
	 */
	private $form;
	/**
	 * @var string
	 */
	private $formController;
	/**
	 * @var string
	 */
	private $formAction;

	/**
	 * Show a list of all hosts, with remove buttons
	 * @param ZwasComponents_Debugger_Forms_HostList $form
	 * @return Zwas_View_Helper_HostsListForm
	 */
	public function hostsListForm(ZwasComponents_Debugger_Forms_HostList $form) {
		$this->form = $form;
		return $this;
	}
	
	/**
	 * @return string
	 */
	public function deniedList() {
		return $this->getForm(
			Zwas_Translate::_('Current list of denied hosts:'),
			Zwas_Translate::_('Use this list to exclude specific hosts from the allowed hosts list.')
		);
	}
	
	/**
	 * @param boolean $localHostIsDenied
	 * @return string
	 */
	public function allowedList($localHostIsDenied = false) {
		if ($localHostIsDenied) {
			$emptyMessage =  Zwas_Translate::_('This list is empty, no hosts are allowed to debug this server until you add hosts to this list.');
		} else {
			$emptyMessage =  Zwas_Translate::_('This list is empty, no hosts except 127.0.0.1 are allowed to debug this server until you add hosts to this list.');
		}
		
		return $this->getForm(
			Zwas_Translate::_('Current list of allowed hosts:'),
			$emptyMessage
		);
	}
	
	/**
	 * @param string $nonEmptyListMsg The message to show above the list when the list is not empty
	 * @param string $emptyListMsg The message to show instead of the list, if the list is empty
	 * @return string
	 */
	private function getForm($nonEmptyListMsg, $emptyListMsg) {
		$hostList = $this->form->getList();
		
		if (empty($hostList)) {
			return $emptyListMsg;
		}
		
		$this->formController	= $this->form->getController();
		$this->formAction		= $this->form->getAction();
		
		$output = "<strong>{$nonEmptyListMsg}</strong><br />" . PHP_EOL;
		$output.= '<div class="host-list-container list-container"><table cellpadding="0" cellspacing="0">';
		
		$hostsCount = count($hostList);
		$i = 0;
		
		foreach ($hostList as $host) {
			$displayHost	= $this->getHostDisplay($host);
			$removeAction	= $this->getRemoveAction($host, $this->form->getSidebarId());
			
			if (++$i == $hostsCount) {
				$output.= '<tr class="last">';
			} else {
				$output.= '<tr>';
			}
			$output .= "<td class=\"w100\">$displayHost</td>
						<td class=\"\">$removeAction</td>
					</tr>";
		}
		
		$output.= '</table></div>' . PHP_EOL;
		return $output;
	}

	/**
	 * @param string $host
	 * @param string $sidebarId specific sidebar item identifier
	 * @return string
	 */
	private function getRemoveAction($host, $sidebarId = null) {
		$action = $this->view->contentLoader(	$this->formController,
												$this->formAction,
												array('host' => str_replace('/', '-', $host)),
												$sidebarId
											);
		return '<a onclick="' . $action . '">' . Zwas_Translate::_('Remove') . '</a>';
	}
	
	/**
	 * Build the display of the host:
	 * 1. if the mask is not 8, 16, 24 or 32 => display the mask
	 * 2. if the mask is one of the following, display * instead of mask
	 *
	 * @param string $host
	 */
	private function getHostDisplay($host) {
		$masks = array(8, 16, 24, 32);
		
		if (false === strpos($host, '/')) {	// host with no mask
			return $host;
		}
		
		$parts = explode('/', $host);
		$mask = (int)$parts[1];
		if (!in_array($mask, $masks)) { // host with mask that not 8,16,24 or 32
			return $host;
		}
		
		$ip = explode('.', $parts[0]);
		for ($i=3 ; $i>0 ; --$i) {
			if ($mask < array_pop($masks)) {
				$ip[$i] = '*';
			}
		}
		return implode('.', $ip);
	}
}
