<?php
/**
 * A helper to print out a menu out of a MenuModel object
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_MenuList extends Zend_View_Helper_Abstract {
	
	/**
	 * Convert a two-level array to a sidebar display
	 *
	 * @param MenuItem $menu
	 * @return string
	 */
	public function menuList(MenuItem $items) {
		$list = '<table class="sub-tabs"><tr>' . PHP_EOL;
		
		$listCount = count($items) - 1;
		
		foreach ($items as $key => $item) { /* @var $item MenuItem */
			$list .= $this->getListItemNoEnd($item);
			
			// Add "|" seperator after each element exept the last one
			if ($listCount != $key) {
				$list .= '</td><td class="menu-seperator">|</td>' . PHP_EOL;
			} else {
				$list .= '</td>' . PHP_EOL;
			}
		}
		$list .= '</tr></table>' . PHP_EOL;
		
		return $list;
	}

	/**
	 * Return a proper <td>whatever.  With link if needed or selected class attribute
	 * IMPORTANT - it returns the <td> _WITHOUT_ the closing </td>
	 *
	 * @param MenuItem $item
	 * @return string
	 */
	private function getListItemNoEnd(MenuItem $item) {
		$text = $this->view->escape($item->getLabel());
		$controller = $item->getController();
		$action = $item->getAction();
		$listItmeId = MenuItem::generateId($controller, $action);
		
		// create the opening TD tag with the relevant class
		$itemString = "<td id=\"$listItmeId\"";
		
		// create the TD content with a link or without it
		if ($item->getController()) {
			$link = $this->view->contentLoader($item->getController(), $item->getAction(), null, $item->getIdentifier());
			
			$itemString .= " onclick=\"$link\"";
		}
		
		$itemString .= '>';
		
		$itemString .= $text;
		
		return $itemString;
	}

	
}