<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_MessagePaneContent extends Zend_View_Helper_Abstract {
	
	/**
	 * @var MessagePane_Abstract
	 */
	private $msgPane;
	
	/**
	 * @param MessagePane_Abstract $msgPane
	 * @return string|Zwas_Text
	 */
	public function messagePaneContent(MessagePane_Abstract $msgPane) {
		$this->msgPane = $msgPane;
		
		$msg = $this->msgPane->getMessage(); 
		$msg = $this->convertBbCode($msg);
		$msg = $this->nl2br($msg);
		return $this->tab2space($msg); 
	}
	
	/**
	 * turn new lines to <br />s without leaving newlines (nl2br leaves new lines)
	 * @param string $msg
	 * @return string
	 */
	private function nl2br($msg) {
		return str_replace(array("\r\n", "\n\r", "\n", "\r"), '<br />', $msg);
	}
	
	/**
	 * @param string $msg
	 * @return string
	 */
	private function tab2space($msg) {
		return preg_replace('/(\t)+/', ' ', $msg);
	}
	
	/**
	 * @param string $msg
	 * @return string
	 */
	private function convertBbCode($msg) {
		$link = $this->msgPane->getLink();
		
		switch (true) {
			case (is_array($link)):
				$onclick = $this->view->contentLoader(
					$link['controller'], 
					$link['action'], 
					(isset($link['params'])) ? $link['params'] : null, 
					(isset($link['sidebarId'])) ? $link['sidebarId'] : null 
				); 
	
				$msg = str_replace(
					array('[a]', '[/a]'), 
					array("<a class=\"link\" onclick=\"{$onclick}\">", '</a>'), 
					$msg
				);
				break;
			case (is_string($link)):
				$msg = str_replace(
					array('[a]', '[/a]'), 
					array("<a class=\"link\" href=\"{$link}\" target=\"_blank\">", '</a>'), 
					$msg
				);
				break;
			default:
				// drop [a][/a] which have no link
				$msg = str_replace(
					array('[a]', '[/a]'), 
					'', 
					$msg
				);
		}
		return $msg;
	}
}