<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
class Zwas_View_Helper_Trimmer extends Zend_View_Helper_Abstract {
	
	/**
	 * before: places tooltip to the left of the target node/widget, or to the right in the case of RTL scripts like Hebrew and Arabic
     * after: places tooltip to the right of the target node/widget, or to the left in the case of RTL scripts like Hebrew and Arabic
     * above: tooltip goes above target node
     * below: tooltip goes below target node
     */
	const POSITION_BELOW	= 1;
	const POSITION_ABOVE	= 2;
	const POSITION_BEFORE	= 3;
	const POSITION_AFTER	= 4;
	
	/**
	 * Create a trimmed version of a string, based on the requested $length.  If the
	 * string is multi-lined and the first line is shorter than the length requested,
	 * the trimmed string will be only the first line
	 * @param string $string
	 * @param integer $length
	 * @param integer $position
	 * @return string
	 */
	public function trimmer($string, $length, $position = null) {
		if (strlen($string) < $length) {
			return $string;
		}

		// Cover the cases of input created in one OS and running on a different one
		$firstNewLine = strpos($string, "\n");
		if (false === $firstNewLine) {
			$firstNewLine = strpos($string, "\r");
		}
		
		if ((false !== $firstNewLine) && ($firstNewLine < $length)) {
			$trimmedString = substr($string, 0, $firstNewLine+1);
		} else {
			$trimmedString = substr($string, 0, $length);
		}
		
		$id = 'trimmed_' . mt_rand();
		$string = nl2br($string);
		
		$toolTip = "<span dojoType=\"dijit.Tooltip\" connectId=\"{$id}\" position=\"{$this->getPosition($position)}\">
						<span>{$string}</span>
					</span>";
		
		return '<span id="' . $id . '">' . $trimmedString . '&nbsp;<span class="trimmer-more">[' . Zwas_Translate::_('more') . '...]</span></span>' . $toolTip;
	}
	
	private function getPosition($position) {
		switch ($position) {
			case self::POSITION_ABOVE:
				return 'above';
				break;
			case self::POSITION_AFTER:
				return 'after';
				break;
			case self::POSITION_BEFORE:
				return 'before';
				break;
			case self::POSITION_BELOW:
			default:
				return 'below';
				break;
		}		
	}

}