<?php
require_once ZEND_SERVER_APP_PE_PATH . '/controllers/AdminController.php';

class EE_AdminController extends PE_AdminController {
	
	public function tasksAction() {
		$licenseDirectives = License_Directives::getSystemLicenseDirectives();
		$zscmLicenseModel = Context_Version::getLicenseModel(
				Context_Api::getUtilAPI()->getSerialNumberInfo(
					$licenseDirectives->getLicenseKey(), $licenseDirectives->getOrderNumber()
				)
			);
		if (ApplicationModel::hasNodesLicense()) {
			$nodeData = ApplicationModel::getNodesLicense();
			$nodesLicenseModel = new License_Model_Nodes(Context_Api::getUtilAPI()->getSerialNumberInfo(
									$nodeData->getLicenseKey(), $nodeData->getOrderNumber()
								));
		} else {
			$nodesLicenseModel = Context_Version::getLicenseModel(array());
		}
		$nodesModel = new Nodes_Model();
		$currentConnectedNodes = $nodesModel->countNodes();
		$this->view->nodesCount = $currentConnectedNodes;
		$this->view->serverLicenseModel	= $nodesLicenseModel;
		$this->view->zscmLicenseModel	= $zscmLicenseModel;
		
		// Cascade error messages  (overwrite by precedence)
		// After submit the success / error message is the one which should be displayed, that's the reason for checking if there is already a msg
		if ((! $this->isSetMessagePane()) && $nodesModel->hasMoreNodesThanLicensed()) {
			$this->setMessagePane(new MessagePane_Notice(
				Zwas_Translate::_('The number of connected members exceeds the limit in your Cluster Manager\'s license')
			));
		}
		
		try {
			$zscmLicenseModel->verifyLicense();
			$nodesLicenseModel->verifyLicense();
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}	
    }
	
	/**
     * Update the license - should update it both in the ZSM and the machines of the cluster
     */
	public function saveLicenseAction() {
		$zscmOrderNumber 	= $this->getTrimmedParam('zscm-username');
		$zscmLicenseKey = $this->getTrimmedParam('zscm-license-key');
		$zsUsername 	= $this->getTrimmedParam('server-username');
		$zsLicenseKey = $this->getTrimmedParam('server-license-key');
		

		// input validation
		if ((('' == $zscmLicenseKey) || ('' == $zscmOrderNumber)) &&
			(('' == $zsLicenseKey) || ('' == $zsUsername))) {
				
				$this->setMessagePane(new MessagePane_Error(
					Zwas_Translate::_('At least one order number / license key pair must be filled')
				));
		}
		
		/// Store the local license information
		if (('' != $zscmOrderNumber) && ('' != $zscmLicenseKey)) {
			try {
				if (Context_Version::getLicenseModel(array())->setLicense($zscmOrderNumber, $zscmLicenseKey)) {
					$this->setMessagePane(new MessagePane_Success(Zwas_Translate::_('License details have been saved')));
				}
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
		}
		
		/// Store servers' license information
		if (('' != $zsUsername) && ('' != $zsLicenseKey)) {
			try {
				ApplicationModel::setNodesLicense($zsUsername, $zsLicenseKey);
				
				$nodesModel = new Nodes_Model();
				if ($nodesModel->hasNodes()) {
					if ($nodesModel->distributeNodesLicense()) {
						$this->setMessagePane(new MessagePane_Notice(
							Zwas_Translate::_('License details have been updated on the cluster\'s servers.  Restart the cluster\'s servers\' PHP to apply changes')));
					} else {
						$this->setMessagePane(new MessagePane_Error(
							Zwas_Translate::_('License details have been saved, but were not distributed to the cluster members. Repeat your last action and if this problem persists, contact the Zend Support Center at: http://www.zend.com/support-center')
						));
					}
				} else {
					$this->setMessagePane(new MessagePane_Success(Zwas_Translate::_('License details have been saved')));
				}
				
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}

		}
		
		$this->forward('Tasks');
	}
	
}
