<?php
require_once ZEND_SERVER_APP_PE_PATH . '/controllers/CodeTracingController.php';

class EE_CodeTracingController extends PE_CodeTracingController {
	
	/**
	 * Turn the Zend Server component off
	 */
	public function deactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component on
	 */
	public function activateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off by force
	 */
	public function forceDeactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
		
	public function dumpsListAction() {
		$nodesModel = new Nodes_Model();
		if($nodesModel->hasNodes()) {
			parent::dumpsListAction();
		} else {
			$this->setMessagePane(new MessagePane_Info(Zwas_Translate::_('There are currently no servers connected to the Zend Server Cluster Manager. Go to Cluster Setup | Servers to add servers to the cluster')));
			$this->renderScript('message.phtml');
			return;
		}
	}
	
	public function deleteDumpsAction() {
		$dumps = $this->getTrimmedParam('dumps');
		
		if (! empty($dumps)) {
			try {
				$this->isDbConnected();
			} catch (Zwas_Db_Exception $e) {
				$this->setMessagePane(new MessagePane_Error(new Zwas_Text(Zwas_Translate::_('Could not delete trace file: %s'), array($e->getMessageObject()))));
				$this->afterActionForward('Dumps-List', $this->controllerName);
				return;
			}
			
			/// We call the ZSM deletion delegate here
			/// It distributes the deletion calls to the servers, which actually perform
			/// deleteDumpsDatabase. Locally, ZSM, only deletes files.
			$failedIds = $this->getModel()->deleteDumps($dumps);
			if (empty($failedIds)) {
				$this->setMessagePane(new MessagePane_Success(Zwas_Translate::_('The trace files were successfully deleted')));
			} else {
				$this->setMessagePane(new MessagePane_Notice(new Zwas_Text(
					Zwas_Translate::_('The following trace files could not be deleted - %s.  Verify file permissions and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'),
					implode(', ', $failedIds)
				)));
			}
		} else {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('Select trace files to delete')));
		}
		
		$this->afterActionForward('Dumps-List', $this->controllerName);
	}
	
	/**
	 * @return ZwasComponents_CodeTracing_Model
	 * @throws Zwas_Exception
	 */
	protected function getModel() {
		if (is_null($this->model)) {
			$this->model = new ZwasComponents_ZSM_CodeTracing_Model();
		}
		return $this->model;
	}
}