<?php

class EE_ConfigurationController extends Zwas_Controller_MainContent {
	
	public function extensionsAction() {
		$nodesModel = new Nodes_Model();
		if (! $nodesModel->hasNodes()) {
			$this->setMessagePane(new MessagePane_Info(
				Zwas_Translate::_('There are currently no servers connected to the Zend Server Cluster Manager. Go to Cluster Setup | Servers to add servers to the cluster'))
			);
		} else {
			if (! $this->areNodesOlderThanZSCM()) {
				$this->view->extensions = $this->getFilteredExtensions();
				Nodes_Action::lockContentOnMixedCluster($this);
			}
		}
	}
	
	public function zendServerComponentsAction() {
		$nodesModel = new Nodes_Model();
		if (! $nodesModel->hasNodes()) {
			$this->setMessagePane(new MessagePane_Info(
				Zwas_Translate::_('There are currently no servers connected to the Zend Server Cluster Manager. Go to Cluster Setup | Servers to add servers to the cluster'))
			);
		} else {
			if (! $this->areNodesOlderThanZSCM()) {
				Nodes_Action::remoteAction($this);
				Nodes_Action::lockContentOnMixedCluster($this);
			}
		}
	}
	
	/**
	 * Load an extension which name was passed through GET
	 */
	public function loadExtensionAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Load an extension which name was passed through GET
	 */
	public function unloadExtensionAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Fix a problematic extension configuration, which is actually the same as unloading it
	 * according to the states map
	 */
	public function fixExtensionAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Restart the webserver
	 */
	public function webserverRestartAction() {
		$nodesModel = new Nodes_Model();
		$nodes = $nodesModel->getRespondingNodes();
		
		// maximum of 300s, minimum of 50s, linearly incremented by number of nodes
		$timelimit = min(300,max(50, 50 * count($nodes)));
		set_time_limit($timelimit);
		/// added for conformity with IIS audit controls
		Context_Api::getPhpMemory()->iniSet('max_execution_time', $timelimit);

		foreach($nodes as $node) { /* @var $node Nodes_Element_Mapper */
			Zwas_Log::info('Sending a restart request to server #' . $node->getId());
			Nodes_Action::remoteNodeAction($this, $node);
			/* 
			 * Sleep for 1 second so that we are operating system independent
			 * If we do not sleep, restartin linux nodes results in clearing the nodes'
			 * signature from the database and generating a needless and misleading error message.
			 * This should be converted to use the future osType node environment variable
			 * So as to be custom-fitted per OS. 
			 */
			sleep(1);
		}
		
		$this->_helper->viewRenderer->setNoRender();
		
		Zwas_Log::info('Waiting after the restart requests');
		sleep(Context_Os::getServerRestartTimeout());
		
		Zwas_Log::info('Trying to update heartbeats');
		try {
			$nodesModel->updateNodesState();
		} catch(Zwas_Exception $e) {
			Zwas_Log::logException('Failed updating nodes\'s state after restart', $e);
		}
		
		// Reload relevant daemon's configurations
		try {
			if (Context_Api::getMonitorDaemonApi()->isNodeRunning()) {
				Zwas_Log::info('Reloading Monitor configurations');
				Context_Api::getMonitorDaemonApi()->reloadConfiguration();
			}
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException(Zwas_Translate::_('Failed reloading Monitor configuraion after a cluster restart'), $e);
		}
	}

	/**
	 * Returns a list of extensions whose names do not match any component's name
	 * @return array
	 */
	private function getFilteredExtensions() {
		$clusterExtensions = new ClusterPhpExtensions_Model();
		$extensions = ClusterPhpExtensions_Model::sortExtensions($clusterExtensions->getRepresentativeExtensions());

		$clusterComponents = new ClusterZendComponents_Model();
		$components = ClusterZendComponents_Model::sortComponents($clusterComponents->getRepresentativeComponents());
		return array_diff_key($extensions, $components + array('zend utils' => 1, 'zend monitor ui' => 1));
	}

	/**
	 * @return boolean
	 */
	private function areNodesOlderThanZSCM() {
		$nodesModel = new Nodes_Model();
		if ($nodesModel->hasNodes() && (! $nodesModel->hasDifferentEnvironmentId())) {
			if ($nodesModel->getRepresentativeForReading()->getZendServerVersion() != ApplicationModel::getZendServerVersion()) {
				$this->setMessagePane(
					new MessagePane_Info(Zwas_Translate::_('This page\'s functionality has been disabled because the cluster members versions are older than the manager\'s'))
				);
				$this->renderScript('message.phtml');
				return true;
			}
		}
		return false;
	}
}
