<?php
require_once ZEND_SERVER_APP_PE_PATH . '/controllers/JobQueueSetupController.php';

class EE_JobQueueSetupController extends PE_JobQueueSetupController {
	/**
	 * Turn the Zend Server component off
	 */
	public function deactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component on
	 */
	public function activateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off by force
	 */
	public function forceDeactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	
	/**
	 * Displays a Job Queue setup screen
	 */
	public function setupAction() {
		$nodesModesl = new Nodes_Model();
		Nodes_Action::remoteAction($this);
		
		if (isset($this->view->userServerJqeBinding)) {
			// Job Queue Extension binding address
			$address = $this->view->userServerJqeBinding;
			$zsmModel = new ZwasComponents_ZSM_JobQueue_Model();

			try {
				$hostBinding = $zsmModel->getHostFromBindning($address);
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Notice(new Zwas_Text(
					Zwas_Translate::_('The default daemon address %s is not a valid IP address or host. Enter correct Job Queue daemon connection details'),
					array($address)
				)));
				return;
			}	
			
			if (! $nodesModesl->isServerPartOfClusterNodesGroup($hostBinding)) {
				$this->setMessagePane(new MessagePane_Info(
					Zwas_Translate::_('The default daemon address does not appear to belong to the cluster. Job Queue Daemon setting changes are not applied to servers not belonging to the cluster')
				));
			} else {
				$node = $nodesModesl->getNodeByAddress($hostBinding);
				if ($node->isDisabled()) {
					$this->setMessagePane(new MessagePane_Info(
						// TRANSLATE
						Zwas_Translate::_('The default daemon address appears to belong to a disabled cluster member. Job Queue Daemon setting changes are not applied to disabled cluster members')
					));
				}
			}
		}	
		Nodes_Action::lockContentOnMixedCluster($this);
	}
	
	/**
	 * Saves Job Queue configuration directives
	 */
	public function saveSetupAction() {
		try {
			$configurationData = ZwasComponents_ZSM_JobQueue_ConfigurationValidator::validate($this->_getAllParams());
			ZwasComponents_ZSM_JobQueue_Model::saveBindingDirective($configurationData['jqBinding'], $configurationData['jqBinding']);
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			$this->forward('setup');
			return;
		}
		
		// prepare the JQD listen-to binding for the nodes
		$this->getRequest()->setParam('jqListen', ZwasComponents_JobQueue_Binding::getDaemonListenBinding($configurationData['jqBinding']));
		Nodes_Action::remoteDistributeAction($this);
		
		$nodesModel = new Nodes_Model();
		$nodes = new Nodes_Collection($nodesModel->getRespondingNodes());
		$nodes->setCollectionAwaitsRestart()->save();
	}
}
