<?php

class EE_LicenseExpiredController extends Zwas_Controller_MainContent {

	public function init() {
		$this->enforceLicense = false;
		parent::init();
	}
	
	public function indexAction() {
		$this->_helper->actionStack('Layout-State', 'Index' , 'EE',
									array(	'module'		=> 'EE',
											'controller' 	=> 'Admin',
											'action'		=> 'Tasks',
									));
		
		$nodesModel = new Nodes_Model();
		$this->view->nodesCount = $nodesModel->countNodes();
		
		$licenseDirectives = License_Directives::getSystemLicenseDirectives();
		$licenseInfo = Context_Api::getUtilAPI()->getSerialNumberInfo(
			$licenseDirectives->getLicenseKey(),
			$licenseDirectives->getOrderNumber()
		);
		$licenseModel = Context_Version::getLicenseModel($licenseInfo);
		$this->view->zscmLicenseModel = $licenseModel;
		
		$message = $this->_helper->flashMessenger->getMessages();
		if (empty($message)) {
			$this->setMessagePane(new MessagePane_Error(
				Zwas_Translate::_('Your Zend Server Cluster Manager license has expired or is invalid')));
		} else {
			$this->setMessagePane($message[0]);
		}
	}
		
	public function detachAllNodesAction() {
		$model = new Nodes_Model();
		try {
			$model->detachAllNodes();
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException('Failed removing a server', $e);
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->afterActionForward('Index', 'License-Expired');
	}
    
	/**
     * Update the license - should update it both in the ZSM and the machines of the cluster
     */
	public function saveLicenseAction() {
		/// Store the local license information
		$username 	= $this->getTrimmedParam('zscm-username', null);
		$licenseKey = $this->getTrimmedParam('zscm-license-key', null);

		if (('' != $username) && ('' != $licenseKey)) {
			try {
				if (Context_Version::getLicenseModel(array())->setLicense($username, $licenseKey)) {
					$this->afterActionForward('Tasks', 'Admin');
					return;
				}
			} catch (Zwas_Exception $e) {
				$this->_helper->flashMessenger(new MessagePane_Error($e->getMessageObject()));
			}
		} else {
			$this->_helper->flashMessenger(new MessagePane_Error(
				Zwas_Translate::_('Enter your order number and license key'))
			);
		}
		$this->afterActionForward('Index', $this->controllerName);
		return;
	}
	
}
