<?php
require_once ZEND_SERVER_APP_PE_PATH . '/controllers/MonitorComponentController.php';

class EE_MonitorComponentController extends PE_MonitorComponentController {
	
	/**
	 * Turn the Zend Server component on
	 */
	public function activateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off
	 */
	public function deactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off by force
	 */
	public function forceDeactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	public function rulesAction() {
		$nodeModel = new Nodes_Model();
		if(!$nodeModel->hasNodes()) {
			$this->setMessagePane(new MessagePane_Info(Zwas_Translate::_('There are currently no servers connected to the Zend Server Cluster Manager. Go to Cluster Setup | Servers to add servers to the cluster')));
		} else {
			$this->doCheckModel = false;
			parent::rulesAction();
		}
	}
	
	public function saveConfigCodeTracingAction() {
		Nodes_Action::remoteDistributeAction($this);
	}
	
	/**
	 * Save the rule edited (from POST)
	 */
	public function updateRuleAction() {
		parent::updateRuleAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function disableRulesAction() {
		parent::disableRulesAction();
		//FIXME get file name of events_rules.xml somewhere to avoid hardcoded.
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function enableRulesAction() {
		parent::enableRulesAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function enableRulesEmailingAction() {
		parent::enableRulesEmailingAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function disableRulesEmailingAction() {
		parent::disableRulesEmailingAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function enableRulesCodeTracingAction() {
		parent::enableRulesCodeTracingAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	public function disableRulesCodeTracingAction() {
		parent::disableRulesCodeTracingAction();
		$this->redistributeConfiguationData(array('events_rules.xml'));
	}
	
	protected function getTraceMode() {
		/// override this functionality only - we may need the original PE model elsewhere.
		/// ZSM monitor model does not inherit the PE model
		return $this->getMonitorModel()->getMonitorMode();
	}
	
	/**
	 * @return ZwasComponents_ProbeInterface
	 */
	protected function getMonitorModel() {
		return new ZwasComponents_ZSM_Monitor_Model();
	}
	
	/**
	 * @param array $fileNames
	 */
	private function redistributeConfiguationData(array $fileNames = array()) {
		try{
			$model = new Nodes_Model();
			$model->distributeConfigurationFiles($fileNames);
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(
				new MessagePane_Error( $e->getMessage() ));
		}
	}
}
