<?php

class EE_NodesController extends Zwas_Controller_MainContent {
	
	public function indexAction() {
		$model = new Nodes_Model();
		$containInprocessNode = false;
		$defaultMessage = '';
		$previouslyMsgSet = $this->isSetMessagePane();
		$this->view->message = $defaultMessage;
		// Cascade error messages  (overwrite by precedence)
		if ($model->hasMoreNodesThanLicensed() && (! $previouslyMsgSet)) {
			$this->setMessagePane(new License_MessagePane_Notice(
				Zwas_Translate::_('The number of connected members exceeds the limit in your Cluster Manager\'s license')
			));
		}
		
		try {
			$zsLicense = ApplicationModel::getNodesLicense();
		} catch (Zwas_Exception $e) {
			if (! $previouslyMsgSet) {
				$this->setMessagePane(new MessagePane_Notice(
					Zwas_Translate::_('Update your license details to enable adding servers. Go to Administration | License and Password to update them'))
				);
			}
		}
		
		$containInprocessNode = $model->hasUnstableNode();
		if ($containInprocessNode && (! $previouslyMsgSet)) {
			if (GracefulShutdown::getTimeLeft() > 0) {
				if ($model->hasNodesInRemovalTransition()) {
					$this->setMessagePane(new MessagePane_Notice(
						// TRANSLATE
						new Zwas_Text(Zwas_Translate::_('A server is currently being removed. This page will be refreshed in %s seconds'), 
						array(GracefulShutdown::getTimeLeft())))
					);
				} elseif ($model->hasNodesInDisableTransition()) {
					$this->setMessagePane(new MessagePane_Notice(
						// TRANSLATE
						new Zwas_Text(Zwas_Translate::_('A server is currently being disabled. This page will be refreshed in %s seconds'), 
						array(GracefulShutdown::getTimeLeft())))
					);
				}
			} else {
				if ($model->hasNodesInRemovalTransition()) {
					// TRANSLATE
					$this->setMessagePane(new MessagePane_Notice(
						Zwas_Translate::_('Adding servers will be enabled once the remove server process is completed and the server\'s status is refreshed')
					));
				} elseif ($model->hasNodesInDisableTransition()) {
					// TRANSLATE
					$this->setMessagePane(new MessagePane_Notice(
						Zwas_Translate::_('Adding servers will be enabled once the disable server process is completed and the server\'s status is refreshed')
					));
				} 
			}
		} elseif (($model->hasNodes()) && (! $model->hasEnabledNodes())) {
			// TRANSLATE
			$this->setMessagePane(new MessagePane_Notice(
				Zwas_Translate::_('Adding servers is not allowed because all servers are disabled. Enable a server in the cluster to add more servers')
			));
		}
		
		$hasDifferentEnvironmentId = $model->hasDifferentEnvironmentId();
		if ($hasDifferentEnvironmentId && ! $previouslyMsgSet) {
			$this->setMessagePane(
				new MessagePane_Notice(
					Zwas_Translate::_('One or more servers in the cluster have a different Zend Server version. Update all servers now to support updated functionality')
				)
			);
		}
		
		$this->view->nodesModel = $model;
		
		try {
			$this->view->nodesList = $model->getNodesListOrderedByName();
			$this->view->containInprocesNode = $containInprocessNode;
		} catch (Zwas_Exception $e) {
			if (! $previouslyMsgSet) {
				$this->setMessagePane(new MessagePane_Error(
					Zwas_Translate::_('Unable to retrieve server list. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'))
				);
			}
		}
		
		if (0 < $model->countNodes()) {
			try {
				$jqdZsmModel = new ZwasComponents_ZSM_JobQueue_Model();
				$this->view->jqdHost = $jqdZsmModel->getZendServerHostBoundAddress();
			} catch (Zwas_Exception $e) {
				// failed to retrieve the JQD host address, silence the exception
			}
		}

		if (GracefulShutdown::isInitialized() && GracefulShutdown::getTimeLeft() > 0) {
			$this->view->gracefulShutdownTimeout = GracefulShutdown::getTimeLeft();
		}
	}
	
	public function enableNodeAction() {
		$model = new Nodes_Model();
		$node = $model->getNode($this->getTrimmedParam('id'));
		if ($node->isDisabled()) {
			try {
				$model->enableNode($node);
				$this->setMessagePane(new MessagePane_Success('The server was successfully enabled'));
			} catch (Zwas_Exception $e) {
				Zwas_Log::logException('Failed enabling a server', $e);
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
		} else {
			// TRANSLATE
			$this->setMessagePane(new MessagePane_Notice('The server is already enabled'));
		}
		$this->afterActionForward('Index', $this->controllerName);
	}
	
	public function disableNodeAction() {
		$model = new Nodes_Model();
		$node = $model->getNode($this->getTrimmedParam('id'));
		if (! $node->isDisabled()) {
			try {
				$node = $model->disableNode($node);
			} catch (Zwas_Exception $e) {
				Zwas_Log::logException('Failed disabling a server', $e);
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
			}
			
			try {
				if (! $this->isSetMessagePane()) { // no need to check the following as the node remove process has failed
					if ($node->isDisabled()) {
						$this->setMessagePane(new MessagePane_Success('The server was successfully disabled'));
					} else {
						switch ($node->getScStatus()) {
							case ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS:
							case ZwasComponents_SessionClustering_Model::SCD_STATUS_OFF:
								// TRANSLATE
								$this->setMessagePane(new MessagePane_Notice(
									new Zwas_Text(Zwas_Translate::_('The server is currently being disabled. This page will be refreshed in %s seconds'), 
									array(GracefulShutdown::getTimeLeft())))
								);
								break;
							default:
								throw new Zwas_Exception(Zwas_Translate::_('Unexpected server Zend Session Clustering status receieved')); 
						}
					}
				}
			} catch (Zwas_Exception $e) {
				Zwas_Log::logException('Failed disabling a server due to a Zend Session Clustering problem', $e);
				$this->setMessagePane(new MessagePane_Error('The server could not be disabled.  Check your Zend Session Clustering configuration'));
			}
		} else {
			$this->setMessagePane(new MessagePane_Notice('The server is already disabled'));
		}
		$this->afterActionForward('Index', $this->controllerName);
	}
	
	public function removeNodeAction() {
		$model = new Nodes_Model();
		try {
			$node = $model->removeNode($model->getNode($this->getTrimmedParam('id')));
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException('Failed removing a server', $e);
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		
		try {
			if (! $this->isSetMessagePane()) { // no need to check the following as the node remove process has failed
				if ($node->isDeleted()) {
					$this->setMessagePane(new MessagePane_Success('The server was successfully removed'));
				} else {
					switch ($node->getScStatus()) {
						case ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS:
						case ZwasComponents_SessionClustering_Model::SCD_STATUS_OFF:
							// TRANSLATE
							$this->setMessagePane(new MessagePane_Notice(
								new Zwas_Text(Zwas_Translate::_('The server is currently being removed. This page will be refreshed in %s seconds'), 
								array(GracefulShutdown::getTimeLeft())))
							);
							break;
						default:
							throw new Zwas_Exception(Zwas_Translate::_('Unexpected server Zend Session Clustering status receieved')); 
					}
				}
			}
		} catch (Zwas_Exception $e) {
			Zwas_Log::logException('Failed removing a server due to a Zend Session Clustering problem', $e);
			$this->setMessagePane(new MessagePane_Error('The server could not be removed.  Check your Zend Session Clustering configuration'));
		}
		$this->afterActionForward('Index', $this->controllerName);
	}
	
	public function forceRemoveNodeAction() {
		$model = new Nodes_Model();
		$node = null;
		try {
			$node = $model->getNode($this->getTrimmedParam('id'));
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Success(Zwas_Translate::_('The server was successfully removed')));
		}
		
		if ($node instanceof Nodes_Element_Mapper) {
			try {
				$node = $model->ungracefulRemoveNode($node);
				if ($node->isDeleted()) {
					$this->setMessagePane(new MessagePane_Success(Zwas_Translate::_('The server was successfully removed')));
				} else {
					throw new Zwas_Exception(Zwas_Translate::_('Unexpected Zend Session Clustering status receieved'));
				}
			} catch (Zwas_Exception $e) {
				Zwas_Log::logException('Failed removing a server', $e);
				$this->setMessagePane(new MessagePane_Error(
					new Zwas_Text(Zwas_Translate::_('Could not force-remove the server. %s'),
					$e->getMessageObject())
				));
			}
		}
		$this->afterActionForward('Index', $this->controllerName);
	}
	
	public function reconfigureNodeAction() {
		$model = new Nodes_Model();
		try {
			$model->reconfigureNode($this->getTrimmedParam('id'));
			$this->setMessagePane(new MessagePane_Success('The server was successfully reconfigured'));
			
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		
		$this->afterActionForward('Index', $this->controllerName);
	}
	
	public function addNodeAction() {
		$form = new Form_Servers_Add();
		$request = $this->getRequest();
		
		$model = new Nodes_Model();
		
		// Protection against trying to add a server when another one is in process of removal
		if ($model->hasNodeInShutdownProcess()) {
			$this->setMessagePane(new MessagePane_Error(
				Zwas_Translate::_('You can not add a server while another server is being removed')
			));
			$this->forward('Index');
		}
		
		// Protection against trying to add a server when another one is in process of startup
		if ($model->hasNodeInStartupProcess()) {
			$this->setMessagePane(new MessagePane_Error(
				Zwas_Translate::_('You can not add a server while another server is returning from disabled state')
			));
			$this->forward('Index');
		}
		
		if ($request->isPost() && $form->isValid($this->getTrimmedParams())) {
			try {
				$form->process();
				$this->afterActionForward('Index', 'Nodes');
				return;
			} catch (Zwas_Exception $e) {
				
				$message = new Zwas_Text(
					Zwas_Translate::_('Failed to add server %s'),
					array($form->getServerUrl()) 
				);
				Zwas_Log::logException((string)$message, $e);
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
				
			} catch (Exception $e) {
				
				$message = new Zwas_Text(
					Zwas_Translate::_('Failed to add server %s'),
					array($form->getServerUrl()) 
				);
				Zwas_Log::logException((string)$message, $e);
				$this->setMessagePane(new MessagePane_Error($e->getMessage()));
				
			}
		}
		
		try {
			$this->view->hasNodes = $model->hasNodes();
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
		}
		$this->view->form = $form;
	}

	public function editNodeAction() {
		$nodeId = $this->getTrimmedParam('id');
		$nodesModel = new Nodes_Model();
		$request = $this->getRequest();
		$form = new Form_Servers_Edit();
		$this->view->form = $form;
		
		try {
			$node = $nodesModel->getNode($nodeId);
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error(
				Zwas_Translate::_('Return to Cluster Setup | Servers and select a server for editing')
			));
			$this->forward('Index');
			return;
		}

		$form->setValues($node);
		
		if (($request->isPost()) && (Nodes_Element::STATUS_OFFLINE != $node->getStatus()) && $form->isValid($this->getTrimmedParams())) {
			try {
				$form->process();
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessageObject()));
				return;
			}
			$this->afterActionForward('Index', 'Nodes');
			return;
		}

		if (ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS == $node->getScStatus()) {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('This server is currently being removed and therefore can not be edited')));
		}
		
		if ($nodesModel->hasNodeInShutdownProcess()) {
			$form->setDisabled(true);
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('You can not edit a server while another server is being removed')));
		}
	
		if (Nodes_Element::STATUS_OFFLINE == $node->getStatus()) {
			$form->setDisabled(true);
			$this->setMessagePane(new MessagePane_Error(Zwas_Translate::_('This server is not responding')));
		}
		
	}
	
	public function updateServersAction() {
		$model = new Nodes_Model();
		$model->updateNodesState();
		$this->afterActionForward('Index', $this->controllerName);
	}
}