<?php
class EE_SessionClusteringController extends Zwas_Controller_MainContent {
	
	/**
	 * Turn the Zend Server component on
	 */
	public function activateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off
	 */
	public function deactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	/**
	 * Turn the Zend Server component off by force
	 */
	public function forceDeactivateAction() {
		Nodes_Action::remoteDistributeAction($this);
		Nodes_Model::refreshNodesState();
	}
	
	public function configurationAction() {
		$nodesModel = new Nodes_Model();
		
		if ($nodesModel->hasRespondingNodes()) {
			$this->view->configuration = new ZwasComponents_SessionClustering_Configuration();
			
			$action = new Nodes_Action();
			try {
				$response = $action->representativeAction('Node-Session-Clustering', 'Configuration');
				if ($response->isError()) {
					throw new Zwas_Exception((string)$response->getData());
				}
				$saveHandler = null;
				$data = $response->getData();
				/// Backwards compatibility for configuration based object responses
				if ($data instanceof ZwasComponents_SessionClustering_Configuration) {
					$this->view->configuration = $response->getData();
					$saveHandler = $this->view->configuration->getSessionHandler();
				} else {
					if ((! isset($data['scConfig']) || (! ($data['scConfig'] instanceof ZwasComponents_SessionClustering_Configuration)))) {
						throw new Zwas_Exception(
							Zwas_Translate::_('Session Clustering configuration could not be retrieved. Retry your last action and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center')
						);
					}
					$this->view->configuration = $data['scConfig'];
					$saveHandler = $data['session.save_handler'];
				}
				
				// Check if this page is displayed after a call to saveHandlerAction, in which case there will be a message set already
				if (! $this->isSetMessagePane()) {
					if (ZwasComponents_SessionClustering_Daemon_Model::SESSION_HANDLER_CLUSTER != $saveHandler) {
					
						$msgPane = new MessagePane_Info(
							new Zwas_Text(Zwas_Translate::_('The PHP session save handler is set to \'%s\'.  Click [a]here[/a] to automatically change the directive to support Session Clustering'), 
							array($saveHandler))
						);
						$msgPane->setLink(array(
							'controller'	=> $this->controllerName, 
							'action'		=> 'Save-Handler', 
							'sidebarId'		=> MenuItem::generateId($this->controllerName, 'Configuration'),
						));
	
						$this->setMessagePane($msgPane);
					}
				}
				
			} catch (Zwas_Exception $e) {
				$this->setMessagePane(new MessagePane_Error($e->getMessage()));
			}
			Nodes_Action::lockContentOnMixedCluster($this);
		} else {
			if ($nodesModel->hasNodes()) {
				$this->setMessagePane(new MessagePane_Info(
					Zwas_Translate::_('No response detected from cluster members. For more details, go to Cluster Setup | Servers'))
				);
			} else {
				$this->setMessagePane(new MessagePane_Info(Zwas_Translate::_('There are currently no servers connected to the Zend Server Cluster Manager. Go to Cluster Setup | Servers to add servers to the cluster')));
			}
			
			$this->renderScript('message.phtml');
			return;
		}
	}
	
	public function saveConfigurationAction() {
		try {
			ZwasComponents_SessionClustering_ConfigurationValidator::validate($this->_getAllParams());
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessage()));
			$this->forward('configuration');
			return;
		}
		
		// getting here means all validation was OK and the params in the request are legal
		
		$action = new Nodes_Action();
		try {
			$response = $action->distributeAction('Node-Session-Clustering', 'Save-Configuration', $this->_getAllParams());
			if ($response->isError()) {
				throw new Zwas_Exception((string)$response->getData());
			}
			
			$this->setMessagePane(
				new MessagePane_Notice('Configuration saved succesfuly, Restart each server\'s Zend Session Clustering daemon to apply changes')
			);
		} catch (Zwas_Exception $e) {
			$this->setMessagePane(new MessagePane_Error($e->getMessage()));
		}
		$this->forward('configuration');
	}

	public function saveHandlerAction() {
		$nodesAction = new Nodes_Action();
		try {
			$response = $nodesAction->distributeAction('Node-Session-Clustering', 'Save-Handler');
		} catch (Zwas_Exception $e) {
			$error = Zwas_Translate::_('Unable to send the request to the cluster members');
			Zwas_Log::logException($error, $e);
			$this->setMessagePane(new MessagePane_Error($error));
		}
		
		if ($response->isError()) {
			switch ($response->getCode()) {
				case 6009:
					$this->setMessagePane(new MessagePane_Error(Zwas_Translate::_('Zend Server could not change the directive. Check php.ini permissions and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center')));
					break;
				default:
					$this->setMessagePane(new MessagePane_Error(Zwas_Translate::_('An unexpected error has occured when trying to change the directive. Retry your action and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center')));
					break;
			}
		} else {
			$this->setMessagePane(new MessagePane_Notice(Zwas_Translate::_('The session save handler was successfully changed. Click Restart PHP to apply changes')));
		}

		$this->afterActionForward('Configuration', $this->controllerName);
	}
}
