<?php

class Form_Registration_DbCredentials extends Zwas_Form {
	
	const OPTION_CREATE_SCHEMA		= 1;
	const OPTION_SKIP_CREATE_SCHEMA	= 2;

	const DEFAULT_VALUE_PORT = 3306;
	
	private $dbManager;
	
	public function init() {
		parent::init();
		$this->addElement(self::getZendUsernameElement());
		$this->addElement(self::getZendPasswordElement());
		$this->addElement(self::getRootUsernameElement());
		$this->addElement(self::getRootPasswordElement());
		$this->addElement(self::getDbHostElement());
		$this->addElement(self::getDbPortElement());
		$this->addElement(self::getCreateSchemaElement());
		
		$this->populateElements();
	}
	
	public function process() {
		parent::process();
		$monitorModel = new ZwasComponents_ZSM_Monitor_Model();
		if (self::OPTION_CREATE_SCHEMA == $this->getValue('createSchema')) {
			$dbManager = $this->getDbManager();
			$monitorModel->createUserAndSchema($dbManager);
		} else {
			$dbManager = $this->getDbManager(ZwasComponents_ZSM_Monitor_DatabaseManager::ZEND_MONITOR_SCHEMA);
			$monitorModel->checkUserAndSchema($dbManager);
		}
		
		// call the monitor credentials saving routine
		// we use the existing db location parameters
		// but refer to the new zendUser and ZendUserPassword
		// values for credentials
		$monitorModel->saveMonitorDbCredentials(
			$this->getValue('dbhost'),
			$this->getValue('dbport'),
			$dbManager->getZendUser(),
			$dbManager->getZendUserPassword()
		);
		return true;
	}
	
	/**
	 * @param array $data
	 * @return boolean
	 */
	public function isValid($data) {
		$this->populate($data);
		if (self::OPTION_CREATE_SCHEMA == $this->getElement('createSchema')->getValue()) {
			$this->getElement('usernameRoot')->setRequired(true);
		} else {
			$this->getElement('usernameZend')->setRequired(true);
		}
		return parent::isValid($data);
	}

	/**
	 * @param ZwasComponents_ZSM_Monitor_DatabaseManager $dbManager the $dbManager to set
	 * @return Form_Registration_DbCredentials
	 */
	public function setDbManager(ZwasComponents_ZSM_Monitor_DatabaseManager $dbManager) {
		$this->dbManager = $dbManager;
		return $this;
	}
	
	/**
	 * @param string $dbName
	 * @return ZwasComponents_ZSM_Monitor_DatabaseManager
	 */
	private function getDbManager($dbName = null) {
		if (is_null($this->dbManager)) {
			
			if (self::OPTION_CREATE_SCHEMA == $this->getElement('createSchema')->getValue()) {
				$username = $this->getElement('usernameRoot')->getValue();
				$password = $this->getElement('passwordRoot')->getValue();
			} else {
				$username = $this->getElement('usernameZend')->getValue();
				$password = $this->getElement('passwordZend')->getValue();
			}
			
			$this->dbManager = new ZwasComponents_ZSM_Monitor_DatabaseManager(
				$this->getValue('dbhost'),
				$this->getValue('dbport'),
				$username,
				$password,
				$dbName
			);
		}
		return $this->dbManager;
	}
	
	/**
	 * @return Zwas_Form_Element_Text
	 */
	private static function getZendUsernameElement() {
		$username = new Zwas_Form_Element_Text('usernameZend');
		$username->setLabel('Database Username');
		return $username;
	}
	
	/**
	 * @return Zwas_Form_Element_Password
	 */
	private static function getZendPasswordElement() {
		$password = new Zwas_Form_Element_Password('passwordZend');
		$password->setLabel('Database Password');
		return $password;
	}
	
	/**
	 * @return Zwas_Form_Element_Text
	 */
	private static function getRootUsernameElement() {
		$username = new Zwas_Form_Element_Text('usernameRoot');
		$username->setLabel('Database Username');
		return $username;
	}
	
	/**
	 * @return Zwas_Form_Element_Password
	 */
	private static function getRootPasswordElement() {
		$password = new Zwas_Form_Element_Password('passwordRoot');
		$password->setLabel('Database Password');
		return $password;
	}
	
	/**
	 * @return Zwas_Form_Element_Text
	 */
	private static function getDbHostElement() {
		$dbhost = new Zwas_Form_Element_Text('dbhost');
		$dbhost->setLabel('Database Host')
			->setRequired(true);
			
		$dbHostValidator = new Form_Validate_NotLocalHost();
		$dbhost->addValidator($dbHostValidator);
		
		return $dbhost;
	}
	
	/**
	 * @return Zwas_Form_Element_Text
	 */
	private static function getDbPortElement() {
		$dbport = new Zwas_Form_Element_Text('dbport');
		$dbport->setLabel('Database Port')
			->setRequired(true)
			->addValidator(new Zwas_Validate_Port());
			
		return $dbport;
	}
	
	/**
	 * @return Zwas_Form_Element_Radio
	 */
	private static function getCreateSchemaElement() {
		$options = array(
			Form_Registration_DbCredentials::OPTION_CREATE_SCHEMA => Zwas_Translate::_('Create the database for me'),
			Form_Registration_DbCredentials::OPTION_SKIP_CREATE_SCHEMA => Zwas_Translate::_('I have already set up the database. Use these credentials as-is')
		);
		
		
		$createSchema = new Zwas_Form_Element_Radio('createSchema', array('escape' => false));
		$createSchema->setRequired(true)
						->addValidator(new Zend_Validate_InArray(array_keys($options)))
						->setValue(Form_Registration_DbCredentials::OPTION_CREATE_SCHEMA)
						->setMultiOptions($options);
						
		return $createSchema;
	}

	private function populateElements() {
		try {
			$monitorUi = new ZwasComponents_ZSM_MonitorUi_Model();
			$directives = $monitorUi->getNodeMonitorConfiguration();
		} catch (Zwas_Exception $e) {
			
		}
		// decide if to mark the option of creating a new schema by the password field
		$this->getElement('createSchema')->setValue(self::OPTION_CREATE_SCHEMA);
		if (isset($directives['zend_monitor.database.password']) && ('' != trim($directives['zend_monitor.database.password']))) {
			$this->getElement('createSchema')->setValue(self::OPTION_SKIP_CREATE_SCHEMA);
		}
		
		if (isset($directives['zend_monitor.database.host_name'])) {
			$this->getElement('dbhost')->setValue($directives['zend_monitor.database.host_name']);
		} else {
			$this->getElement('dbhost')->setValue('');
		}
		
		if (isset($directives['zend_monitor.database.port'])) {
			$this->getElement('dbport')->setValue($directives['zend_monitor.database.port']);
		} else {
			$this->getElement('dbport')->setValue(self::DEFAULT_VALUE_PORT);
		}
			
		$this->getElement('usernameZend')->setValue('zend');
		$this->getElement('usernameRoot')->setValue('root');
		if (isset($directives['zend_monitor.database.user'])) {
			$this->getElement('usernameZend')->setValue($directives['zend_monitor.database.user']);
		}
			
	}
	
	/**
	 * @param string $name
	 * @param array $data
	 * @return boolean
	 */
	private function isElementValid($name, $data) {
		if (isset($data[$name]) && $this->getElement($name)->isValid($data[$name])) {
			return true;
		}
		return false;
	}	
}
