<?php

class Form_Registration_LicenseEE extends Zwas_Form {
	
	public function init() {
		parent::init();
		
		$this->addElement(self::getCopyOrderNumberElement());
		$this->addElement(self::getZscmOrderNumberElement());
		$this->addElement(self::getZscmLicenseKeyElement());
		$this->addElement(self::getServerOrderNumberElement());
		$this->addElement(self::getServerLicenseKeyElement());
		
		$this->populateElements();
	}
	
	public function process() {
		parent::process();
		$this->saveZscmLicense();
		$this->saveServersLicense();
		return true;
	}
	
	protected function saveZscmLicense() {
    	$username	= $this->getValue('zscmOrderNumber');
		$licenseKey	= $this->getValue('zscmLicenseKey');
		Context_Version::getLicenseModel(array())->setLicense($username, $licenseKey);
    }
    
	protected function saveServersLicense() {
		if ('1' == $this->getValue('copyUsername')) {
			$orderNumber	= $this->getValue('zscmOrderNumber');
		} else {
			$orderNumber	= $this->getValue('serverOrderNumber');
		}
		$licenseKey	= $this->getValue('serverLicenseKey');
		ApplicationModel::setNodesLicense($orderNumber, $licenseKey);
    }    

    private function populateElements() {
    	$zscmLicenseDetails = License_Directives::getSystemLicenseDirectives();
    	
    	$this->getElement('zscmOrderNumber')->setValue($zscmLicenseDetails->getOrderNumber());
    	$this->getElement('zscmLicenseKey')->setValue($zscmLicenseDetails->getLicenseKey());
    	
    	try {
			$serverLicenseDetails = ApplicationModel::getNodesLicense();
		} catch (Zwas_Exception $e) {
			$serverLicenseDetails = new License_Directives();
		}
		    	
    	$this->getElement('serverOrderNumber')->setValue($serverLicenseDetails->getOrderNumber());
    	$this->getElement('serverLicenseKey')->setValue($serverLicenseDetails->getLicenseKey());
    	
    	$copyUsernameChecked = false;
		if (('' != $serverLicenseDetails->getOrderNumber()) &&
			($serverLicenseDetails->getOrderNumber() === $zscmLicenseDetails->getOrderNumber())) {
			
			$copyUsernameChecked = true;
		}

		$this->getElement('copyUsername')->setChecked($copyUsernameChecked);
    }
    
    /**
     * @return Zwas_Form_Element_Text
     */
    private static function getZscmOrderNumberElement() {
    	$zscmOrderNumber = new Zwas_Form_Element_Text('zscmOrderNumber');
		$zscmOrderNumber->setLabel(Zwas_Translate::_('Order number'))
			->addValidator(new Zend_Validate_StringLength(1));
			
		return $zscmOrderNumber;
    }
    
    /**
     * @return Zwas_Form_Element_Text
     */
    private static function getZscmLicenseKeyElement() {
    	$zscmLicenseKey = new Zwas_Form_Element_Text('zscmLicenseKey');
		$zscmLicenseKey->setLabel(Zwas_Translate::_('License Key'))
			->addValidator(new License_Validate_Key('license', Context_Version::EDITION_MANAGER));
			
		return $zscmLicenseKey;
    }
    
    /**
     * @return Zwas_Form_Element_Text
     */
    private static function getServerOrderNumberElement() {
    	$serverOrderNumber = new Zwas_Form_Element_Text('serverOrderNumber');
		$serverOrderNumber->setLabel(Zwas_Translate::_('Order number'))
			->addValidator(new Zend_Validate_StringLength(1));
		return $serverOrderNumber;
    }
    
    /**
     * @return Zwas_Form_Element_Text
     */
    private static function getServerLicenseKeyElement() {
    	$serverLicenseKey = new Zwas_Form_Element_Text('serverLicenseKey');
		$serverLicenseKey->setLabel(Zwas_Translate::_('License Key'))
			->addValidator(new License_Validate_Key('license', Context_Version::EDITION_PROFESSIONAL));
		return $serverLicenseKey;
    }
    
    /**
     * @return Zwas_Form_Element_Checkbox
     */
    private static function getCopyOrderNumberElement() {
    	$copyOrderNumber = new Zwas_Form_Element_Checkbox('copyUsername');
		$copyOrderNumber->setLabel(Zwas_Translate::_('Same as cluster manager\'s'));
		return $copyOrderNumber;
    }
}
