<?php

class Form_Servers_Abstract extends Zwas_Form {

	public function init() {
		parent::init();
		
		$urlDefaultValues = self::getUrlFromString('');
		
		$serverName = new Zwas_Form_Element_Text('name');
		$serverName->setLabel(Zwas_Translate::_('Server Name:'))
			->setRequired(true)
			->addValidator(new Zend_Validate_StringLength(1),true);
		
		$serverDistribute = new Zwas_Form_Element_Checkbox('distribute');
		$serverDistribute->setLabel(Zwas_Translate::_('Apply this server\'s PHP and Zend Components configuration to all other servers in the cluster'))
			->addValidator(new Zend_Validate_NotEmpty(),true);

		$serverScheme = new Zwas_Form_Element_Select('scheme');
		$serverScheme->setRequired(true)
			->setValue($urlDefaultValues->getScheme())
			->setMultiOptions(array(
				'http' => Zwas_Translate::_('http'), 
				'https' => Zwas_Translate::_('https'))
			);
		
		
		$serverAddress = new Zwas_Form_Element_Text('address');
		$serverAddress->setRequired(true)
			->addValidator(new Form_Validate_NotLocalHost(),true);
		
		$serverPort = new Zwas_Form_Element_Text('port');
		$serverPort->setValue($urlDefaultValues->getPort())
			->setRequired(true);
		
		$serverUri = new Zwas_Form_Element_Text('uri');
		$serverUri->setAttrib('disabled', 'disabled')
			->setValue(self::getUriFromPath($urlDefaultValues->getPath()))
			->setRequired(true)
			->addValidator(new Zend_Validate_Identical('ZendServer'),true);
		
		$this->addElement($serverName);
		$this->addElement($serverScheme);
		$this->addElement($serverAddress);
		$this->addElement($serverPort);
		$this->addElement($serverUri);
		$this->addElement($serverDistribute);
		
		$hostGroup = $this->addDisplayGroup(array('scheme', 'address', 'port', 'uri'), 'host')->getDisplayGroup('host');
		$hostGroup->setLegend(Zwas_Translate::_('Zend Server Address:'));
		$hostGroup->setDecorators(array(new Form_Decorator_ServerAddress()));
	}
	
	/**
	 * Create a server URL suitable for storage in the nodes table
	 * @return string
	 */
	public function getServerUrl() {
		return "{$this->getValue('scheme')}://{$this->getValue('address')}:{$this->getValue('port')}/ZendServer";
	}
	
	/**
	 * @param string $address
	 * @return array
	 */
	protected static function prepareUrlForPopulate($address) {
		$url = self::getUrlFromString($address);
		$urlArray = array(
			'scheme'	=> $url->getScheme(),
			'address'	=> $url->getHost(),
			'port'		=> $url->getPort(),
			'uri'		=> self::getUriFromPath($url->getPath()),
		);
		return $urlArray;
	}
	
	/**
	 * Convert an http://1.1.1.1:10081/ZendServer to a Zend_Uri object.  On error returns a clean one with the default values
	 * @param string $address
	 * @return Zend_Uri_Http
	 */
	protected static function getUrlFromString($address) {
		try {
			$url = Zend_Uri_Http::fromString($address);
		} catch (Exception $e) {
			$url = Zend_Uri::factory();
			$url->setPort(10081);
			$url->setPath('/ZendServer');
		}
		
		return $url;
	}
	
	
	/**
	 * Convert a Zend_Uri::getPath() string to a Uri part (e.g. '/ZendServer' to 'ZendServer')
	 * @param string $path
	 * @return string
	 */
	protected static function getUriFromPath($path) {
		return substr($path, 1);
	}
}

