<?php

class Form_Servers_Edit extends Form_Servers_Abstract {
	
	/**
	 * @var boolean
	 */
	private $disabled = false;
	
	/**
	 * @return boolean
	 */
	public function isDisabled() {
		return $this->disabled;
	}

	/**
	 * @param boolean $disabled
	 * @return Form_Servers_Edit
	 */
	public function setDisabled($disabled) {
		if ($this->disabled !== $disabled) {
			foreach($this->getElements() as $element) {/* @var Zend_Form_Element_Abstract $element */
				$element->setAttrib('disabled', $disabled ? 'disabled' : '');
			}
		}
		$this->disabled = $disabled;
		return $this;
	}

	public function init() {
		parent::init();
		
		$serverId = new Zend_Form_Element_Hidden('serverId');
		$serverId->setRequired(true);
		$serverId->setDecorators(array('ViewHelper'));
		
		$serverId->addValidator(new Zend_Validate_NotEmpty());
		
		$this->getElement('address')->setAttrib('disabled', 'disabled');
		$this->getElement('address')->setRequired(false);
		
		$this->addElement($serverId);
	}
	
	/**
	 * @return string
	 */
	public function process() {
		parent::process();
		$model = new Nodes_Model();
		$node = $model->getNode($this->getValue('serverId'));
		if ($this->getValue('serverId') != $node->getId()) {
			throw new Zwas_Exception(Zwas_Translate::_('Return to Cluster Setup | Servers and select a server for editing'));
		}
		
		// override any incoming value for URI and host address with the existing values
		$url = self::prepareUrlForPopulate($node->getAddress());
		$this->getElement('address')->setValue($url['address']);
		$this->getElement('uri')->setValue($url['uri']);
		
		$node->setAddress($this->getServerUrl());
		$node->setName($this->getValue('name'));
		
		$node->save();
		return true;
	}

	public function setValues(Nodes_Element_Mapper $node) {
		$this->getElement('serverId')->setValue($node->getId());
		$this->getElement('name')->setValue($node->getName());
		
		$url = self::getUrlFromString($node->getAddress());
		$this->getElement('scheme')->setValue($url->getScheme());
		$this->getElement('address')->setValue($url->getHost());
		$this->getElement('port')->setValue($url->getPort());
		$this->getElement('uri')->setValue(self::getUriFromPath($url->getPath()));
		
	}
}

