<?php

class Form_Validate_NotLocalHost extends Zend_Validate_Abstract {
	
	const LOCALHOST_NOT_ALLOWED = 1;
	const INVALID_REMOTE_IP = 2;
	const INVALID_HOSTNAME = 3;
	
	/**
	 * @var array
	 */
	private $illegalPatterns;
	
	/**
	 * @var Zend_Validate_Hostname
	 */
	private $hostnameValidator;
	
	/**
	 * @var Zwas_Validate_RemoteIp
	 */
	private $ipValidator;
	
	public function __construct() {
		$this->hostnameValidator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_DNS | Zend_Validate_Hostname::ALLOW_LOCAL);
		$this->hostnameValidator->setMessages(array(
	        Zend_Validate_HostName::INVALID                 => Zwas_Translate::_('The accepted values for this field are strings'),
	        Zend_Validate_HostName::IP_ADDRESS_NOT_ALLOWED  => Zwas_Translate::_("'%value%' appears to be an IP address, but IP addresses are not allowed"),
	        Zend_Validate_HostName::UNKNOWN_TLD             => Zwas_Translate::_("The accepeted values are remote hostnames or remote IPs"),
	        Zend_Validate_HostName::INVALID_DASH            => Zwas_Translate::_("'%value%' appears to be a DNS hostname but contains a dash (-) in an invalid position"),
	        Zend_Validate_HostName::INVALID_HOSTNAME_SCHEMA => Zwas_Translate::_("The accepeted values are remote hostnames or remote IPs"),
	        Zend_Validate_HostName::UNDECIPHERABLE_TLD      => Zwas_Translate::_("The accepeted values are remote hostnames or remote IPs"),
	        Zend_Validate_HostName::INVALID_HOSTNAME        => Zwas_Translate::_("'%value%' does not match the expected structure for a DNS hostname"),
	        Zend_Validate_HostName::INVALID_LOCAL_NAME      => Zwas_Translate::_("'%value%' does not appear to be a valid local network name"),
	        Zend_Validate_HostName::LOCAL_NAME_NOT_ALLOWED  => Zwas_Translate::_("'%value%' appears to be a local network name but local network names are not allowed"),
	        Zend_Validate_HostName::CANNOT_DECODE_PUNYCODE  => Zwas_Translate::_("'%value%' appears to be a DNS hostname but the given punycode notation cannot be decoded")
    	));
    	
		/// we need to extract the remoteIp validator due to a logical issue in zend_validate_hostname
		$this->ipValidator = new Zwas_Validate_RemoteIp();
		$this->illegalPatterns = array('localhost');
		$this->_messageTemplates = array(
			self::LOCALHOST_NOT_ALLOWED => Zwas_Translate::_("'%value%' is a loopback host. An external interface address is needed"),
			self::INVALID_REMOTE_IP => Zwas_Translate::_("%value%"),
			self::INVALID_HOSTNAME => Zwas_Translate::_("%value%"),
		);
	}
	
	/**
	 * @param $illegalPatterns the $illegalPatterns to set
	 * @return Form_Validate_NotLocalHost
	 */
	public function setIllegalPatterns($illegalPatterns) {
		$this->illegalPatterns = $illegalPatterns;
		return $this;
	}

	public function isValid($value) {
		if (in_array($value, $this->illegalPatterns)) {
			$this->_error(self::LOCALHOST_NOT_ALLOWED, $value);
			return false;
		}
		
		$validHostname = $this->hostnameValidator->isValid($value);
		$validIpAdress = $this->ipValidator->isValid($value);
		
		/// figure out which error message is relevant
		if ((! $validHostname) && (! $validIpAdress)) {
			if (in_array(Zend_Validate_Hostname::IP_ADDRESS_NOT_ALLOWED, $this->hostnameValidator->getErrors())) {
				$this->_error(self::INVALID_REMOTE_IP, current($this->ipValidator->getMessages()));
			} else {
				$this->_error(self::INVALID_HOSTNAME, current($this->hostnameValidator->getMessages()));
			}
		}
		
		return $validHostname || $validIpAdress;
	}
}