<?php
class Cluster_ConfigurationData extends Node_ConfigurationData {
	
	/**
	 * @var string
	 */
	private $eventRulesXml;
	
	/**
	 * ExportConfiguration data constructor
	 */
	public function __construct(Node_Environment $zendEnvironment) {
		parent::__construct($zendEnvironment);
		$this->eventRulesXml = basename(ZwasComponents_Monitor_Model::getXMLFile());
	}
	
	/**
	 * @return Node_ConfigurationData
	 */
	public function produceNodeConfiguration() {
		$clusterNodeFiles = array_slice($this->zendServerConfigurations, 0, count($this->zendServerConfigurations), true);
		if(isset($clusterNodeFiles[$this->eventRulesXml])) {
			$clusterEventRules = clone $clusterNodeFiles[$this->eventRulesXml];
			$clusterParser = new ZwasComponents_Monitor_Xml_Modifier($clusterEventRules->getFileContent());
			
			foreach ($clusterParser->getRules() as $ruleId => $rule) {
				if (strpos($rule->getType(), 'zsm') !== false) {
					$clusterParser->deleteRule($ruleId);
				}
			}
			$clusterParser->save();
			$clusterEventRules->setFileContent($clusterParser->getSavedXml());
			$clusterNodeFiles[$this->eventRulesXml]= $clusterEventRules;
		}
		$nodeConfig = new Node_ConfigurationData($this->zendEnvironment);
		$nodeConfig->setZendServerConfigurations($clusterNodeFiles);
		return $nodeConfig;
	}
	
	/**
	 * Mash together the current manager's configuration with the representative's configuration.
	 * The result will be a node-consumable configuration data object that can be distributed freely.
	 * 
	 * Since this mashup is performed per file, each file will require special handling - or none at all.
	 * @param Node_ConfigurationData $repConfig
	 * @return Node_ConfigurationData
	 */
	public function mashupConfigurationFiles(Node_ConfigurationData $repConfig) {
		$configFiles = $repConfig->getZendServerConfigurations();
		$filteredConfigFiles = array();
		
		if ((isset($configFiles[$this->eventRulesXml]))
		&& (isset($this->zendServerConfigurations[$this->eventRulesXml]))) {
			$filteredConfigFiles[$this->eventRulesXml] = $this->mashUpEventRulesXml($configFiles[$this->eventRulesXml]);
		}
		
		$repConfig->cleanZendServerConfigurations();
		$repConfig->setZendServerConfigurations($filteredConfigFiles);
		return $repConfig;
	}
	
	
	
	/**
	 * @param Node_FileObject $eventRules
	 * @return Node_FileObject
	 */
	protected function mashUpEventRulesXml(Node_FileObject $eventRules) {
		$clusterEventRules = $this->zendServerConfigurations[$this->eventRulesXml];
		$repParser = new ZwasComponents_Monitor_Xml_Modifier($eventRules->getFileContent());
		$clusterParser = new ZwasComponents_Monitor_Xml_Modifier($clusterEventRules->getFileContent(),
									Zwas_Path::create(Context_Api::getPhpMemory()->getCfgVar('zend.conf_dir'), $clusterEventRules->getFileNameWithSubPath()));
		
		/// clean up zscm's non-zsm rules
		foreach ($clusterParser->getRules() as $ruleId => $rule) {
			if (strpos($rule->getType(), 'zsm') === false) {
				$clusterParser->deleteRule($ruleId);
			}
		}
		
		foreach ($repParser->getRules() as $ruleId => $rule) {/* @var $rule ZwasComponents_Monitor_Rule */
			if (strpos($rule->getType(), 'zsm') !== false) {
				// clear out the zsm rules from the rep's rules
				$repParser->deleteRule($ruleId);
			} else {
				// add rep's PE rules
				$clusterParser->addRule($rule);
			}
		}
		
		/// representative should save back into the node file 
		/// object since we have no local file path to save to
		$eventRules->setFileContent($repParser->save());
		/// cluster can save locally on its own path
		$clusterParser->save();
		$clusterEventRules->setFileContent($clusterParser->getSavedXml());
		return $eventRules;
	}
	
}