<?php

class Cluster_Status {

	/**
	 * Get a message describe the nodes status
	 * Cache this message for 3600 seconds
	 *
	 * @return string
	 */
	public static function getNodesStatusMessage() {
		$cache		= Context_Cache::getCache();
		$cacheKey	= 'Cluster_Status::getNodesStatusMessage';
		
		$message	= '';
		
		if (! $cache->exist($cacheKey) ) {
			try {
				$nodesModel = new Nodes_Model();
			} catch (Zwas_Exception $e) {
				// do nothing
			}
			$cache->store($cacheKey, 'node-status', 3600);
		}
			
		if (self::clusterHasNodeInOfflineState()) {
			$message = Zwas_Translate::_('Some of your servers can not be reached. Go to Cluster Setup | Servers for details');
		}
		if (self::clusterHasNodeInvalidState()) {
			$message = Zwas_Translate::_('Some of your servers are in an error state. Go to Cluster Setup | Servers for details');
		}
		
		if (self::clusterHasNodeAwaitRestart() ){
			$message = Zwas_Translate::_('Your cluster\'s PHP needs to be restarted ');
		}
		
		return $message;
	}
	
	/**
	 * Check if there is at least one node with error
	 * @return boolean
	 */
	private static function clusterHasNodeInvalidState() {
		$nodesModel = new Nodes_Model();
		return ($nodesModel->hasNodeInvalid());
	}
	
	/**
	 * Check if there is at least one off line node
	 * @return boolean
	 */
	private static function clusterHasNodeInOfflineState() {
		$nodesModel = new Nodes_Model();
		foreach ($nodesModel->getEnabledNodes() as $node) { /* @var $node Nodes_Element_Mapper */
			if (Nodes_Element::STATUS_OFFLINE == $node->getStatus()) {
				return true;
			}
		}
		return false;
	}
	
	/**
	 * check if there is at least one node await restart
	 * @return boolean
	 */
	private static function clusterHasNodeAwaitRestart() {
		$nodesModel = new Nodes_Model();
		foreach ($nodesModel->getEnabledNodes() as $node) { /* @var $node Nodes_Element_Mapper */
			if ($node->awaitsRestart()) {
				return true;
			}
		}
		return false;
	}
}