<?php

class ClusterPhpExtensions_Model {
	
	
	/**
	 * @param string $extensionName
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getExtensionsWithMessagesByExtensionName($extensionName) {
		$extensionsRowset = Context_Db::getNodesExtensionTable()->getExtensionsWithMessagesByExtensionName($extensionName);
		$extensions = array();
		foreach ($extensionsRowset as $extensionElement) { /* @var $extensionElement Nodes_Extension_Element */
			$extensions[]= $extensionElement;
		}
		return $extensions;
	}
	
	/**
	 * @return array
	 */
	public function getExtensionsWithMessages() {
		$extensionsRowset = Context_Db::getNodesExtensionTable()->getExtensionsWithMessages();
		$extensions = array();
		foreach ($extensionsRowset as $extensionElement) { /* @var $extensionElement Nodes_Extension_Element */
			if (array_key_exists($extensionElement->getName(), $extensions)) {
				$extensions[$extensionElement->getName()][]= $extensionElement;
			} else {
				$extensions[$extensionElement->getName()] = array($extensionElement);
			}
		}
		return $extensions;
	}
	
	/**
	 * @param string $extensionName
	 * @return boolean
	 */
	public function extensionExists($extensionName) {
		return (0 < Context_Db::getNodesExtensionTable()->getExtension($extensionName)->count());
	}

	/**
	 * @param string $extensionName
	 * @return boolean
	 */
	public function isExtensionUnstable($extensionName) {
		return Context_Db::getNodesExtensionTable()->isExtensionUnstable($extensionName);
	}

	/**
	 * @param string $extensionName
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getExtension($extensionName) {
		return Context_Db::getNodesExtensionTable()->getExtension($extensionName);
	}
	
	/**
	 * @param string $extensionName
	 * @return Nodes_Extension_Element
	 */
	public function getRepresentativeExtension($extensionName) {
		$nodes = new Nodes_Model();
		try {
			$representative = $nodes->getRepresentativeForReading();
		} catch (Zwas_Exception $e) {
			return Context_Db::getNodesExtensionTable()->createRow();
		}

		return Context_Db::getNodesExtensionTable()->getNodeExtension($extensionName, $representative->getId());
	}

	/**
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getRepresentativeExtensions() {
		$nodes = new Nodes_Model();
		try {
			$representative = $nodes->getRepresentativeForReading();
		} catch (Zwas_Exception $e) {
			Zwas_Log::warn((string)$e->getMessageObject());
			return new Zend_Db_Table_Rowset(array());
		}
		
		return Context_Db::getNodesExtensionTable()->getNodeExtensions($representative->getId());
	}
	
	/**
	 * @param Zend_Db_Table_Rowset_Abstract $extensions
	 * @return array
	 */
	public static function sortExtensions(Zend_Db_Table_Rowset_Abstract $extensions) {
		$sortedExtensions = array();
		
		foreach ($extensions as $extension) { /* @var $extension Nodes_Extension_Element */
			$sortedExtensions[ strtolower($extension->getName()) ] = $extension;
		}
		ksort($sortedExtensions);
		
		return $sortedExtensions;
	} 
}