<?php
class ClusterZendComponents_Model {
	
	/**
	 * @param string $componentName
	 * @return array
	 */
	public function getComponentMessages($componentName) {
		$select = Context_Db::getZsmAdapter()->select();
		
		$select->from('nodes')
			->join('component', 'nodes.id = component.nodeId')
			->where('component.name = ?', $componentName)
			->where('component.errorString != \'\'')
			->where('nodes.disabled = 0')
			->where('nodes.status != ?', Nodes_Element::STATUS_OFFLINE);
			
		$result = array();
		$nodesComponentsTable = Context_Db::getNodesComponentTable(); 
		foreach ($select->query()->fetchAll() as $row) {
			$result[] = $nodesComponentsTable->createRow($row);
		}
		
		return $result;
	}
	
	/**
	 * @param string $componentName
	 * @return boolean
	 */
	public function isComponentUnstable($componentName) {
		return Context_Db::getNodesComponentTable()->isComponentUnstable($componentName);
	}
	
	/**
	 * @return array
	 */
	public function getComponentsWithMessages() {
		$componentsRowset = Context_Db::getNodesComponentTable()->getComponentsWithMessages();
		$components = array();
		foreach ($componentsRowset as $componentElement) { /* @var $componentElement Nodes_Component_Element */
			if (array_key_exists($componentElement->getName(), $components)) {
				$components[$componentElement->getName()][]= $componentElement;
			} else {
				$components[$componentElement->getName()] = array($componentElement);
			}
		}
		return $components;
	}
	
	/**
	 * @param string $componentName
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getComponent($componentName) {
		return Context_Db::getNodesComponentTable()->getComponent($componentName);
	}
	
	/**
	 * @param string $componentName
	 * @return boolean
	 */
	public function componentExists($componentName) {
		return (0 < Context_Db::getNodesComponentTable()->getComponent($componentName)->count());
	}

	/**
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getRepresentativeComponents() {
		$nodes = new Nodes_Model();
		try {
			$representative = $nodes->getRepresentativeForReading();
		} catch (Zwas_Exception $e) {
			Zwas_Log::warn((string)$e->getMessageObject());
			return new Zend_Db_Table_Rowset(array());
		}
		
		return Context_Db::getNodesComponentTable()->getNodeComponents($representative->getId());
	}

	/**
	 * @param string $componentName
	 * @return Nodes_Component_Element
	 */
	public function getRepresentativeComponent($componentName) {
		$nodes = new Nodes_Model();
		try {
			$representative = $nodes->getRepresentativeForReading();
		} catch (Zwas_Exception $e) {
			return Context_Db::getNodesComponentTable()->createRow();
		}

		return Context_Db::getNodesComponentTable()->getNodeComponent($componentName, $representative->getId());
	}
	
	/**
	 * @param Zend_Db_Table_Rowset_Abstract $components
	 * @return array
	 */
	public static function sortComponents(Zend_Db_Table_Rowset_Abstract $components) {
		$sortedComponents = array();
		
		foreach ($components as $component) { /* @var $component Nodes_Component_Element */
			$sortedComponents[ strtolower($component->getName()) ] = $component;
		}
		ksort($sortedComponents);
		
		return $sortedComponents;
	} 	
}