<?php

abstract class Communication_Queue_Abstract {

	/**
	 * @var array
	 */
	private $settings = array();
	/**
	 * @var integer
	 */
	private $timeout = 60;
	/**
	 * @var array
	 */
	protected $requestObjects = array();
	/**
	 * @var Nodes_Response_Wrapper
	 */
	protected $nodesResponseWrapper;
	/**
	 * @var Zwas_Http_Client_Adapter
	 */
	protected $adapter;
	
	public function __construct() {
		$this->nodesResponseWrapper = new Nodes_Response_Wrapper();
	}
	
	/**
	 * @param Zwas_Http_Client_Adapter $adapter
	 */
	public function setAdapter($adapter) {
		$this->adapter = $adapter;
	}
	
	/**
	 * @param array $params
	 * @return Node_Response
	 */
	public abstract function sendRequest();

	/**
	 * @param array $params
	 * @return array of Nodes_Response
	 */
	public abstract function sendRequests();
	
	/**
	 * @param array $params
	 * @param string $uri
	 * @param boolean $representative
	 * @return Communication_Queue_Request_Interface
	 */
	public abstract function makeRequest($params = array(), $uri, $representative=false);
	
	/**
	 * @param Communication_Queue_Request_Interface $request
	 */
	public function attachRequest(Communication_Queue_Request_Interface $request) {
		$this->requestObjects[] = $request;
	}
	
	/**
	 * @return Nodes_Response_Wrapper
	 */
	public function getNodesResponseWrapper() {
		return $this->nodesResponseWrapper;
	}
	
	/**
	 * @return Communication_Queue_Request_Interface array
	 */
	public function getRequestObjects() {
		return $this->requestObjects;
	}
	
	/**
	 * Clear out the request objects array
	 */
	public function clearRequestObjects() {
		$this->requestObjects = array();
	}
	
	/**
	 * Extracts the first item off the requests array and returns the item.
	 * @return Communication_Queue_Request_Interface
	 */
	public function shiftRequestObject() {
		return array_shift($this->requestObjects);
	}
	
	/**
	 * @param integer $i
	 * @return Communication_Queue_Request_Interface
	 */
	public function getRequestObject($i) {
		if (isset($this->requestObjects[$i])) {
			return $this->requestObjects[$i];
		}
		throw new Zwas_Exception(Zwas_Translate::_('Unable to retrieve request object'), Zwas_Exception::ASSERT);
	}
	
	/**
	 * @param integer $timeout
	 */
	public function setTimeout($timeout) {
		$this->timeout = $timeout;
	}

	/**
	 * @return integer
	 */
	public function getTimeout() {
		return $this->timeout;
	}

}