<?php

class Communication_Queue_PeclHttp extends Communication_Queue_Abstract {
	
	/**
	 * @return Nodes_Response
	 */
	public function sendRequest() {
		$request = $this->shiftRequestObject();
		$response = null;
		try{
			$request->send();
		} catch (HttpException $e) {
			$response = Node_Response::factory(
				new Communication_Queue_Exception($e->getMessage(), $e->getCode()),
				4000, Zwas_Translate::_('Unable to communicate with the server'));
		}
		
		if (null === $response) {
			try {
				$response = Zwas_Package::unpack($request->getResponseBody());
				
			} catch (Zwas_Exception $e) {	// data error
				$response = Node_Response::factory($e, 4017, Zwas_Translate::_('Cluster Manager could not extract data from the server\'s response. If the problem persists, contact your system administrator'));
			}
		}
		
		return $this->nodesResponseWrapper->wrap($response, $request);
	}
	
	/**
	 * @return array of Nodes_Response
	 */
	public function sendRequests() {
		$httpRequestPool = new HttpRequestPool();
		$responses = array();
		 
		$requests = $this->getRequestObjects();
		$this->clearRequestObjects();
		foreach ($requests as $httpRequest) {
			$httpRequestPool->attach($httpRequest);
		}
		

		try {
			$httpRequestPool->send();
		} catch (HttpRequestPoolException $e) {
			/// ignore the exception, we need to tie in each response to its node
		}
		
		foreach ($httpRequestPool->getFinishedRequests() as $httpRequest) {
			if ($httpRequest->getResponseCode()) {
				try {
					$response = Zwas_Package::unpack($httpRequest->getResponseBody());
					
				} catch (Zwas_Exception $e) {	// data error
					$response = Node_Response::factory($e, 4017, Zwas_Translate::_('Cluster Manager could not extract data from the server\'s response. If the problem persists, contact your system administrator'));
				}
			} else {
				$response = Node_Response::factory(Zwas_Translate::_('Unable to communicate with the server'), 4004, Zwas_Translate::_('HTTP Error - server is unreachable'));
			}
			
			// We can not set a nodeId as a key here because we do not know if any nodeId is set
			$responses[] = $this->nodesResponseWrapper->wrap($response, $httpRequest);
			$httpRequestPool->detach($httpRequest);
		}
		$httpRequestPool->reset();
		$httpRequestPool->__destruct();
		unset($httpRequestPool);
		
		return $responses;
	}
	
	/**
	 * @param array $params
	 * @param string $uri
	 * @param boolean $representative
	 * @return Communication_Queue_Request_Interface
	 */
	public function makeRequest($params = array(), $uri, $representative=false) {
		$uri = rtrim($uri, '/') . '/index.php';
		$httpRequest = new Communication_Queue_Request_PeclHttp($uri, HttpRequest::METH_POST, $representative);
		
		if ($this->getTimeout()) {
			$httpRequest->setOptions(array('timeout' => $this->getTimeout()));	
		}
		
		$httpRequest->setOptions(array('useragent' => ZEND_SERVER_USER_AGENT));
		$httpRequest->setPostFields($params);
		
		return $httpRequest;
	}
	
}