<?php

class Communication_Queue_Zend extends Communication_Queue_Abstract {
	
	/**
	 * @return Nodes_Response
	 */
	public function sendRequest() {
		$request = $this->shiftRequestObject();
		$nodeResponse = $this->send($request);
		return $this->getNodesResponseWrapper()->wrap($nodeResponse, $request);
	}
	
	/**
	 * @return array of Nodes_Response
	 */
	public function sendRequests() {
		$nodesResponses = array();
		$requests = $this->getRequestObjects();
		$this->clearRequestObjects();
		foreach ($requests as $request) {
			try {
				$nodeResponse = $this->send($request);
			} catch (Exception $e) {
				$nodeResponse = Node_Response::factory(Zwas_Translate::_('Unable to communicate with the server'), 4004, Zwas_Translate::_('HTTP Error - server is unreachable'));
			}
			$nodesResponses[] = $this->getNodesResponseWrapper()->wrap($nodeResponse, $request);
		}
		return $nodesResponses;
	}
	
	/**
	 *
	 * @param array $params
	 * @param string $uri
	 * @param boolean $representative
	 * @return Communication_Queue_Request_Interface
	 */
	public function makeRequest($params = array(), $uri, $representative=false) {
		$requestObject = new Communication_Queue_Request_Zend($representative);
		
		if ($this->getAdapter()) {
			$requestObject->setAdapter($this->getAdapter());
		}
		if ($this->getTimeout()) {
			$requestObject->setConfig(array('timeout' => $this->getTimeout()));
		}
		
		$uri = rtrim($uri, '/') . '/index.php';
		$requestObject->resetParameters()->setConfig(array('keepalive' => true, 'useragent' => ZEND_SERVER_USER_AGENT))->setParameterPost($params)->setMethod(Zend_Http_Client::POST)->setUri($uri);
		return $requestObject;
	}
	
	/**
	 * @return Zwas_Http_Client_Adapter
	 */
	public function getAdapter() {
		return $this->adapter;
	}
	
	/**
	 * @param Communication_Queue_Request_Zend $request
	 * @return Node_Response
	 */
	private function send($request) {
		if ($this->adapter) {
			$request->setAdapter($this->getAdapter());
		}
		try {
			$httpResponse = $request->request();
		} catch (Zend_Http_Client_Exception $e) { // communication error (e.g. no network connection)
			return Node_Response::factory(
				new Communication_Queue_Exception($e->getMessage(), $e->getCode()),
			 	4000, Zwas_Translate::_('Unable to communicate with the server'));
		}
		
		if ($httpResponse->isError()) { // HTTP error (e.g. 404, 500, etc.)
			// 4004 does not represent all HTTP errors
			// the data segment contains the real HTTP code
			return Node_Response::factory($httpResponse->getStatus(), 4004, Zwas_Translate::_('HTTP Error - server is unreachable'));
		}
				
		try {
			return Zwas_Package::unpack($httpResponse->getBody());
		} catch (Zwas_Exception $e) { // data error
			return Node_Response::factory($e, 4017, Zwas_Translate::_('Cluster Manager could not extract data from the server\'s response. If the problem persists, contact your system administrator'));
		}
	}
}