<?php

class GracefulShutdown implements Zwas_Semaphore_Interface {

	const NS 		= 'ZEND_SERVER_GRACEFUL_SHUTDOWN';
	const THRESHOLD	= 15;
	
	/**
	 * Initializes the session name space with the content of the request parameters
	 */
	public static function init($time = null) {
        $ns = new Zend_Session_Namespace(self::NS);
        if (is_null($time)) {
        	$time = time();
        }
        $ns->content	= $time;
	}
	
	public static function destroy() {
		try {
			Zend_Session::namespaceUnset(self::NS);
		} catch (Zend_Session_Exception $e) {
			Zwas_Log::logException(Zwas_Translate::_('Unable to unset the graceful shutdown flag'), $e);
		}
	}
	
	/**
	 * @return integer
	 */
	public static function getValue() {
		$ns = new Zend_Session_Namespace(self::NS);
	    return $ns->content;
	}
	/**
	 * Returns the time left for automated refresh
	 * This method guarantees a minimum of 0
	 * @return integer
	 */
	public static function getTimeLeft() {
		if (is_null(self::getValue())) {
			return 0;
		}
		return max(0, self::THRESHOLD - (time() - self::getValue()));
	}

	/**
	 * @return boolean
	 */
	public static function isInitialized() {
		$ns = new Zend_Session_Namespace(self::NS);
	    return (! is_null($ns->content));
	}
}
