<?php
class License_Model_EE extends License_Model_Abstract {
	/**
     * Sets a license key and username after validation
     *
     * @param string $username
     * @param string $licenseKey
     * @return boolean Returns true if a restart is required
     * @throws Zwas_Exception
     */
    public function setLicense($username, $licenseKey) {
		
    	$this->validateLicenseInputs($username, $licenseKey, Context_Version::EDITION_MANAGER);
    	
		try {
			$directivesModel = new Directives_Model();
			$directivesModel->saveDirectives(array(	self::$serialNumberDirective => $licenseKey,
													self::$userNameDirective 	 => $username));
		} catch (Zwas_Exception $e) {
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Failed to save the new license: %s'), array($e->getMessageObject())));
		}
		return true;
    }
    
	/**
	 * Verifies if the license is valid, if no - throws exception
	 * @return boolean
	 * @throws Zwas_Exception
	 */
	public function verifyLicense() {
		
		if (! $this->isValid()) {
			if ('' === $this->getSerialNumber()) {
				throw new Zwas_Exception(Zwas_Translate::_('The Cluster Manager\'s license key is not set'));
			}
			if ($this->isSignatureInvalid()) {
				throw new Zwas_Exception(Zwas_Translate::_('The Cluster Manager\'s license key is not valid'));
			}
			if ($this->isExpired()) {
				throw new Zwas_Exception(Zwas_Translate::_('The Cluster Manager\'s license has expired'));
			}
			throw new Zwas_Exception(Zwas_Translate::_('The Cluster Manager\'s license key is not valid'));
		}
		return true;
	}	
    
}