<?php
class License_Model_Nodes extends License_Model_Abstract {
	
	public function __construct($licenseInfo = null) {
		if (is_null($licenseInfo)) {
			$nodesLicense = ApplicationModel::getNodesLicense();
			$licenseInfo = Context_Api::getUtilAPI()->
							getSerialNumberInfo($nodesLicense->getLicenseKey(), $nodesLicense->getOrderNumber());
		}
		parent::__construct($licenseInfo);
	}
	
	/**
     * Sets a license key and username after validation
     *
     * @param string $username
     * @param string $licenseKey
     * @return boolean Returns true if a restart is required
     * @throws Zwas_Exception
     */
    public function setLicense($username, $licenseKey) {
		ApplicationModel::setNodesLicense($username, $licenseKey);
		return false;
    }
    
	/**
	 * Verifies if the license is valid, if no - throws exception
	 * @return boolean
	 * @throws Zwas_Exception
	 */
	public function verifyLicense() {
		if (! $this->isValid()) {
			if ('' === $this->getSerialNumber()) {
				throw new Zwas_Exception(Zwas_Translate::_('The cluster members\' license key is not set, limiting the availability of certain features. To resolve, re-enter your cluster members\' license in the Administration tab'));
			}
			if ($this->isSignatureInvalid()) {
				throw new Zwas_Exception(Zwas_Translate::_('The cluster members\' license key is not valid, limiting the availability of certain features. To resolve, re-enter your cluster members\' license in the Administration tab'));
			}
			if ($this->isExpired()) {
				throw new Zwas_Exception(Zwas_Translate::_('The cluster members\' license has expired, limiting the availability of certain features. To resolve, enter a valid cluster members\' license in the Administration tab'));
			}
			throw new Zwas_Exception(Zwas_Translate::_('The cluster members\' license key is not valid, limiting the availability of certain features. To resolve, re-enter your cluster members\' license in the Administration tab'));
		}
		return true;
	}	
    
}