<?php

class Metadata_Table extends Zend_Db_Table_Abstract {
	
	protected $_name		= 'metadata';
	protected $_primary		= 'id';
	
	/**
	 * @return string the current database version
	 * @throws Metadata_Exception
	 * @throws Zwas_Db_Exception
	 */
	public function getCurrentVersion() {
		try {
			$row = $this->fetchRow("name='version'", 'value DESC');
		} catch (Zend_Db_Exception $e) {
			throw new Zwas_Db_Exception($e->getMessage(), Zwas_Exception::ERROR);
		}
		if (is_null($row) || (! isset($row->value))) {
			throw new Metadata_Exception(Zwas_Translate::_('Corrupted Cluster Managers\' internal UI database detected'));
		}
		return $row->value;
	}
	
	/**
	 * @return boolean
	 */
	public function isLatestVersion() {
		try {
			if (Context_Db_Factory::CLUSTER_DB_VERSION === $this->getCurrentVersion()) {
				return true;
			}
		} catch (Zwas_Db_Exception $e) {
			Zwas_Log::logException('Could not verify DB version', $e);
		}
		return false;
	}
	
	/**
	 * @param $currentMaxId - the current maximal server ID for fallback - in case the table was corrupted
	 * @return integer the ID for the next node to insert
	 */
	public function getNextServerId($currentMaxId = 0) {
		$row = $this->fetchRow("name='nextServerId'", 'value DESC');
		if (is_null($row) || (! isset($row->value))) {
			$row = $this->createRow();
			$row->name	= 'nextServerId';
			$row->value	= $currentMaxId + 1;
		}
		
		$returnValue = $row->value;
		
		// increment the value for the next time
		$row->cdate	= time();
		$row->value++;
		$row->save();
		
		return $returnValue;
	}
}