<?php
class Nodes_Collection extends Zwas_Collection {
	
	/**
	 * @param array $items
	 */
	public function __construct($items = array()) {
		foreach($items as $node) {/* @var $node Nodes_Element_Mapper */
			$this->items[$node->getId()]= $node;
		}
	}
	/**
	 * @return Nodes_Collection
	 */
	public function setCollectionAwaitsRestart() {
		foreach($this->items as $node) {/* @var Nodes_Element_Mapper $node */
			$node->setAwaitRestart(true);
		}
		return $this;
	}
	
	public function hasOnlineNodes() {
		return $this->getOnlineCounter() > 0;
	}
	
	public function getOnlineCounter() {
		return $this->scanNodesOnline()->count();
	}
	
	/**
	 * @return boolean
	 */
	public function hasInProcess() {
		return ($this->getInProcessCounter() > 0);
	}
	
	/**
	 * @return integer
	 */
	public function getInProcessCounter() {
		return $this->scanNodesSessionClusteringInProcess()->count();
	}

	/**
	 * Scan for that were previously in process of shutting down session clustering
	 * @return Nodes_Collection
	 */
	public function scanNodesPreviousScStatusInProcess() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
				&& ($item->getPreviousScStatus() == ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS)) {
					
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	/**
	 * Scan collection for in process nodes.
	 * @return Nodes_Collection of nodes
	 */
	public function scanNodesSessionClusteringInProcess() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
				&& ($item->getScStatus() == ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS)) {
					
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Scan collection for in error nodes.
	 * @return Nodes_Collection of nodes
	 */
	public function scanNodesError() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
			&& ($item->getStatus() == Nodes_Element::STATUS_ERROR)) {
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Scan collection for in error nodes.
	 * @return Nodes_Collection of nodes
	 */
	public function scanNodesConfigMismatch() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
				&& ($item->getStatus() == Nodes_Element::STATUS_CONFIG_MISMATCH)) {
					
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Scan collection for offline nodes.
	 * @return Nodes_Collection of updated nodes
	 */
	public function scanNodesOffline(){
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
				&& ($item->getStatus() == Nodes_Element::STATUS_OFFLINE)) {
					
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Scan collection for online nodes.
	 * @return Nodes_Collection of updated nodes
	 */
	public function scanNodesOnline(){
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Element_Mapper */
			if(($item instanceof Nodes_Element_Mapper)
				&& ($item->getStatus() == Nodes_Element::STATUS_ONLINE)) {
					
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * @return Nodes_Collection
	 */
	public function scanNodesStable() {
		$stableNodes = new Nodes_Collection();
		foreach($this as $key => $node){
			if (! $node->awaitsRestart()) {
				$stableNodes[$key]= $node;
			}
		}
		$this->rewind();
		return $stableNodes;
	}
	
	/**
	 * Save all modification in collection to the database.
	 * Throws an exception if database operation fails
	 * @return Nodes_Collection
	 * @throws Zwas_Exception
	 */
	public function save() {
		try {
			foreach($this as $node) {/* @var $node Nodes_Element_Mapper */
				$node->save();
			}
		} catch (Zwas_Exception $e) {
			throw $e;
		}
		return $this;
	}
	
	/**
	 * @param $offset
	 * @param $value
	 * @throws Nodes_Collection_Exception
	 */
	public function offsetSet($offset, $value) {
		if((! is_null($value)) && (! $value instanceof Nodes_Element_Mapper)) {
			throw new Nodes_Collection_Exception('$value must be of type Nodes_Element_Mapper');
		}
		parent::offsetSet($offset, $value);
	}
	
	protected function newCollection($items = array()) {
		return new Nodes_Collection($items);
	}
}