<?php
class Nodes_Component_Element extends Zend_Db_Table_Row_Abstract {
	
	/**
	 * @return integer
	 */
	public function getNodeId() {
		return (integer)$this->nodeId;
	}

	/**
	 * @return string
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * @return boolean
	 */
	public function isInstalled() {
		return ((boolean)$this->installed) ? true : false;
	}
	
	/**
	 * @return string
	 */
	public function getVersion() {
		return $this->version;
	}
	
	/**
	 * @return boolean
	 */
	public function awaitsRestart() {
		return ((boolean)$this->awaitsRestart) ? true : false;
	}

	/**
	 * @return string
	 */
	public function getErrorString() {
		return $this->errorString;
	}

	/**
	 * @return integer
	 */
	public function getDaemonStatus() {
		return $this->daemonStatus;
	}
	
	/**
	 * @return boolean
	 */
	public function isEnabled() {
		return (boolean)$this->enabled;
	}

	/**
	 * @return string
	 */
	public function getComponentHash() {
		return (string)$this->componentHash;
	}
	
		
	/**
	 * @param boolean $enabled
	 * @return Nodes_Component_Element
	 */
	public function setEnabled($enabled) {
		$this->enabled = ((integer)$enabled);
		return $this;
	}

	/**
	 * @param integer $nodeId
	 * @return Nodes_Component_Element
	 */
	public function setNodeId($nodeId) {
		$this->nodeId = $nodeId;
		return $this;
	}

	/**
	 * @param string $name
	 * @return Nodes_Component_Element
	 */
	public function setName($name) {
		$this->name = $name;
		return $this;
	}

	/**
	 * @param boolean $installed
	 * @return Nodes_Component_Element
	 */
	public function setInstalled($installed) {
		$this->installed = ((integer)$installed);
		return $this;
	}
	
	/**
	 * @param boolean $awaitsRestart
	 * @return Nodes_Component_Element
	 */
	public function setAwaitsRestart($awaitsRestart) {
		$this->awaitsRestart = ((integer)$awaitsRestart);
		return $this;
	}

	/**
	 * @param string $errorString
	 * @return Nodes_Component_Element
	 */
	public function setErrorString($errorString) {
		$this->errorString = $errorString;
		return $this;
	}

	/**
	 * @param string $version
	 * @return Nodes_Component_Element
	 */
	public function setVersion($version) {
		$this->version = $version;
		return $this;
	}
	/**
	 * @param string $hash
	 * @return Nodes_Component_Element
	 */
	public function setComponentHash($hash) {
		$this->componentHash = (string)$hash;
		return $this;
	}
	/**
	 * @param integer $status
	 * @return Nodes_Component_Element
	 */
	public function setDaemonStatus($status) {
		$this->daemonStatus = (integer)$status;
		return $this;
	}
	
	/* (non-PHPdoc)
	 * @see Zend/Db/Table/Row/Zend_Db_Table_Row_Abstract::save()
	 */
	public function save() {
		$this->setComponentHash(self::generateHash($this));
		parent::save();
	}
	
	/**
	 * @param Nodes_Component_Element|Node_Component_Container $component
	 * @return string
	 */
	public static function generateHash($component) {
		// keep in mind $this->getNodeId() is not included on purpose
		return sha1(
			$component->awaitsRestart() .
			$component->getDaemonStatus() .
			$component->isEnabled() . 
			$component->getErrorString() .
			$component->getName() .
			$component->getVersion() .
			$component->isInstalled()
		);
	}

	/* (non-PHPdoc)
	 * @see Zend/Db/Table/Row/Zend_Db_Table_Row_Abstract::_insert()
	 */
	protected function _insert() {
		$this->setComponentHash(self::generateHash($this));
		parent::_insert();
	}

}
