<?php
class Nodes_Component_Table extends Zend_Db_Table_Abstract {
	
	protected $_name		= 'component';
	protected $_primary		= array('nodeId','name');
	protected $_rowClass	= 'Nodes_Component_Element';
	
	public function addComponents(array $components, $nodeId) {
		$this->removeAllNodeComponents($nodeId);
		
		$sql = <<<SQL
		INSERT INTO component
			(nodeId, name, installed, version, errorString,awaitsRestart, daemonStatus, enabled, componentHash)
			VALUES
			(?, ?, ?, ?, ?, ?, ?, ?, ?)
SQL;
		$stmt = $this->getAdapter()->prepare($sql);

		// @see mantis bug 31014 - using the transaction and prepared statement is used in order to speed things up
		$this->getAdapter()->beginTransaction();
		foreach ($components as $component) { /* @var $component Node_Component_Container */
			if ($component instanceof Node_Component_Container) {
				$stmt->execute(array(
					$nodeId,
					$component->getName(),
					$component->isInstalled(),
					$component->getVersion(),
					$component->getErrorString(),
					$component->awaitsRestart(),
					$component->getDaemonStatus(),
					$component->isEnabled(),
					Nodes_Component_Element::generateHash($component),
				));
			}
		} 
		$this->getAdapter()->commit();
		
	}
	
	/**
	 * @param integer $nodeId
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getNodeComponents($nodeId) {
		$select = $this->select();
		$select->where('nodeId = ?', $nodeId);
		
		return $this->fetchAll($select);
	}
	
	/**
	 * @param string $componentName
	 * @param integer $nodeId
	 * @return Nodes_Component_Element
	 */
	public function getNodeComponent($componentName, $nodeId) {
		$select = $this->select();
		$select->where('nodeId = ?', $nodeId);
		$select->where('name = ?', $componentName);
		
		$componentRow = $this->fetchRow($select);
		if (! ($componentRow instanceof Nodes_Component_Element)) {
			$componentRow = $this->createRow();
		}
		return $componentRow;
	}
	
	/**
	 * @param integer $nodeId
	 * @return integer the number of rows deleted
	 */
	public function removeAllNodeComponents($nodeId) {
		return $this->delete(array('nodeId = ?' =>  $nodeId));
	}	
	/**
	 * @param string $componentName
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getComponent($componentName) {
		$select = $this->select();
		return $this->fetchAll($select->where('name = ?', $componentName));
	}

	/**
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getComponentsWithMessages() {
		$select = $this->select();
		$select->where('errorString != \'\'');
		return $this->fetchAll($select);
	}

	/**
	 * @param string $componentName
	 * @return boolean
	 */
	public function isComponentUnstable($componentName) {
		$select = $this->select()
			->from($this->_name, array('counter' => 'COUNT(DISTINCT "componentHash")', 'name'))
			->where('name = ?', $componentName)
			->group('component.name');
		
		return (1 < (int)$select->query()->fetchColumn(0));
	}
}
