<?php

class Nodes_Element extends Zend_Db_Table_Row_Abstract {
	
	const STATUS_ONLINE				= 11;
	const STATUS_OFFLINE			= 12;
	const STATUS_ERROR				= 13;
	const STATUS_CONFIG_MISMATCH	= 14;
	
	const SERVER_TRANSITION_TO_REMOVE	= 21;
	const SERVER_TRANSITION_TO_DISABLE	= 22;
	const SERVER_TRANSITION_TO_ENABLE	= 23;
	const SERVER_TRANSITION_TO_ADD		= 24;
	const SERVER_TRANSITION_TO_REFRESH	= 25;
	
	/**
	 * @var boolean
	 */
	private $mismatchFlag = false;
	/**
	 * @var boolean
	 */
	private $deleted = false;
	
	/**
	 * @return string
	 */
	public function getGuiTag() {
		return $this->guiTag;
	}
	
	/**
	 * @return integer
	 */
	public function getPreviousScStatus() {
		return $this->_cleanData['scStatus'];
	}
	
	/**
	 * @return integer
	 */
	public function getId() {
		return (integer)$this->id;
	}

	/**
	 * @return boolean
	 */
	public function isDeleted() {
		return $this->deleted;
	}
	
	/**
	 * @return string
	 */
	public function getName() {
		return $this->name;
	}
	
	/**
	 * @return string
	 */
	public function getAddress() {
		return $this->address;
	}
	
	/**
	 * @return string
	 */
	public function getPassword() {
		return $this->password;
	}
	/**
	 * @return boolean
	 */
	public function isRepresentative() {
		return (1 == $this->representative);
	}

	/**
	 * @return integer
	 */
	public function getStatus(){
		return $this->status;
	}
	
	/**
	 * A field used for marking transition state of the node, e.g. from online to disabled
	 * @return integer
	 */
	public function getTransition() {
		return (int)$this->transition;
	}
	
	/**
	 * @return boolean
	 */
	public function isDisabled() {
		return (boolean)$this->disabled;
	}
	
	/**
	 * @return boolean
	 */
	public function awaitsRestart() {
		return (boolean)$this->awaitsRestart;
	}
	
	/**
	 * @return integer
	 */
	public function getScStatus() {
		return $this->scStatus;
	}
	
	/**
	 * @return string
	 * @throws Zwas_Exception
	 */
	public function getHostname() {
		$parts = array();
		preg_match("/^(?:(?:https|http):\/\/)([^:]+)/i", $this->getAddress(), $parts);
		if (isset($parts[1])) {
			return $parts[1];
		}
		throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Invalid server address %s'), $this->getAddress()), Zwas_Exception::ASSERT);
	}
		
	/**
	 * @return integer
	 */
	public function getEnvironmentId() {
		return (integer)$this->environmentId;
	}

	/**
	 * @return integer
	 */
	public function getUpdateTime() {
		return $this->metaUdate;
	}

	/**
	 * @return integer
	 */
	public function getCreationTime() {
		return $this->metaCdate;
	}

	/**
	 * @return integer
	 */
	public function getHeartbeatTime() {
		return $this->metaHBdate;
	}

	/**
	 * @return string
	 */
	public function getNetworkScheme() {
		return $this->networkScheme;
	}

	/**
	 * @return string
	 */
	public function getNetworkHost() {
		return $this->networkHost;
	}

	/**
	 * @return string
	 */
	public function getNetworkPort() {
		return $this->networkPort;
	}

	/**
	 * @return string
	 */
	public function getNetworkUri() {
		return $this->networkUri;
	}

	/**
	 * @param integer $environmentId
	 * @return Nodes_Element
	 */
	public function setEnvironmentId($environmentId) {
		$this->environmentId = $environmentId;
		return $this;
	}

	/**
	 * @param integer $metaUdate
	 * @return Nodes_Element
	 */
	public function setUpdateTime($metaUdate) {
		$this->metaUdate = $metaUdate;
		return $this;
	}

	/**
	 * @param integer $metaCdate
	 * @return Nodes_Element
	 */
	public function setCreationTime($metaCdate) {
		$this->metaCdate = $metaCdate;
		return $this;
	}

	/**
	 * @param integer $metaHBdate
	 * @return Nodes_Element
	 */
	public function setHeartbeatTime($metaHBdate) {
		$this->metaHBdate = $metaHBdate;
		return $this;
	}

	/**
	 * @param string $networkScheme
	 * @return Nodes_Element
	 */
	public function setNetworkScheme($networkScheme) {
		$this->networkScheme = $networkScheme;
		return $this;
	}

	/**
	 * @param string $networkHost
	 * @return Nodes_Element
	 */
	public function setNetworkHost($networkHost) {
		$this->networkHost = $networkHost;
		return $this;
	}

	/**
	 * @param string $networkPort
	 * @return Nodes_Element
	 */
	public function setNetworkPort($networkPort) {
		$this->networkPort = $networkPort;
		return $this;
	}

	/**
	 * @param string $networkUri
	 * @return Nodes_Element
	 */
	public function setNetworkUri($networkUri) {
		$this->networkUri = $networkUri;
		return $this;
	}
		
	/**
	 * @param string $address
	 * @return Nodes_Element
	 * @throws Zwas_Exception
	 */
	public function setAddress($address) {
		$this->address = $address;
		$parsedUrl = parse_url($address);
		if ((! $parsedUrl) || (! isset($parsedUrl['host']))) {
			throw new Zwas_Exception(new Zwas_Text(Zwas_Translate::_('Invalid server address %s'), array($address)), Zwas_Exception::ASSERT);
		}

		$this->setNetworkHost($parsedUrl['host']);
		if (isset($parsedUrl['port'])) {
			$this->setNetworkPort($parsedUrl['port']);
		} else {
			$this->setNetworkPort(10081);
		}
		
		if (isset($parsedUrl['scheme'])) {
			$this->setNetworkScheme($parsedUrl['scheme']);
		} else {
			$this->setNetworkScheme('http');
		}
		
		if (isset($parsedUrl['path'])) {
			$this->setNetworkUri($parsedUrl['path']);
		} else {
			$this->setNetworkUri('/ZendServer');
		}
		
		return $this;
	}

	/**
	 * @param integer $id
	 * @return Nodes_Element
	 */
	public function setId($id) {
		$this->id = $id;
		return $this;
	}

	/**
	 * @param string $name
	 * @return Nodes_Element
	 */
	public function setName($name) {
		$this->name = $name;
		return $this;
	}

	/**
	 * @param string $password
	 * @return Nodes_Element
	 */
	public function setPassword($password) {
		$this->password = $password;
		return $this;
	}

	/**
	 * @param boolean $representative
	 * @return Nodes_Element
	 */
	public function setRepresentative($representative) {
		$this->representative = (integer)$representative;
		return $this;
	}
	
	/**
	 * @param $status integer
	 * @return Nodes_Element
	 */
	public function setStatus($status){
		$this->status = $status;
		return $this;
	}
	
	/**
	 * @param $transition integer
	 * @return Nodes_Element
	 */
	public function setTransition($transition){
		$this->transition = $transition;
		return $this;
	}
	
	/**
	 * @param boolean $disabled
	 * @return Nodes_Element
	 */
	public function setDisabled($disabled) {
		$this->disabled = ((boolean)$disabled) ? 1 : 0;
		return $this;
	}
	
	/**
	 * @param boolean $awaitRestart
	 * @return Nodes_Element
	 */
	public function setAwaitRestart($awaitRestart){
		$this->awaitsRestart = (boolean)$awaitRestart;
		return $this;
	}
	
	/**
	 * @param integer $status
	 * @return Nodes_Element
	 */
	public function setScStatus($status) {
		$this->scStatus = $status;
		return $this;
	}
	
	/**
	 * @param string $guiTag
	 * @return Nodes_Element
	 */
	public function setGuiTag($guiTag) {
		$this->guiTag = $guiTag;
		return $this;
	}
	
	/**
	 * @param string $address
	 * @param string $password
	 * @param integer $id
	 * @return Nodes_Element
	 */
	public static function fabricateNodeElement($address, $password, $id = 0) {
		return Context_Db::getNodesTable()->createRow(array('id' => $id, 'name' => md5(mt_rand()), 'address' => $address, 'password' => $password)); 
	}
	
	/**
	 * @throws Zwas_Exception
	 * @return integer
	 * @see Zend/Db/Table/Row/Zend_Db_Table_Row_Abstract::save()
	 */
	public function save() {
		$this->setAddress($this->getAddress());
		return parent::save();
	}
	
	/**
     * Allows post-delete logic to be applied to row.
     * Subclasses may override this method.
     */
    protected function _postDelete() {
    	$this->setDeleted(true);
    }
	
    protected function _insert() {
    	//TODO Need to place __get columns calls with getters/setters
    	if (! $this->environmentId) {
    		$this->environmentId = 0;
    	}
    	
    	if (! $this->getUpdateTime()) {
    		$this->setUpdateTime(time());
    	}

    	if (! $this->getCreationTime()) {
    		$this->setCreationTime(time());
    	}
    }
    
    protected function _update() {
    	$this->setUpdateTime(time());
    }
    
	/**
	 * @param boolean $deleted
	 * @return Nodes_Element
	 */
	private function setDeleted($deleted) {
		$this->deleted = $deleted;
		return $this;
	}
}