<?php

class Nodes_Element_Mapper {
	
	/**
	 * @var Nodes_Element
	 */
	private $nodesElement;
	/**
	 * @var array
	 */
	private $nodeSignatures = null;
	/**
	 * @var Nodes_Environment_Element
	 */
	private $nodesEnvironmentElement = null;
	
	public function __construct(Nodes_Element $nodesElement) {
		$this->nodesElement = $nodesElement;
	}
	
	/**
	 * @return string
	 */
	public function getGuiTag() {
		return $this->nodesElement->getGuiTag();
	}

	/**
	 * @return integer
	 */
	public function getPreviousScStatus() {
		return $this->nodesElement->getPreviousScStatus();
	}
	
	/**
	 * @return integer
	 */
	public function getId() {
		return $this->nodesElement->getId();
	}

	/**
	 * @return boolean
	 */
	public function isDeleted() {
		return $this->nodesElement->isDeleted();
	}
	
	/**
	 * @return string
	 */
	public function getName() {
		return $this->nodesElement->getName();
	}
	
	/**
	 * @return string
	 */
	public function getAddress() {
		return $this->nodesElement->getAddress();
	}
	
	/**
	 * @return string
	 */
	public function getPassword() {
		return $this->nodesElement->getPassword();
	}
	/**
	 * @return boolean
	 */
	public function isRepresentative() {
		return $this->nodesElement->isRepresentative();
	}

	/**
	 * @return integer
	 */
	public function getStatus(){
		return $this->nodesElement->getStatus();
	}
	
	/**
	 * A field used for marking transition state of the node, e.g. from online to disabled
	 * @return integer
	 */
	public function getTransition() {
		return $this->nodesElement->getTransition();
	}	
	
	/**
	 * @return boolean
	 */
	public function isNodeInRemovalProcess() {
		return (Nodes_Element::SERVER_TRANSITION_TO_REMOVE === $this->getTransition());
	}
	
	/**
	 * @return boolean
	 */
	public function isNodeInDisableProcess() {
		return (Nodes_Element::SERVER_TRANSITION_TO_DISABLE === $this->getTransition());
	}
	
	/**
	 * @return boolean
	 */
	public function isDisabled() {
		return $this->nodesElement->isDisabled();
	}
		
	public function refresh() {
		try {
			$this->nodesElement->refresh();
		} catch (Zend_Db_Table_Row_Exception $e) {
			throw new Zwas_Db_Exception($e->getMessage());
		}
	}
	
	/**
	 * @return boolean
	 */
	public function awaitsRestart() {
		return $this->nodesElement->awaitsRestart();
	}
	
	/**
	 * @return integer
	 */
	public function getScStatus() {
		return $this->nodesElement->getScStatus();
	}
	
	/**
	 * @return string
	 * @throws Zwas_Exception
	 */
	public function getHostname() {
		return $this->nodesElement->getHostname();
	}
	
	/**
	 * @param string $name
	 * @return Nodes_Signatures_Element
	 */
	public function getSignature($name = Node_HeartbeatGenerator::SIGNATURE_NAME_MASTER) {
		if (is_null($this->nodeSignatures)) {
			$rows = Context_Db::getNodesSignaturesTable()->getNodeSignatures($this->getId());
			$this->nodeSignatures = array();
			foreach ($rows as $row) {
				$this->nodeSignatures[$row->getName()]=$row;
			}
		}
		
		if (! (isset($this->nodeSignatures[$name]))) {
			return '';
		}
		return $this->nodeSignatures[$name]->getValue();
	}
	
	/**
	 * @return Nodes_Environment_Element
	 */
	public function getNodesEnvironmentElement() {
		if (is_null($this->nodesEnvironmentElement)) {
			$row = Context_Db::getNodesEnvironmentTable()->getEnvironmentById($this->getEnvironmentId());
			$this->nodesEnvironmentElement = $row;
			
			if (! ($row instanceof Nodes_Environment_Element)) {
				// TRANSLATE
				throw new Zwas_Exception(Zwas_Translate::_(new Zwas_Text('Environment of %s was not find in environment table'), $this->getEnvironmentId()));
				Zwas_Log::debug(new Zwas_Text('Could not found environment for node id %s', $this->getEnvironmentId()));
			}
		}
		return $this->nodesEnvironmentElement;
	}
	
	/**
	 * @return string $zendServerVersion 
	 */
	public function getZendServerVersion() {
		return $this->getNodesEnvironmentElement()->getServerVersion();
	}
	
	/**
	 * @return integer
	 */
	public function getEnvironmentId() {
		return $this->nodesElement->getEnvironmentId();
	}

	/**
	 * @return integer
	 */
	public function getUpdateTime() {
		return $this->nodesElement->getUpdateTime();
	}

	/**
	 * @return integer
	 */
	public function getCreationTime() {
		return $this->nodesElement->getCreationTime();
	}

	/**
	 * @return integer
	 */
	public function getHeartbeatTime() {
		return $this->nodesElement->getHeartbeatTime();
	}

	/**
	 * @return string
	 */
	public function getNetworkScheme() {
		return $this->nodesElement->getNetworkScheme();
	}

	/**
	 * @return string
	 */
	public function getNetworkHost() {
		return $this->nodesElement->getNetworkHost();
	}

	/**
	 * @return string
	 */
	public function getNetworkPort() {
		return $this->nodesElement->getNetworkPort();
	}

	/**
	 * @return string
	 */
	public function getNetworkUri() {
		return $this->nodesElement->getNetworkUri();
	}

	/**
	 * @return boolean
	 */
	public function waitingForHeartbeat() {
		return in_array(
			$this->getTransition(), 
			array(
				Nodes_Element::SERVER_TRANSITION_TO_ADD, 
				Nodes_Element::SERVER_TRANSITION_TO_ENABLE, 
				Nodes_Element::SERVER_TRANSITION_TO_REFRESH,
			)
		);
	}
	
	/**
	 * @param integer $environmentId
	 * @return Nodes_Element
	 */
	public function setEnvironmentId($environmentId) {
		$this->nodesElement->setEnvironmentId($environmentId);
		return $this;
	}
	
	/**
	 * @param string $serverVersion 
	 * @return Nodes_Element_Mapper
	 */
	public function setZendServerVersion($serverVersion) {
		$this->getNodesEnvironmentElement()->setServerVersion($serverVersion);
		return $this;
	}
	/**
	 * @param integer $metaUdate
	 * @return Nodes_Element
	 */
	public function setUpdateTime($metaUdate) {
		$this->nodesElement->setUpdateTime($metaUdate);
		return $this;
	}

	/**
	 * @param integer $metaCdate
	 * @return Nodes_Element
	 */
	public function setCreationTime($metaCdate) {
		$this->nodesElement->setCreationTime($metaCdate);
		return $this;
	}

	/**
	 * @param integer $metaHBdate
	 * @return Nodes_Element
	 */
	public function setHeartbeatTime($metaHBdate) {
		$this->nodesElement->setHeartbeatTime($metaHBdate);
		return $this;
	}

	/**
	 * @param string $networkScheme
	 * @return Nodes_Element
	 */
	public function setNetworkScheme($networkScheme) {
		$this->nodesElement->setNetworkScheme($networkScheme);
		return $this;
	}

	/**
	 * @param string $networkHost
	 * @return Nodes_Element
	 */
	public function setNetworkHost($networkHost) {
		$this->nodesElement->setNetworkHost($networkHost);
		return $this;
	}

	/**
	 * @param string $networkPort
	 * @return Nodes_Element
	 */
	public function setNetworkPort($networkPort) {
		$this->nodesElement->setNetworkPort($networkPort);
		return $this;
	}

	/**
	 * @param string $networkUri
	 * @return Nodes_Element
	 */
	public function setNetworkUri($networkUri) {
		$this->nodesElement->setNetworkUri($networkUri);
		return $this;
	}
		
	/**
	 * @param string $address
	 * @return Nodes_Element_Mapper
	 */
	public function setAddress($address) {
		$this->nodesElement->setAddress($address);
		return $this;
	}

	/**
	 * @param integer $id
	 * @return Nodes_Element_Mapper
	 */
	public function setId($id) {
		$this->nodesElement->setId($id);
		return $this;
	}

	/**
	 * @param string $name
	 * @return Nodes_Element_Mapper
	 */
	public function setName($name) {
		$this->nodesElement->setName($name);
		return $this;
	}

	/**
	 * @param string $password
	 * @return Nodes_Element_Mapper
	 */
	public function setPassword($password) {
		$this->nodesElement->setPassword($password);
		return $this;
	}

	/**
	 * @param boolean $representative
	 * @return Nodes_Element_Mapper
	 */
	public function setRepresentative($representative) {
		$this->nodesElement->setRepresentative($representative);
		return $this;
	}

	/**
	 * @param boolean $disabled
	 * @return Nodes_Element_Mapper
	 */
	public function setDisabled($disabled) {
		$this->nodesElement->setDisabled($disabled);
		return $this;
	}
	
	/**
	 * @param $status integer
	 * @return Nodes_Element_Mapper
	 */
	public function setStatus($status) {
		$this->nodesElement->setStatus($status);
		return $this;
	}
	
	/**
	 * @param $transition integer
	 * @return Nodes_Element
	 */
	public function setTransition($transition){
		$this->nodesElement->setTransition($transition);
		return $this;
	}
	
	/**
	 * Set transition value and save immediately
	 * @param $transition integer
	 * @return Nodes_Element
	 */
	public function updateTransition($transition){
		$this->nodesElement->setTransition($transition);
		$this->nodesElement->save();
		return $this;
	}
		
	/**
	 * @param $awaitRestart
	 * @return Nodes_Element_Mapper
	 */
	public function setAwaitRestart($awaitRestart) {
		$this->nodesElement->setAwaitRestart($awaitRestart);
		return $this;
	}
	
	/**
	 * @param integer $status
	 * @return Nodes_Element_Mapper
	 */
	public function setScStatus($status) {
		$this->nodesElement->setScStatus($status);
		return $this;
	}
	
	/**
	 * @param string $guiTag
	 * @return Nodes_Element_Mapper
	 */
	public function setGuiTag($guiTag) {
		$this->nodesElement->setGuiTag($guiTag);
		return $this;
	}
	
	/**
	 * @param string $value
	 * @param string $name
	 * @return Nodes_Element_Mapper
	 */
	public function setSignature($value, $name = Node_HeartbeatGenerator::SIGNATURE_NAME_MASTER) {
		
		/// lazy-initialize the signatures array and test for availability
		/// we can not use the direct output here - it is a string, not an object
		$signature = $this->getSignature($name);
		if (('' == $signature) && (! isset($this->nodeSignatures[$name]))) {
			Zwas_Log::debug(new Zwas_Text("New signature row %s created", array($name)));
			$signature = Context_Db::getNodesSignaturesTable()->createRow();
		} else {
			if ($signature != $value) {
				Zwas_Log::debug(new Zwas_Text("Signature row %s modified", array($name)));
			}
			$signature = $this->nodeSignatures[$name];
		}
		
		$signature->setNodeId($this->getId())
					->setName($name)
					->setValue($value)
					->setTimestamp(time());
		$this->nodeSignatures[$name]= $signature;
		return $this;
	}
		
	/**
	 * @param Nodes_Environment_Element $environment
	 * @return Nodes_Element_Mapper
	 */
	public function setNodesEnvironmentElement(Nodes_Environment_Element $environment) {
		$this->nodesEnvironmentElement = $environment;
		return $this;
	}
	
	/**
     * Set the read-only status of the nodes element
     *
     * @param boolean $flag
     * @return boolean
     */
	public function setReadOnly($flag) {
		$this->nodesElement->setReadOnly($flag);
	}
		
	/**
	 * @return Nodes_Element_Mapper
	 */
	public function __clone() {
		$this->nodesElement = clone $this->nodesElement;
		if (is_object($this->nodesEnvironmentElement)) {
			$this->nodesEnvironmentElement = clone $this->nodesEnvironmentElement;
		}
	}
	
	/**
	 * @param string $address
	 * @param string $password
	 * @param integer $id
	 * @return Nodes_Element_Mapper
	 */
	public static function fabricateNodeElement($address, $password, $id = 0) {
		$nodesElement = Nodes_Element::fabricateNodeElement($address, $password, $id);
		return new self($nodesElement);
	}
	
	public function save() {
		if ($this->nodesElement instanceof Nodes_Element) {
			$this->nodesElement->save();
		}
		if (is_array($this->nodeSignatures)) {
			foreach ($this->nodeSignatures as $signature) {
				if ($signature instanceof Nodes_Signatures_Element) {
					$signature->save();
				}
			}
		}
		if ($this->nodesEnvironmentElement instanceof Nodes_Environment_Element) {
			$this->nodesEnvironmentElement->save();
		}
	}
	
	/**
	 * @return boolean
	 * @throws Zwas_Exception
	 */
	public function isScStatusMatching() {
		$model = new Nodes_Model();
		return $this->nodesElement->getScStatus() == $model->getRepresentativeForReading()->getScStatus();
	}
	
	/**
	 * @param string $name
	 * @return boolean
	 */
	public function isSignatureMatchingCluster($name = Node_HeartbeatGenerator::SIGNATURE_NAME_MASTER) {
		if ($this->nodesElement->isRepresentative()) {
			return true;
		}
		$model = new Nodes_Model();
		$representative = $model->getRepresentativeForReading();
		$nodeSignature = $this->getSignature($name);
		
		$repSignature = $representative->getSignature($name);
		
		return ((string)$nodeSignature == (string)$repSignature);
	}
		
	/**
	 * delete of node signature from signatures table  
	 */
	public function delete() {
		$this->purgeNodeData($this->getId());
		$this->nodesElement->delete();
	}
	
	public function disable() {
		$this->setDisabled(true)
			->setTransition(0)
			->save();
		$this->purgeNodeData($this->getId());
	}
	
	/**
	 * Remove the server data from service tables and internal placeholders
	 * @throws Nodes_Model_Delegate_Exception
	 */
	private function purgeNodeData($nodeId) {
		try {
			Context_Db::getNodesSignaturesTable()->removeNodeSignatures($nodeId);
		} catch (Zend_Db_Table_Row_Exception $e) {
			// TRANSLATE
			Zwas_Log::warn(new Zwas_Text(
				Zwas_Translate::_('Could not remove the signatures list of server %s'),
				array($nodeId)
			));
			throw new Nodes_Model_Delegate_Exception(Zwas_Translate::_('You do not have permission to perform this action'));
		}
		// also clean the internal cache of the signatures
		$this->nodeSignatures = null;
		
		try {
			Context_Db::getNodesExtensionTable()->removeAllNodeExtensions($nodeId);
		} catch (Zend_Db_Table_Row_Exception $e) {
			// TRANSLATE
			Zwas_Log::warn(new Zwas_Text(
				Zwas_Translate::_('Could not remove the extensions list of server %s'),
				array($nodeId)
			));
			throw new Nodes_Model_Delegate_Exception(Zwas_Translate::_('You do not have permission to perform this action'));
		}
		
		try {
			Context_Db::getNodesComponentTable()->removeAllNodeComponents($nodeId);
		} catch (Zend_Db_Table_Row_Exception $e) {
			// TRANSLATE
			Zwas_Log::warn(new Zwas_Text(
				Zwas_Translate::_('Could not remove the components list of server %s'),
				array($nodeId)
			));
			throw new Nodes_Model_Delegate_Exception(Zwas_Translate::_('You do not have permission to perform this action'));
		}
	}
	
}