<?php

class Nodes_Environment_Element extends Zend_Db_Table_Row_Abstract {

	/**
	 * Create a Nodes_Environment object according to a Node_Environment object
	 * @param Node_Environment $nodeEnv
	 * @return Nodes_Environment_Element
	 */
	public static function fromNodeEnvironment(Node_Environment $nodeEnv) {
		$environment = Context_Db::getNodesEnvironmentTable()->createRow();
		$environment->setInstallationPath($nodeEnv->getInstallPath());
		$environment->setOperatingSystem($nodeEnv->getOs());
		$environment->setPhpVersion($nodeEnv->getPhpVersion());
		$environment->setServerVersion($nodeEnv->getZendServerVersion());
		return $environment;
	}
	
	/**
	 * @param Nodes_Environment_Element $a the server to compare with
	 * @param Nodes_Environment_Element $b the server needs comparing (e.g. the added one)
	 * @throws Zwas_Exception
	 * @return boolean
	 */
	public static function compare(Nodes_Environment_Element $a, Nodes_Environment_Element $b) {
		if ($a->getEnvironmentHash() == $b->getEnvironmentHash()) {
			return true;
		}
		
		if ($a->getServerVersion() != $b->getServerVersion()) {
			throw new Zwas_Exception(Zwas_Translate::_('The Add Server action is for adding servers running the same Zend Server version'));
		}
		
		if (version_compare($a->getPhpVersion(), $b->getPhpVersion(), '!=') ) {
			throw new Zwas_Exception(new Zwas_Text(
				Zwas_Translate::_('The Add Server action is for adding servers running the same PHP version. The PHP version needs to be %s'),
				array($a->getPhpVersion())
			));
		}
		
		if ($a->getInstallationPath() != $b->getInstallationPath()) {
			throw new Zwas_Exception(Zwas_Translate::_('The Add Server action is for adding servers running the same Zend Server installation path'));
		}

		if ($a->getOperatingSystem() != $b->getOperatingSystem()) {
			throw new Zwas_Exception('The Add Server action is for adding servers running the same operating system');
		}
		
		
		return true;
	}
	
	/**
	 * @return string
	 */
	public function produceEnvironmentHash() {
		return sha1(
			$this->getOperatingSystem() .
			$this->getInstallationPath() .
			$this->getServerVersion() .
			$this->getPhpVersion()
		);
	}
	
	public function save() {
		$this->setEnvironmentHash($this->produceEnvironmentHash());
		return parent::save();
	}
	
	/**
	 * @return integer
	 */
	public function getEnvironmentId() {
		return (integer)$this->environmentId;
	}

	/**
	 * @return integer
	 */
	public function getClusterId() {
		return $this->clusterId;
	}

	/**
	 * @return integer
	 */
	public function getProfileId() {
		return $this->profileId;
	}

	/**
	 * @return string
	 */
	public function getOperatingSystem() {
		return $this->operatingSystem;
	}

	/**
	 * @return string
	 */
	public function getInstallationPath() {
		return $this->installationPath;
	}

	/**
	 * @return string
	 */
	public function getServerVersion() {
		return $this->serverVersion;
	}

	/**
	 * @return string
	 */
	public function getPhpVersion() {
		return $this->phpVersion;
	}

	/**
	 * @return string
	 */
	public function getEnvironmentHash() {
		return $this->environmentHash;
	}

	/**
	 * @param integer $clusterId
	 * @return Nodes_Environment_Element
	 */
	public function setClusterId($clusterId) {
		$this->clusterId = $clusterId;
		return $this;
	}

	/**
	 * @param integer $profileId
	 * @return Nodes_Environment_Element
	 */
	public function setProfileId($profileId) {
		$this->profileId = $profileId;
		return $this;
	}

	/**
	 * @param string $operatingSystem
	 * @return Nodes_Environment_Element
	 */
	public function setOperatingSystem($operatingSystem) {
		$this->operatingSystem = $operatingSystem;
		return $this;
	}

	/**
	 * @param string $installationPath
	 * @return Nodes_Environment_Element
	 */
	public function setInstallationPath($installationPath) {
		$this->installationPath = $installationPath;
		return $this;
	}

	/**
	 * @param string $serverVersion
	 * @return Nodes_Environment_Element
	 */
	public function setServerVersion($serverVersion) {
		$this->serverVersion = $serverVersion;
		return $this;
	}

	/**
	 * @param string $phpVersion
	 * @return Nodes_Environment_Element
	 */
	public function setPhpVersion($phpVersion) {
		$this->phpVersion = $phpVersion;
		return $this;
	}

	/**
	 * @param string $environmentHash
	 * @return Nodes_Environment_Element
	 */
	public function setEnvironmentHash($environmentHash) {
		$this->environmentHash = $environmentHash;
		return $this;
	}

	/**
	 * @param integer $environmentId
	 * @return Nodes_Environment_Element
	 */
	public function setEnvironmentId($environmentId) {
		$this->environmentId = $environmentId;
		return $this;
	}
}
