<?php

class Nodes_Environment_Table extends Zend_Db_Table_Abstract {

	protected $_name		= 'environment';
	protected $_primary		= 'environmentId';
	protected $_rowClass	= 'Nodes_Environment_Element';
	
	/**
	 * Accepts an environment row object for storage. If the row does not exist, it is inserted.
	 * If the row exists already, the method returns the full row data.
	 * @param Zend_Db_Table_Row_Abstract $environment
	 * @return Zend_Db_Table_Row_Abstract
	 * @throws Zwas_Db_Exception Zwas_Exception
	 */
	public function addEnvironment(Nodes_Environment_Element $environment) {
		$existingEnvironment = null;
		
		// protection for Mantis bug 30979 
		if ('5.0.2' === $environment->getServerVersion()) {
			
			$select = $this->select();
			$select->where('clusterId = 1')
				->where('profileId = 1')
				->where('operatingSystem != ""')
				->where('installationPath != ""')
				->where('serverVersion = ?', $environment->getServerVersion())
				->where('phpVersion = ?', $environment->getPhpVersion());
			
			$row = $select->query()->fetch();
			if (false !== $row) {
				$existingEnvironment = $this->createRow($row);
			}
			
		} else {
			$hash = $environment->produceEnvironmentHash();
			$existingEnvironment = $this->fetchRow("clusterId = 1 AND profileId = 1 AND environmentHash = '$hash'");
		}
		
		if ($existingEnvironment instanceof Nodes_Environment_Element) {
			return $existingEnvironment;
		}
		
		try {
			$environment->clusterId			= 1;
			$environment->profileId			= 1;
			$environment->save();
		} catch (Zend_Db_Exception $e) {
			throw new Zwas_Db_Exception($e->getMessage(), Zwas_Exception::ERROR);
		}
		return $environment;
	}
	
	/**
	 * @param integer $environmentId
	 * @return Nodes_Environment_Element
	 */
	public function getEnvironmentById($environmentId) {
		$where = array(
				$this->getAdapter()->quoteInto('environmentId = ?', $environmentId),
			);
		$row = $this->fetchRow($where);
		if (is_null($row)) {
			$row = $this->createRow();
		}
		return $row;
	}
}
