<?php
class Nodes_Extension_Element extends Zend_Db_Table_Row_Abstract implements Node_Extension_Interface {
	
	/**
	 * @return integer
	 */
	public function getNodeId() {
		return (int)$this->nodeId;
	}

	/**
	 * @return string
	 */
	public function getName() {
		return (string)$this->name;
	}

	/**
	 * @return string
	 */
	public function getFilename() {
		return (string)$this->filename;
	}

	/**
	 * @return boolean
	 */
	public function fileExists() {
		return ((boolean)$this->fileExists) ? true : false;
	}

	/**
	 * @return boolean
	 */
	public function isLoaded() {
		return ((boolean)$this->loaded) ? true : false;
	}

	/**
	 * @return integer
	 */
	public function getIniStatus() {
		return (int)$this->iniStatus;
	}

	/**
	 * @return string
	 */
	public function getIniFile() {
		return (string)$this->iniFile;
	}

	/**
	 * @return boolean
	 */
	public function awaitsRestart() {
		return ((boolean)$this->awaitsRestart) ? true : false;
	}

	/**
	 * @return string
	 */
	public function getErrorString() {
		return (string)$this->errorString;
	}
	
	/**
	 * @return string
	 */
	public function getExtensionHash() {
		return (string)$this->extensionHash;
	}

	/**
	 * @return integer
	 */
	public function getNumberOfDirectives() {
		return (int)$this->numOfDirectives;
	}
	
	/**
	 * @param integer $nodeId
	 * @return Nodes_Extension_Element
	 */
	public function setNodeId($nodeId) {
		$this->nodeId = $nodeId;
		return $this;
	}

	/**
	 * @param string $name
	 * @return Nodes_Extension_Element
	 */
	public function setName($name) {
		$this->name = $name;
		return $this;
	}

	/**
	 * @param string $filename
	 * @return Nodes_Extension_Element
	 */
	public function setFilename($filename) {
		$this->filename = $filename;
		return $this;
	}

	/**
	 * @param boolean $fileExists
	 * @return Nodes_Extension_Element
	 */
	public function setFileExists($fileExists) {
		$this->fileExists = ((integer)$fileExists);
		return $this;
	}

	/**
	 * @param boolean $loaded
	 * @return Nodes_Extension_Element
	 */
	public function setLoaded($loaded) {
		$this->loaded = ((integer)$loaded);
		return $this;
	}

	/**
	 * @param integer $iniStatus
	 * @return Nodes_Extension_Element
	 */
	public function setIniStatus($iniStatus) {
		$this->iniStatus = $iniStatus;
		return $this;
	}

	/**
	 * @param string $iniFile
	 * @return Nodes_Extension_Element
	 */
	public function setIniFile($iniFile) {
		$this->iniFile = $iniFile;
		return $this;
	}

	/**
	 * @param boolean $awaitsRestart
	 * @return Nodes_Extension_Element
	 */
	public function setAwaitsRestart($awaitsRestart) {
		$this->awaitsRestart = ((integer)$awaitsRestart);
		return $this;
	}

	/**
	 * @param string $errorString
	 * @return Nodes_Extension_Element
	 */
	public function setErrorString($errorString) {
		$this->errorString = $errorString;
		return $this;
	}

	/**
	 * @param string $hash
	 * @return Nodes_Extension_Element
	 */
	public function setExtensionHash($hash) {
		$this->extensionHash = (string)$hash;
		return $this;
	}

	/**
	 * @param integer $numOfDirectives
	 * @return Nodes_Extension_Element
	 */
	public function setNumberOfDirectives($numOfDirectives) {
		$this->numOfDirectives = (int)$numOfDirectives;
		return $this;
	}
	
	/* (non-PHPdoc)
	 * @see Zend/Db/Table/Row/Zend_Db_Table_Row_Abstract::save()
	 */
	public function save() {
		$this->setExtensionHash(self::generateHash($this));
		parent::save();
	}

	/**
	 * @param Node_Extension_Interface $extension
	 * @return string
	 */
	public static function generateHash($extension) {
		// keep in mind $this->getNodeId() is not included on purpose
		return sha1(
			$extension->awaitsRestart() .
			$extension->getErrorString() .
			$extension->getFilename() .
			$extension->getIniFile() .
			$extension->getIniStatus() .
			$extension->getName() .
			$extension->fileExists() .
			$extension->isLoaded() .
			$extension->getNumberOfDirectives()
		);
	}
	
	/* (non-PHPdoc)
	 * @see Zend/Db/Table/Row/Zend_Db_Table_Row_Abstract::_insert()
	 */
	protected function _insert() {
		$this->setExtensionHash(self::generateHash($this));
		parent::_insert();
	}

}
