<?php
class Nodes_Model_Delegate_DisableNode extends Nodes_Model_Delegate_Abstract {
	
	/**
	 * @param Nodes_Model $model
	 */
	public function __construct(Nodes_Model $model) {
		parent::__construct($model);
		$this->setEventToReport(new ZwasComponents_MonitorUi_UiEvent_NodeDisabled());
	}
	
	/**
	 * @param Nodes_Element_Mapper $node
	 * @return Nodes_Element_Mapper
	 * @throws Nodes_Model_Delegate_Exception
	 */
	public function disable(Nodes_Element_Mapper $node) {
		if (Nodes_Element::STATUS_OFFLINE == $node->getStatus()) {
			/// update node state, maybe it's back and can be disabled normally
			try {
				$this->model->getModelHeartbeat()->updateHeartBeat($node);
			} catch (Exception $e) {
				// TRANSLATE
				Zwas_Log::logException('Server revival encountered a problem', $e);
			}
		}
		$this->node = $node;
		
		if ((Nodes_Element::STATUS_OFFLINE != $this->node->getStatus())
			&& ($this->isNodeReadyForGracefulShutdown($node))) {
				
			$this->gracefulShutdownSc($node);
		} else {
			$this->disableNode($node);
			if ($node->isRepresentative()) {
				// this is a representative, find a replacement candidate
				try {
					$this->model->replaceRepresentative();
				} catch(Zwas_Exception $e) {
					/// we've failed in the attempt to replace the representative.
					/// not much we can do about that...
				}
				if ($this->model->hasEnabledNodes()) {
					$this->model->getModelHeartbeat()->analyzeNodesState(new Nodes_Collection($this->model->getEnabledNodes()));
				}
			}
			GracefulShutdown::destroy();
		}
		return $node;
	}
	
	/**
	 * @param Nodes_Element_Mapper $node
	 * @return Nodes_Model_Delegate_DisableNode
	 */
	protected function disableNode(Nodes_Element_Mapper $node) {
		$this->node = $node;
		$this->node->disable();
		$this->createEvent($this->node);
		return $this;
	}
	
	/**
	 * @param Nodes_Element_Mapper $node
	 * @return Nodes_Model_Delegate_DisableNode
	 */
	protected function gracefulShutdownSc(Nodes_Element_Mapper $node) {
		parent::gracefulShutdownSc($node);
		if ($this->isNodeReadyForPostGraceful($node)) {
			$this->disable($node);
			return $this;
		}
		$node->setTransition(Nodes_Element::SERVER_TRANSITION_TO_DISABLE)->save();
		GracefulShutdown::init();
		return $this;
	}
	
}