<?php

abstract class Nodes_Model_Plugin_Abstract {
	/**
	 *
	 * @param Nodes_Model $model
	 * @param Nodes_Element_Mapper $node
	 */
	public function preAction(Nodes_Model $model, Nodes_Element_Mapper $node = null) {
		
	}
    /**
	 * @param Nodes_Model $model
	 * @param array $nodes array of Nodes_Element_Mapper elements
	 */
	public function postAction(Nodes_Model $model, array $nodes) {
		
	}
	
	/**
	 * @param Nodes_Model $model
	 * @param array $nodes
	 * @param string $controller
	 * @param string $action
	 * @param array $params
	 * @param boolean $needReturnData
	 */
	protected function nodesRequests(Nodes_Model $model, array $nodes, $controller, $action, array $params, $needReturnData = false) {
		$mapper = $model->getCommMapper();
		$nodeResponses = $mapper->distributeActionGetResponses($nodes, $controller, $action, $params);
		$errorResponses = $nodeResponses->scanErrorResponses();
		if ($errorResponses->count() > 0) {
			throw new Zwas_Exception((string)$errorResponses[0]->getData(), $errorResponses[0]->getCode());
		}
		
		if ($needReturnData) {
			return $nodeResponses->getRepresentativeResponse()->getData();
		} elseif (! $nodeResponses->scanResponseDataOk()->count() == $nodeResponses->count()) {
			throw new Zwas_Exception('Incorrect response data returned from one of the nodes');
		}
	}
	/**
	 * @param Nodes_Model $model
	 * @param Nodes_Element_Mapper $node
	 * @param string $controller
	 * @param string $action
	 * @param array $params
	 * @param bool $needReturnData
	 * @return Node_Response|string
	 */
	protected function nodeRequest(Nodes_Model $model, Nodes_Element_Mapper $node, $controller, $action, array $params, $needReturnData = false) {
		$mapper = $model->getCommMapper();
		$nodeResponse = $mapper->remoteAction($node, $controller, $action, $params);
		
		if ($nodeResponse->isError()) {
			$data = (string)$nodeResponse->getData();
			if ($nodeResponse->getData() instanceof Zwas_Exception) {
				$data = $nodeResponse->getData()->getMessageObject();
			}
			throw new Zwas_Exception($data);
		}
		
		if ($needReturnData) {
			return $nodeResponse->getData();
		} else {
			if ($nodeResponse->getData() !== 'OK') {
				throw new Zwas_Exception(Zwas_Translate::_('Incorrect response data returned from server'));
			}	
		}
		
	}
	
	/**
	 * @param Communication_Queue_Abstract $client
	 * @param array $nodes
	 * @param array $params
	 * @return Communication_Queue_Abstract
	 */
	protected function populateCommunicationQueue(Communication_Queue_Abstract $client, array $nodes, array $params) {
		foreach ($nodes as $node) { /* @var $node Nodes_Element_Mapper */
			$client->attachRequest($this->createRequest($client, $node, $params));
		}
		return $client;
	}
	
	/**
	 * @param Communication_Queue_Abstract $client
	 * @param Nodes_Element_Mapper $node
	 * @param array $params
	 * @return Communication_Queue_Request_Interface
	 */
	protected function createRequest(Communication_Queue_Abstract $client, Nodes_Element_Mapper $node, array $params) {
		$params['nodekey']= $node->getPassword();
		$request = $client->makeRequest($params, $node->getAddress(), $node->isRepresentative());
		$request->setNodeId($node->getId());
		return $request;
	}
}