<?php
class Nodes_Model_Plugin_ConnectMonitorToZSM extends Nodes_Model_Plugin_Abstract {
	
	/**
	 * @param Nodes_Model $model
	 * @param array $nodes array of Nodes_Element_Mapper elements
	 */
	public function postAction(Nodes_Model $model, array $nodes) {
		
		$monitorUiModel = new ZwasComponents_ZSM_MonitorUi_Model();
		$monitorConfigDirectives = $monitorUiModel->getNodeMonitorConfiguration();
		$directives = $this->filterConfigurationDirectives($monitorConfigDirectives);
		$params = array ();
		$params['controller']	= 'Node-Monitor-Component';
		$params['action']		= 'Connect-Monitor-To-Zsm';
		$params['module']		= 'PE';
		$params['directives'] 	= $directives;
			
		$client = $model->getCommMapper()->getClient();
		$this->populateCommunicationQueue($client, $nodes, $params);
		
		$responses = $client->sendRequests();
		$responses = new Nodes_Response_Collection($responses);
		
		$errorResponses = $responses->scanErrorResponses();
		if ($errorResponses->count() > 0) {
			$response = $errorResponses->current();
			$data = (string)$response->getData();
			if ($response->getData() instanceof Zwas_Exception) {
				$data = $response->getData()->getMessageObject();
			}
			Zwas_Log::err(new Zwas_Text('Failed on Nodes_Model_Plugin_ConnectMonitorToZSM post add node: %s', array($data)));
			throw new Zwas_Exception($data);
		}
	}
	
	/* (non-PHPdoc)
	 * @see Nodes_Model_Plugin_Abstract::createRequest()
	 */
	protected function createRequest(Communication_Queue_Abstract $client, Nodes_Element_Mapper $node, array $params) {
		$params['directives']['zend_monitor.node_id'] = $node->getId();
		return parent::createRequest($client, $node, $params);
	}
	
	/**
	 * @param array $directives
	 * @return array 
	 */
	private function filterConfigurationDirectives(array $directives) {
		$resultDirectives = array(
			'zend_monitor.database.type' 				=> '',
			'zend_monitor.database.name' 				=> '',
			'zend_monitor.database.host_name'			=> '',
			'zend_monitor.database.port'				=> '',
			'zend_monitor.database.user'				=> '',
			'zend_monitor.database.password'			=> '',
			'zend_monitor.node_id'						=> '',
		);

		foreach ($resultDirectives as $name => $value) {
			if (isset($directives[$name])) {
				$resultDirectives[$name] = $directives[$name]; 
			}
		}
		
		return $resultDirectives;
	}
	
}