<?php
class Nodes_Model_Plugin_ConnectNodeToSessionClustering extends Nodes_Model_Plugin_Abstract {
	
	/**
	 * @param Nodes_Model $model
	 * @param array $nodes array of Nodes_Element_Mapper elements
	 */
	public function postAction(Nodes_Model $model, array $nodes) {
		
		$sessionClusteringModel = new ZwasComponents_ZSM_SessionClustering_Model();
		$params = array('allowedHosts'	=> $sessionClusteringModel->getNodesAllowedHosts());
		$nodes = $model->getRespondingNodes();
		if (1 == count($nodes)) {
			$params['forceEnable']= 1;
		}
		$params['controller']	= 'Node-Session-Clustering';
		$params['action']		= 'Connect-Node-To-Session-Clustering';
		$params['module']		= 'PE';
		
		$client = $model->getCommMapper()->getClient();
		$this->populateCommunicationQueue($client, $nodes, $params);
		
		$responses = $client->sendRequests();
		$responses = new Nodes_Response_Collection($responses);
		
		foreach ($responses as $response) { /* @var $response Nodes_Response */
			if ($response->isError()) {
				$errorData = $response->getData();
				
				if ($errorData instanceof Exception) {
					$errorData = $errorData->getMessage();
				} else {
					$errorData = (string)$errorData;
				}
				Zwas_Log::err(new Zwas_Text('Failed on Nodes_Model_Plugin_ConnectNodeToSessionClustering post add node: %s', array($errorData)));
			}
		}
	}
	
	
	/* (non-PHPdoc)
	 * @see Nodes_Model_Plugin_Abstract::createRequest()
	 */
	protected function createRequest(Communication_Queue_Abstract $client, Nodes_Element_Mapper $node, array $params) {
		$params['hostname'] = $node->getHostname();
		return parent::createRequest($client, $node, $params);
	}
}
