<?php
class Nodes_Model_Plugin_GracefullShutdownSessionClustering extends Nodes_Model_Plugin_Abstract {
	
	/**
	 * @param Nodes_Model $model
	 * @param Nodes_Element_Mapper $node
	 */
	public function preAction(Nodes_Model $model, Nodes_Element_Mapper $node = null) {
		$nodeResponse = $model->getCommMapper()->remoteAction($node, 'Node-Session-Clustering', 'Graceful-Shutdown');
		if ($nodeResponse->isError()) {
			if($nodeResponse->getData() instanceof Zwas_Exception) {
				Zwas_Log::logMessage(
					new Zwas_Text(	Zwas_Translate::_('Communication error [%s]: %s'), 
									array($nodeResponse->getCode(), $nodeResponse->getData()->getMessage())),
					Zend_Log::ERR);
					
				throw new Nodes_Model_Plugin_Exception(
					Zwas_Translate::_('Could not communicate with the server'),
					Zwas_Exception::ERROR
				);
			}
			throw new Nodes_Model_Plugin_Exception(
				new Zwas_Text(
					Zwas_Translate::_('If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'), array()
				), 
				$nodeResponse->getCode()
			);
		}
		$scStatus = ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS;
		$result = $nodeResponse->getData();
		
		if (is_array($result)) {
			Zwas_Log::notice(new Zwas_Text(
				Zwas_Translate::_('Got the following response from the server while trying to gracefully shutdown its Session Clustering %s'),
				array(var_export($result, true))
			));
			if (is_array($result) && isset($result['messagePaneObj'])) {
				$message = $result['messagePaneObj']; /* @var $message MessagePane_Abstract */
				throw new Nodes_Model_Plugin_Exception(new Zwas_Text(
					// TRANSLATE
					Zwas_Translate::_('The server has returned the following message: %s'),
					array($message->getMessage())
				));
			} else {
				// TRANSLATE
				throw new Nodes_Model_Plugin_Exception(
					Zwas_Translate::_('The server has returned an invalid response. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center')
				);
			}
		}
		
		switch ($result) {
			case ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS:
				$scStatus = ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS;
				break;
			case ZwasComponents_SessionClustering_Model::SCD_STATUS_OFF:
				$scStatus = ZwasComponents_SessionClustering_Model::SCD_STATUS_OFF;
				break;
			case ZwasComponents_SessionClustering_Model::SCD_STATUS_STANDBY:
				$scStatus = ZwasComponents_SessionClustering_Model::SCD_STATUS_STANDBY;
				break;
			case ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_FAILED:
			case ZwasComponents_SessionClustering_Model::SCD_STATUS_OK:
			default:
				Zwas_Log::notice(new Zwas_Text(
					Zwas_Translate::_('Got status %s from the server while trying to gracefully shutdown its Session Clustering'),
					array($result)
				));
				throw new Nodes_Model_Plugin_Exception(new Zwas_Text(
					Zwas_Translate::_('The server is issuing a conflicting response. Manually shutdown the server you are trying to remove and reinstall Zend Server (%s)'), 
					array($nodeResponse->getData())
				));
		}
		$node->setScStatus($scStatus);
		$node->save();
		if ($node->getScStatus() == ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS) {
			// node is still in process, abort the removal chain in a graceful fashion
			throw new Nodes_Model_Delegate_Exception(
				Zwas_Translate::_('Session clustering daemon is in the process of shutting down. Try removing the node again later'), 
				Nodes_Model_Plugin_Exception::ABORT_PLUGIN_CHAIN
			);
		}
		return true;
	}
	
}