<?php

class Nodes_Response extends Node_Response {
	
	/**
	 * @var boolean
	 */
	private $distributedMvcErrors = false;
	/**
	 * @var boolean
	 */
	private $distributed = false;
	/**
	 * @var boolean
	 */
	private $representative;
	
	/**
	 * Determines if this response an MVC error object
	 * @return boolean
	 */
	public function isMvcError() {
		if (parent::isMvcError()) { // internal code based check
			return true;
		} elseif (! $this->isError()) {
			if (is_array($this->getData())) {
				$responseArray = $this->getData();
				if ((array_key_exists('messagePaneObj', $responseArray)) && ($responseArray['messagePaneObj'] instanceof MessagePane_Error)) {
					$PaneObjectMessage = $responseArray['messagePaneObj']->getMessage();
					if ((false !== strpos($PaneObjectMessage, 'Invalid controller specified'))
						|| (false !== strpos($PaneObjectMessage, 'does not exist and was not trapped in __call'))) {

						return true;
					}
				}
			}
		}
		return false;
	}
	
	/**
	 * @return boolean
	 */
	public function isRepresentative() {
		return $this->representative;
	}
	
	/**
	 * @return boolean
	 */
	public function isDistributed() {
		return $this->distributed;
	}

	/**
	 * Returns true if the collection that originally contained this response had any MvcErrors
	 * This method always returns false if the response was never returned as a representative response
	 * @return boolean
	 */
	public function hasDistributedMvcErrors() {
		if ($this->isDistributed()) {
			return $this->distributedMvcErrors;
		}
		return false;
	}

	/**
	 * @param boolean $distributedMvcErrors
	 * @return Nodes_Response
	 */
	public function setDistributedMvcErrors($distributedMvcErrors) {
		$this->distributedMvcErrors = $distributedMvcErrors;
		return $this;
	}

	/**
	 * @param boolean $distributed
	 * @return Nodes_Response
	 */
	public function setDistributed($distributed) {
		$this->distributed = $distributed;
		return $this;
	}

	/**
	 * @param boolean $representative
	 * @return Nodes_Response
	 */
	public function setRepresentative($representative) {
		$this->representative = $representative;
		return $this;
	}

}