<?php
/**
 * A collection of node responses.
 * This collection stores responses in any order with no regard to duplication, context or validity.
 */
class Nodes_Response_Collection extends Zwas_Collection {
	
	/**
	 * Scan collection for erranous responses.
	 * @return Nodes_Collection of nodes
	 */
	public function scanErrorResponses() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Response */
			if(($item instanceof Nodes_Response)
			&& ($item->isError())) {
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Scan collection for representative responses.
	 * @return Nodes_Collection of nodes
	 */
	public function scanRepresentativeResponses() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Response */
			if(($item instanceof Nodes_Response)
				&& ($item->isRepresentative() == 1)) {
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}

	/**
	 * Scan collection for specific response data.
	 * @param string|integer|object|array $data
	 * @return Nodes_Collection of nodes
	 */
	public function scanResponseDataOk() {
		$arrayCollection = array();
		foreach($this as $key => $item){/* @var $item Nodes_Response */
			if(($item instanceof Nodes_Response)
			&& ($item->getData() == 'OK')) {
				$arrayCollection[$key]= $item;
			}
		}
		$this->rewind();
		return $this->newCollection($arrayCollection);
	}
	
	/**
	 * Retrieve the first Representative response found
	 * @return Nodes_Response
	 * @throws Zwas_Collection_Exception
	 */
	public function getRepresentativeResponse() {
		$response = $this->scanRepresentativeResponses()->current();
		if ($response === false) {
			Zwas_Log::logMessage(Zwas_Translate::_('No representative response found'));
			throw new Zwas_Exception(Zwas_Translate::_('An internal application error has occurred.  If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'));
		}
		/* @var $response Nodes_Response */
		$response->setDistributed(true);
		$response->setDistributedMvcErrors($this->hasMvcErrors());
		return $response;
	}
	
	/**
	 * Does this collection have any responses with an error?
	 * @return boolean
	 */
	public function hasErrors() {
		return $this->scanErrorResponses()->count() > 0;
	}
	
	/**
	 * Scan through the collection for any response that is an MVC error
	 * @return boolean
	 */
	public function hasMvcErrors() {
		foreach ($this as $response) { /* @var $response Nodes_Response */
			if ($response->isMvcError()) {
				return true;
			}
		}
		return false;
	}
	
	protected function newCollection($items = array()) {
		return new Nodes_Response_Collection($items);
	}
}