<?php

class Nodes_Signatures_Table extends Zend_Db_Table_Abstract {

	protected $_name		= 'nodesSignature';
	protected $_primary		= array('nodeId', 'sigName');
	protected $_rowClass	= 'Nodes_Signatures_Element';
	
	/**
	 * @param integer $nodeId
	 * @param string $signatureName
	 * @param string $signature
	 * @return array Associative array of primary key(nodeId, sigName)
	 */
	public function setNodeSignature($nodeId, $signatureName, $signature) {
		$signatureRow = $this->getNodeSignature($nodeId, $signatureName);
		$signatureRow->setNodeId($nodeId)
			->setName($signatureName)
			->setValue($signature)
			->setTimestamp(time());
		return $signatureRow->save();
	}
	
	/**
	 * @param integer $nodeId
	 * @param string $signatureName
	 * @return Nodes_Signatures_Element - if there is no signature, the returned row has empty values
	 */
	public function getNodeSignature($nodeId, $signatureName) {
		$where = array(
				$this->getAdapter()->quoteInto('nodeId = ?', $nodeId),
				$this->getAdapter()->quoteInto('sigName = ?', $signatureName)
			);
			
		$row = $this->fetchRow($where);
		if (is_null($row)) {
			$row = $this->createRow();
		}
		return $row;
	}
	
	/**
	 * @param integer $nodeId
	 * @return Zend_Db_Table_Rowset_Abstract - if there is no signature, the returned rowset has no row elements
	 */
	public function getNodeSignatures($nodeId) {
		$where = array(
				$this->getAdapter()->quoteInto('nodeId = ?', $nodeId),
			);
			
		$rows = $this->fetchAll($where);
		if (is_null($rows)) {
			$rows = new Zend_Db_Table_Rowset();
		}
		return $rows;
	}
	
	/**
	 * @param integer $nodeId
	 * @return integer
	 */
	public function removeNodeSignatures($nodeId) {
		$where = $this->getAdapter()->quoteInto('nodeId = ?', $nodeId);
		return $this->delete($where);
	}
	
}
