<?php
class Upgrade_Conversion_Db_Collection {
	
	/**
	 * @var array
	 */
	private $conversions = array();
	/**
	 * @var Zend_Db_Adapter_Abstract
	 */
	private $dbAdapter;
	/**
	 * @var array
	 */
	private $messages = array();
	
	/**
	 * @param array $conversions
	 */
	public function __construct(array $conversions = null) {
		if (is_array($conversions)) {
			foreach($conversions as $conversion) {
				if ($conversion instanceof Upgrade_Conversion_Db_Abstract) {
					$this->addItem($conversion);
				}
			}
		}
	}
	
	/**
	 * @return array of Upgrade_Conversion_Db_Abstract elements
	 */
	public function getItems() {
		return $this->conversions;
	}
	
	/**
	 * Execute the conversion plan
	 * @param string $filepath
	 * @return string the last step's filepath
	 * @throws Conversion_Exception 
	 */
	public function convert($filepath) {
		$dirpath = dirname($filepath);
		$baseName = basename($filepath);
		$backupPath = ApplicationModel::getGuiTempDir();
		$myPid = getmypid();
		foreach ($this->conversions as $conversion) { /* @var $conversion Upgrade_Conversion_Db_Abstract */
			$backupFile = Zwas_Path::create($backupPath, "{$baseName}.{$myPid}.{$conversion->getOriginVersion()}");
			try {
				if (! Context_FileSystem::copy($filepath, $backupFile)) {
					throw new Zwas_Exception('Copy operation failed', $code);
				}
				Zwas_Log::debug(new Zwas_Text('Converted database backed up in %s', array($backupFile)));
			} catch (Zwas_Exception $e) {
				Zwas_Log::warn(new Zwas_Text('Backup operation failed: %s', array($e->getMessageObject())));
				$this->messages[]= new Zwas_Text(Zwas_Translate::_('Backup operation failed: %s'), array($e->getMessageObject()));
			}
			
			try {
				$conversion->convert($this->dbAdapter);
			} catch (Upgrade_Conversion_Exception $e) {
				if ($e->getCode() == Upgrade_Conversion_Exception::ERROR) {
					throw new Upgrade_Conversion_Exception(
						new Zwas_Text(Zwas_Translate::_('Conversion to schema v%s failed: %s'), 
						array($conversion->getTargetVersion(), $e->getMessageObject())), $e->getCode()
					);
				} elseif ($e->getCode() == Upgrade_Conversion_Exception::WARNING) {
					Zwas_Log::warn($e->getMessageObject());
					$this->messages[]= $e->getMessageObject();
				}
			}
			Zwas_Log::debug(new Zwas_Text('Conversion from version %s to %s was completed', array($conversion->getOriginVersion(), $conversion->getTargetVersion())));
		}
		Zwas_Log::info(new Zwas_Text('Conversion was completed with %s warnings', array(count($this->messages))));
		return $filepath;
	}
	
	/**
	 * @param Zend_Db_Adapter_Abstract $adapter
	 * @return Upgrade_Conversion_Db_Collection
	 */
	public function setAdapter(Zend_Db_Adapter_Abstract $adapter) {
		$this->dbAdapter = $adapter;
		return $this;
	}
	
	/**
	 * @param Upgrade_Conversion_Db_Abstract $conversion
	 * @return Upgrade_Conversion_Db_Collection
	 */
	public function addItem(Upgrade_Conversion_Db_Abstract $conversion) {
		$this->conversions[ $conversion->getOriginVersion() ]= $conversion;
		Zwas_Log::debug(
			new Zwas_Text(Zwas_Translate::_('Added conversion from %s to %s'), 
			array($conversion->getOriginVersion(), $conversion->getTargetVersion()))
		);
		return $this;
	}
	
	/**
	 * @return array
	 */
	public function getMessages() {
		return $this->messages;
	}

}