<?php
abstract class ZwasComponents_MonitorUi_UiEvent_Abstract {
	
	/**
	 * The relevant Monitor UI constant type
	 * @var integer
	 */
	protected $type = 0;

	/**
	 * @var Nodes_Element_Mapper
	 */
	protected $node;
	
	/**
	 * Report the event
	 */
	public function report() {
		if (0 === $this->type) {
			throw new Zwas_Exception(Zwas_Translate::_('Invalid type provided for reporting'), Zwas_Exception::ASSERT);
		}
		
		try {
			Context_Api::getMonitorUiApi()->reportGuiEvent(
							$this->type,
							trim($this->getEventDetails())
			);
		} catch (Zwas_Exception $e) {
			// do nothing
		}
	}
	
	/**
	 * @return Nodes_Element_Mapper
	 */
	public function getNode() {
		return $this->node;
	}
	
	/**
	 * @param Nodes_Element_Mapper $node
	 * @return ZwasComponents_MonitorUi_UiEvent_NodeAdded
	 */
	public function setNode(Nodes_Element_Mapper $node) {
		$this->node = $node;
		return $this;
	}
	
	/**
	 * Return XML formatted data of the event details
	 * @return string
	 */
	protected function getEventDetails() {
		if (! ($this->getNode() instanceof Nodes_Element_Mapper)) {
			throw new Zwas_Exception(Zwas_Translate::_('Missing Server'), Zwas_Exception::ASSERT);
		}
		
		if ($this->getNode()->isDeleted()) {
			throw new Zwas_Exception(Zwas_Translate::_('Possibly deleted server'), Zwas_Exception::ASSERT);
		}
		
		$nodeId = array(
			'label'	=> Zwas_Translate::_('Server ID'),
			'value'	=> $this->node->getId(),
		);
		$nodeName = array(
			'label'	=> Zwas_Translate::_('Server Name'),
			'value'	=> $this->node->getName(),
		);
		$nodeAddress = array(
			'label'	=> Zwas_Translate::_('Server Address'),
			'value'	=> $this->node->getHostname(),
		);
		
		return <<<XML
		<?xml version="1.0" encoding="UTF-8"?>
		<details>
			<items>
				<item>
					<label><![CDATA[{$nodeId['label']}]]></label>
					<value><![CDATA[{$nodeId['value']}]]></value>
				</item>
				<item>
					<label><![CDATA[{$nodeName['label']}]]></label>
					<value><![CDATA[{$nodeName['value']}]]></value>
				</item>
				<item>
					<label><![CDATA[{$nodeAddress['label']}]]></label>
					<value><![CDATA[{$nodeAddress['value']}]]></value>
				</item>
			</items>
		</details>
XML;
	}
}