<?php
class ZwasComponents_ZSM_CodeTracing_Model extends ZwasComponents_CodeTracing_Model {
	
	/**
	 * Retrieve an AMF details file from a remote node
	 * 
	 * @param integer $dumpId
	 * @param integer $nodeId
	 * @return ZwasComponents_CodeTracing_Dump_AmfDetails
	 * @throws Zwas_Exception
	 */
	public function getDumpFileAmfDetails($dumpId) {
		$dumpRow = self::getTraceFilesTable()->getDumpById($dumpId);
		if(! is_null($dumpRow)) {
			$nodesModel = new Nodes_Model();
			$data = $nodesModel->getCommMapper()->remoteAction(
				$nodesModel->getNode($dumpRow->getNodeId()), 
				'Node-Code-Tracing-Amf', 
				'Fetch-Amf', 
				array('dumpId' => $dumpRow->getTraceId())
			);
			
			if (! $data->isError()) {
				$filename = self::getDumpFilePrefix() . '.' . $dumpRow->getTraceId() .'.amf';
				/// write the retrieved file content into a remote.dumpid to be processed normally by the dumpFileDetails method
				$fileObject = Context_FileSystem::getFileObject($filename,'w+');
				$fileObject->fwrite($data->getData());
				$fileObject->rewind();
			} else {
				Zwas_Log::logMessage(
					new Zwas_Text(Zwas_Translate::_('Retrieving data from the server returned [%s] %s'), array($data->getCode(), $data->getMessage()))
				);
				throw new Zwas_Exception(Zwas_Translate::_('Failed to retrieve the trace file data from the server'));
			}
		} else {
			Zwas_Log::logMessage(new Zwas_Text(
				Zwas_Translate::_('Could not locate the requested trace file details for trace id %s'),
				array($dumpId)
			));
			throw new Zwas_Exception(Zwas_Translate::_('Could not locate the requested trace file details'));
		}
		return self::generateAmfFileResult($fileObject);
	}
	
	/**
	 * @param $dumpFileName
	 * @return string
	 */
	public function getDumpIdByFileName($dumpFileName){
		if (preg_match('#\.([[:digit:]]+\.[[:digit:]]+\.[[:digit:]]+)$#', $dumpFileName, $matches)) {
			$dumpId = $matches[1];
			/// we can't use ZwasComponents_CodeTracing_Model::getDumpIdByFile
			/// it assumes usage of local path variables, which may or may not 
			/// conform to that of the node that created the trace originally
			$traceTable = self::getTraceFilesTable();
			$traceRow = $traceTable->fetchRow($traceTable->getAdapter()->quoteInto('trace_id = ?', $dumpId));
			if ((is_null($traceRow)) || (! $traceRow->getTraceId())) {
				// TRANSLATE
				Zwas_Log::logMessage('Could not find a trace file row', Zend_Log::WARN);
				throw new Zwas_Exception(Zwas_Translate::_('Could not find a trace file row'));
			}
			return $traceRow->getTraceId();
		}
		// TRANSLATE
		Zwas_Log::logMessage('Could not extract the trace ID from the file name', Zend_Log::WARN);
		throw new Zwas_Exception(Zwas_Translate::_('Could not extract the trace ID from the file name'));
	}
	
	/**
	 * @param array $dumpIds
	 * @return array
	 */
	public function deleteDumpsDatabase(array $dumpIds) {
		$deleteDelegate = new ZwasComponents_ZSM_CodeTracing_Model_Delegate_Delete();
		return $deleteDelegate->deleteDumpsDatabase($dumpIds);
	}
	
	/**
	 * @param array $dumpIds
	 * @return array of dump IDs which couldn't be deleted
	 * @throws Zwas_Exception
	 */
	public function deleteDumps(array $dumpIds) {
		$deleteDelegate = new ZwasComponents_ZSM_CodeTracing_Model_Delegate_Delete();
		return $deleteDelegate->deleteDumps($dumpIds);
	}
	
}