<?php

class ZwasComponents_ZSM_CodeTracing_Model_Delegate_Delete extends ZwasComponents_CodeTracing_Model_Delegate_Delete{
	
	/**
	 * @var Nodes_Model
	 */
	private $nodesModel;
	/**
	 * @param array $dumpIds
	 * @return array of dump IDs which couldn't be deleted
	 * @throws Zwas_Exception
	 */
	public function deleteDumps(array $dumpIds) {
		if(count($dumpIds) == 0) {
			return array();
		}
		
		$dumpsToNodes = ZwasComponents_CodeTracing_Model::getTraceFilesTable()->getNodeIdsByTraceIds($dumpIds);
		/// run through all dumpIds, break apart into separate nodeIds
		$nodesToDumps = array();
		foreach ($dumpsToNodes as $dumpId => $nodeId) {
			if(isset($nodesToDumps [$nodeId])) {
				$nodesToDumps [$nodeId][]= $dumpId;
			} else {
				$nodesToDumps [$nodeId]= array($dumpId);
			}
		}
		
		$failedIds = array();
		$localNodesToDelete = array();
		$nodesModel = $this->getNodesModel();
		foreach($nodesToDumps as $nodeId => $dumps) {
			if($nodeId > 0) { // nodeId = 0|-1 is the cluster manager itself. These dumps will be handled later.
				try {
					$node = $nodesModel->getNode($nodeId);
				} catch(Zwas_Exception $e) {
					/// node is not connected or does not exist, skip ahead
					continue;
				}
				//Remove the binary + any leftover amf related from node
				$response = $nodesModel->getCommMapper()->remoteAction($node, 'Node-Code-Tracing', 'Delete-Dumps', array('dumps' => $dumps))->getData();
				if (count($response) > 0) {
					if (is_array($response) && is_string(current($response))) {
						$failedIds = array_merge($failedIds, $response);
					} else { /// we assume all of of the node's dumps failed to be deleted
						$failedIds = array_merge($failedIds, $dumps);
					}
				}
			}
		}
		//Remove the binary + any leftover amf from the manager
		/// we do not care about failures here, amf files can be
		/// regenerated as needed and no dump files are actually present.
		/// IDs that failed in the nodes should not be removed on zscm.
		$localFailedIds = parent::deleteDumps(array_diff($dumpIds, $failedIds));
		return $localFailedIds + $failedIds;
	}
	
	
	/**
	 * @return Nodes_Model
	 */
	public function getNodesModel() {
		if (is_null($this->nodesModel)) {
			$this->nodesModel = new Nodes_Model();
		}
		return $this->nodesModel;
	}
	
	/**
	 * @param Nodes_Model $nodesModel to set
	 * @return ZwasComponents_ZSM_CodeTracing_Model_Delegate_Delete
	 */
	public function setNodesModel(Nodes_Model $nodesModel) {
		$this->nodesModel = $nodesModel;
		return $this;
	}

}

