<?php

class ZwasComponents_ZSM_JobQueue_Model extends ZwasComponents_ZSM_ProbeModel {
	
	public function getController() {
		return 'Node-Job-Queue';
	}
	
	/**
	 * save binding directive
	 * @param string $daemonBinding - an scheme://IP:port pointing to where the daemon is located 
	 * @param string $daemonListen - an scheme://IP:port on which the JQ daemon should be listening
	 */
	public static function saveBindingDirective($daemonBinding, $daemonListen) {
		ZwasComponents_JobQueue_Binding::saveZwasBindingDirective($daemonBinding);
	}
	
	/**
	 * Returns whether the component's status is supposed to be on or off
	 * taking into consideration possible future restart action
	 *
	 * @return boolean
	 */
	public function isActivated() {
		
		return Context_Api::getJobQueueApi()->isRunning();
	}
	
	/**
	 * @return string
	 * @throws Zwas_Exception
	 */
	public function getZendServerHostBoundAddress() {
		$ipAddress = ZwasComponents_JobQueue_Model::getZendServerHostBinding();
		$results = preg_match('#tcp://([^:]+):[[:digit:]]+#', $ipAddress, $matches);
		
		$validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_LOCAL|Zend_Validate_Hostname::ALLOW_IP,false,false,new Zend_Validate_Ip());
		if(($results) && (isset($matches[1])) && ($validator->isValid($matches[1]))) {
			return $matches[1];
		} else {
			Zwas_Log::logMessage('Job Queue host binding is not an IP address.', Zend_Log::WARN);
			// TRANSLATE
			throw new Zwas_Exception(Zwas_Translate::_('Job Queue host binding is not an IP address.'));
		}
	}
	
	/**
	 * Function that gets ip/hostname in ZS JobQ format (tcp as the protocol and default port '10085' and returns the ip/host alone
	 * @param unknown_type $ipAddress
	 * @return string ip/host address
	 */
	public function getHostFromBindning($binding) {
		
		$results = preg_match('#tcp://([^:]+):[[:digit:]]+#', $binding, $matches);
		$validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
		
		if (! $validator->isValid($matches[1])) {
			throw new Zwas_Exception(Zwas_Translate::_("Invalid IP/host address entered"));
		}
		return $matches[1];
		
	}
}