<?php
/**
 * @uses viewHelper Zend_View_Helper_Abstract
 */
abstract class Zwas_View_Helper_Common_Table extends Zend_View_Helper_Abstract {
	
	/**
	 * @var integer
	 */
	protected $sortBy;
	/**
	 * @var integer
	 */
	protected $sortDirection;
	
	/**
	 * @param array $dumps
	 * @param string $sortBy
	 * @param string $sortDirection
	 * @return string
	 */
	protected function getTable(array $rowRecords, $sortBy = null, $sortDirection = null) {
		$this->sortBy			= $sortBy;
		$this->sortDirection	= $sortDirection;
		
		return <<<TABLE
<table cellpadding="0" cellspacing="0" class="extensions t100">
<thead>{$this->getTableHeader()}</thead>
<tbody>{$this->getRows($rowRecords)}</tbody>
</table>
TABLE;
	}
	
	/**
	 * Get the action which should be provoked when clicking this element
	 * @param string $controller
	 * @param string $action
	 * @param string $idName
	 * @param integer $id
	 * @return string
	 */
	protected function getViewOnClickAction($controller, $action, $idName, $id) {
		$url = $this->view->url(array(	'controller'	=> $controller,
										'action'		=> $action,
										$idName		=>  $id));

		return "dumpsList.detach('{$url}');";
	}
	
	/**
	 * @param string $controller
	 * @param string $action
	 * @param string $title
	 * @param integer $sortKey
	 * @param string $additionalClass
	 * @return string
	 */
	protected function getSortableColumn($controller, $action, $title, $sortKey, $additionalClass = '') {
		$sortUrlOptions = array('controller'	=> $controller,
								'action'		=> $action);
		$direction = 'DESC';
		$sortClass = '';
		if ($sortKey == $this->sortBy) {
			if ($this->sortDirection == 'ASC') {
				$sortClass = 'sort-asc';
			} else {
				$direction = 'ASC';
				$sortClass = 'sort-desc';
			}
		}
		$sortUrlOptions['sort']			= $sortKey;
		$sortUrlOptions['direction']	= $direction;
		$sortUrl = $this->view->url($sortUrlOptions, null, true);
		
		$class = ($additionalClass) ? " class=\"{$additionalClass}\"" : '';
		return "
			<th{$class}>
				<div class=\"hand {$sortClass}\" onclick=\"zend.doGet('{$sortUrl}', 'content-data-inner');\">{$this->view->escape($title)}</div>
			</th>";
	}
	
	protected function getHeaderSeparator($colSpan) {
		return "<tr class=\"header-separator\"><td colspan=\"$colSpan\">&nbsp;</td></tr>";
	}
	/**
	 * @return string
	 */
	protected abstract function getTableHeader();
	/**
	 * @param array $rowRecords
	 * @return string
	 */
	protected abstract function getRows(array $rowRecords);
}
