<?php
/**
 * Zwas_View_Helper_ComponentMessageDetails helper
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_ComponentMessageDetails extends Zend_View_Helper_Abstract {
	
	/**
	 * @var array
	 */
	private $blackList = array(
		'This component\'s status will change to "Off" after the PHP is restarted' => 0,
		'This component\'s status will change to "On" after the PHP is restarted' => 1
	);
	
	/**
	 * @param string $componentName the component name without the leading "ext-"
	 * @return string
	 */
	public function componentMessageDetails($componentName) {
		$clusterModel = new ClusterZendComponents_Model();
		$messages = $clusterModel->getComponentMessages($componentName);
		
		if ($this->isUniformHash($messages)) {
			$message = current($messages);
			if ($message instanceof Nodes_Component_Element) {
				return (string)$message->getErrorString();
			} else {
				Zwas_Log::warn(new Zwas_Text(
					Zwas_Translate::_('Got the wrong type of component message element - %s'),
					array(is_object($message) ? get_class($message) : gettype($message))
				));
				return '';
			}
		}
		
		$filteredMessages = array();
		foreach ($messages as $componentElement) { /* @var $componentElement Nodes_Component_Element */
			if (! isset($this->blackList[ $componentElement->getErrorString() ])) {
				$filteredMessages[] = $componentElement;
			}
		}
		
		$messagesCount = count($filteredMessages);
		if (0 == $messagesCount) {
			// all messages were filtered out
			return '';
		} else if ($messagesCount > 1) {
			// TRANSLATE
			$information = new Zwas_Text(Zwas_Translate::_('Problems encountered on %s servers.'), array($messagesCount));
		} else {
			// TRANSLATE
			$information = Zwas_Translate::_('Problems encountered on 1 server.');
		}
		
		return	$information .
				' <a class="show-extension-details" onclick="zendComponents.toggle(\'ext-' . $this->inflection($componentName) . '\', this)" href="javascript:void(0)">' .
				Zwas_Translate::_('Details') .
				'</a>';

	}
	
	private function inflection($componentName) {
		return str_replace(' ', '-', $componentName);
	}
	
	/**
	 * @param array $messages
	 * @return boolean
	 */
	private function isUniformHash($messages) {
		$nodesModel = new Nodes_Model();
		if (count($nodesModel->getRespondingNodes()) != count($messages)) {
			return false;
		}
		
		$uniformHash = null;
		
		/// scan for identical case
		foreach ($messages as $componentElement) { /* @var $componentElement Nodes_Component_Element */
			if (is_null($uniformHash)) {
				$uniformHash = $componentElement->getComponentHash();
				continue;
			}
			
			if ($componentElement->getComponentHash() != $uniformHash) {
				return false;
			}
		}
		return true;
	}
}