<?php
require_once 'Common/Table.php';
/**
 * Zwas_View_Helper_DashboardNodesList
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_DashboardNodesList extends Zwas_View_Helper_Common_Table {
	
	/**
	 * @param array $nodesList
	 * @return string
	 */
	public function dashboardNodesList(array $nodesList) {
		return $this->dashboardNodesTable($nodesList);
	}
	
	/**
	 * 
	 */
	protected function getTableHeader() {
		return <<<HEADER
<tr class="header">
	<th>{$this->view->escape(Zwas_Translate::_('Status'))}</th>
	<th>{$this->view->escape(Zwas_Translate::_('Id'))}</th>
	<th>{$this->view->escape(Zwas_Translate::_('Server Name'))}</th>
	<th class="w100">{$this->view->escape(Zwas_Translate::_('Server Address'))}</th>
</tr>
{$this->getHeaderSeparator(4)}
HEADER;
	}
	
	/**
	 * @param array $rowRecords
	 */
	protected function getRows(array $rowRecords) {
		$nodesTable = '';
		foreach ($rowRecords as $node) { /** @var Nodes_Element_Mapper $node */
			$nodesTable .= <<<ROW
<tr>
	<td>{$this->view->serversList($node)->getStatusIcon()}</td>
	<td>{$node->getId()}</td>
	<td class="no-wrap">{$this->view->escape($node->getName())}</td>
	<td>{$this->view->escape($node->getAddress())}</td>
</tr>
ROW;
		}
		return $nodesTable;
	}
		
	private static function orderNodes($nodes) {
		$errorNodes = array();
		$offlineNodes = array();
		$onlineNodes = array();
		foreach ($nodes as $node) {
			switch ($node->getStatus()) {
				case Nodes_Element::STATUS_ONLINE:
					$onlineNodes[] = $node;
					break;
				case Nodes_Element::STATUS_OFFLINE:
					$offlineNodes[] = $node;
					break;
				case Nodes_Element::STATUS_ERROR:
					$errorNodes[] = $node;
					break;
			}	
		}
		
		return array_merge($errorNodes, $offlineNodes, $onlineNodes);
	}
	
	private function dashboardNodesTable($nodesList) {
		//prepare nodes
		if (! count($nodesList)){
			return '';
		}
		return $this->getTable($nodesList);
	}
	
	private function messageTypeToClass($type) {
		switch($type) {
			case MessagePane_Abstract::MESSAGE_PANE_ERROR:
				return 'error';
				break;
			case MessagePane_Abstract::MESSAGE_PANE_NOTICE:
				return 'notice';
				break;
			case MessagePane_Abstract::MESSAGE_PANE_SUCCESS:
				return 'success';
				break;
			case MessagePane_Abstract::MESSAGE_PANE_INFO:
				return 'info';
				break;
		}
	}
	
	private function dashboardMessage(MessagePane_Abstract $message = null) {
		if (is_null($message)) {
			return '';
		}
		$msgType = $this->messageTypeToClass($message->getType());
		$messageText = $message->getMessage();
			return <<<MESSAGE
<div id="message-pane1" class="message-pane $msgType" style="display: block;">
<table border="0" cellspacing="0" cellpadding="0" class="w100">
<tr>
<td class="top-left-corner"></td>
<td class="top-line"></td>
<td class="top-right-corner"></td>		
</tr>	
<tr>	
<td class="left-line"></td>		
<td class="center">
$messageText
</td>
<td class="right-line"></td>
</tr>
<tr>
<td class="bottom-left-corner"></td>	
<td class="bottom-line"></td>	
<td class="bottom-right-corner"></td>	
</tr>
</table>
</div>
MESSAGE;
	}
}
