<?php
/**
 * Zwas_View_Helper_ExtensionAction helper
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_ExtensionAction extends Zend_View_Helper_Abstract {
	
	/**
	 * @param string $extensionName
	 * @return string
	 */
	public function extensionAction($extensionName) {
		$extensionsModel = new ClusterPhpExtensions_Model();
		
		if (! $extensionsModel->extensionExists($extensionName)) {
			return '';
		}

		$label = '';
		$action = '';
		
		/* @var $extension Nodes_Extension_Element */
		$extension = $extensionsModel->getRepresentativeExtension($extensionName);
		
		// Check that a real extension was retrieved
		if ('' == $extension->getName()) {
			return '';
		}
		
		$iniStatus 		= $extension->getIniStatus();
		$fileExists 	= $extension->fileExists();
		$loaded 		= $extension->isLoaded();
		$awaitRestart	= $extension->awaitsRestart();
		
		if (Extensions_ElementAbstract::INI_ENABLED === $iniStatus) {
			if ($fileExists) {
				if ($loaded) {
					// Loaded and unloadable
					$label = Zwas_Translate::_('Turn off');
					$action = 'Unload-Extension';
				} else {	// else, not Loaded
					if ($awaitRestart) {
						$label = Zwas_Translate::_('Turn off');
						$action = 'Unload-Extension';
					} else {
						// Enabled and file exists but extension is not loaded - Failed to load the extension
						return '';
					}
				}
			} else {	// else, file not exists
				if ($loaded) {
					// Built-in and also enabled (without a reason) - should be disabled
					$label = Zwas_Translate::_('Turn off');
					$action = 'Fix-Extension';
				} else {	// else, not loaded
					// Extension in not loaded, file not exists but extension is enabled - should be disabled
					$label = Zwas_Translate::_('Turn off');
					$action = 'Fix-Extension';
				}
			}
		} else {	// else, extension is not enabled in the ini file
			if ($fileExists) {
				if ($loaded) {
					if ($awaitRestart) {
						$label = Zwas_Translate::_('Turn on');
						$action = 'Load-Extension';
					} else {
						// Extension is built-in , extension file also exists
						$label = Zwas_Translate::_('Built-in');
					}
				} else {	// else, not loaded
					// Not loaded and loadable
					$label = Zwas_Translate::_('Turn on');
					$action = 'Load-Extension';
				}
			} else {	// else, file not exists
				if ($loaded) {
					// Extension is built-in
					$label = Zwas_Translate::_('Built-in');
				} else {
					// Should never reach here - extension is not loaded, file doesn't exist and nothing in the ini file
					return ''; 
				}
			}
		}
		
		if ('' == $action) {
			return $label;
		}
		
		$onclick = $this->view->contentLoader(
			'Configuration', 
			$action,
			array('name' => $extensionName),
			MenuItem::generateId('Configuration', 'Extensions')
		);
		
		return '<a onclick="' . $onclick . '">' . $label . '</a>';
	}
	
}