<?php
/**
 * Zwas_View_Helper_ExtensionMessageDetails helper
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_ExtensionMessageDetails extends Zend_View_Helper_Abstract {
	
	/**
	 * @param string $extensionName the extension name without the leading "ext-"
	 * @param array $nodesMessages array of the structure array(<extName> => array(array(<serverName>,<message>),...))
	 * @return string
	 */
	public function extensionMessageDetails($extensionName) {
		$clusterModel = new ClusterPhpExtensions_Model();
		$messages = $clusterModel->getExtensionsWithMessagesByExtensionName($extensionName);
		
		if (0 == count($messages)) {
			return '';
		}
		
		$serverCount = count($messages);
		if (0 == $serverCount) {
			return '';
		}
		
		
		if ($this->isUniformHash($messages)) {
			return (string)current($messages)->getErrorString();
		}
		
		
		if ($serverCount > 1) {
			$output = new Zwas_Text(
							// TRANSLATE
							Zwas_Translate::_('Problems encountered on %s servers.'),
							array($serverCount)
						);
		} else {
			// TRANSLATE
			$output = Zwas_Translate::_('Problems encountered on 1 server.');
		}
		$output .= new Zwas_Text(
						' <a class="show-extension-details" onclick="extensions.toggle(\'ext-%s\', this)" href="javascript:void(0)">',
						array($extensionName)
					);
		// TRANSLATE
		$output .= Zwas_Translate::_('Details');
		$output .= '</a>';
		
		return (string)$output;
	}
	
	/**
	 * @param array $messages
	 * @return boolean
	 */
	private function isUniformHash($messages) {
		$nodesModel = new Nodes_Model();
		if ($nodesModel->countNodes() != count($messages)) {
			return false;
		}
		
		$uniformHash = null;
		
		/// scan for identical case
		foreach ($messages as $extensionElement) { /* @var $extensionElement Nodes_Extension_Element */
			if (is_null($uniformHash)) {
				$uniformHash = $extensionElement->getExtensionHash();
				continue;
			}
			
			if ($extensionElement->getExtensionHash() != $uniformHash) {
				return false;
			}
		}
		return true;
	}
}