<?php
/**
 * Zwas_View_Helper_ExtensionStatus helper
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_ExtensionStatus extends Zend_View_Helper_Abstract {
	
	const ICON_GREEN	= '/images/icons/led-green.gif';
	const ICON_GREY		= '/images/icons/led-grey.gif'; 
	const ICON_RED		= '/images/icons/led-red.gif';
	const ICON_NOTICE	= '/images/icons/led-green-notice.gif';
	
	/**
	 * @param string $extensionName
	 * @return string
	 */
	public function extensionStatus($extensionName) {
		$extensionsModel = new ClusterPhpExtensions_Model();
		
		if (! $extensionsModel->extensionExists($extensionName)) {
			return '';
		}

		$image = '';
		$tooltipContent = '';
		$id = 'status-' . strtolower($extensionName);
		
		if ($extensionsModel->isExtensionUnstable($extensionName)) {
			$image = self::ICON_NOTICE;
			// TRANSLATE
			$tooltipContent = Zwas_Translate::_('Cluster misconfiguration');
		} else {
			/* @var $extension Nodes_Extension_Element */
			$extension = $extensionsModel->getExtension($extensionName)->current();
			
			$iniStatus 		= $extension->getIniStatus();
			$fileExists 	= $extension->fileExists();
			$loaded 		= $extension->isLoaded();
			$awaitRestart	= $extension->awaitsRestart();
			
			if (Extensions_ElementAbstract::INI_ENABLED === $iniStatus) {
				if ($fileExists) {
					if ($loaded) {
						// Loaded and unloadable
						$image = self::ICON_GREEN;
						$tooltipContent =  Zwas_Translate::_('Currently turned on');
					} else {	// else, not Loaded
						if ($awaitRestart) {
							// Will be loaded after restart (file exists and was enabled)
							$image = self::ICON_GREY;
							$tooltipContent =  Zwas_Translate::_('Currently turned off');
						} else {
							// Enabled and file exists but extension is not loaded - Failed to load the extension
							$image = self::ICON_RED;
							$tooltipContent =  Zwas_Translate::_('There was an error');
						}
					}
				} else {	// else, file not exists
					if ($loaded) {
						// Built-in and also enabled (without a reason) - should be disabled
						$image = self::ICON_GREEN;
						$tooltipContent =  Zwas_Translate::_('There was an error');						
					} else {	// else, not loaded
						// Extension in not loaded, file not exists but extension is enabled - should be disabled
						$image = self::ICON_RED;
						$tooltipContent =  Zwas_Translate::_('There was an error');
					}
				}
			} else {	// else, extension is not enabled in the ini file
				if ($fileExists) {
					if ($loaded) {
						if ($awaitRestart) {
							// Extension is built-in , extension file also exists
							$image = self::ICON_GREEN;
							$tooltipContent =  Zwas_Translate::_('Currently turned on');
						} else {
							$image = self::ICON_GREEN;
							$tooltipContent =  Zwas_Translate::_('Currently turned on');							
						}
					} else {	// else, not loaded
						// Not loaded and loadable
						$image = self::ICON_GREY;
						$tooltipContent =  Zwas_Translate::_('Currently turned off');
					}
				} else {	// else, file not exists
					if ($loaded) {
						// Extension is built-in
						$image = self::ICON_GREEN;
						$tooltipContent =  Zwas_Translate::_('Currently turned on');						
					} else {
						// Should never reach here - extension is not loaded, file doesn't exist and nothing in the ini file
						return '';
					}
				}
			}
		}
		
		$result = <<<STATUS
		<div id="{$id}" class="icon-led"><img src="{$this->view->baseurl($image)}" /></div>
STATUS;

		if ('' !== $tooltipContent) {
			$result .= <<<TOOLTIP
		<span dojoType="dijit.Tooltip" connectId="{$id}">
			<div class="limitedTooltip">{$tooltipContent}</div>
		</span>
TOOLTIP;
		}
		
		return $result;
	}
	
}