<?php
/**
 * @uses viewHelper Zwas_View_Helper
 */
 require_once(ZEND_SERVER_APP_PATH . '/PE/views/helpers/Common/IssueEventGroups.php');

class Zwas_View_Helper_IssueEventGroups extends Zwas_View_Helper_Common_IssueEventGroups {
	
	private static $nodes = null;
	
	/**
	 * @param ZwasComponents_MonitorUi_Issue_Groups $group
	 * @param int $issueType
	 * @return string
	 */
	public function issueEventGroups(ZwasComponents_MonitorUi_Issue_Groups $eventGroups, $issueType) {
		switch ($issueType) {
			case ZM_TYPE_ZSM_CONFIGUATION_MISMATCH:
			case ZM_TYPE_ZSM_NODE_ADDED_SUCCESSFULLY:
			case ZM_TYPE_ZSM_NODE_REMOVED_SUCCESSFULLY:
			case ZM_TYPE_ZSM_NODE_IS_NOT_RESPONDING:
			case ZM_TYPE_ZSM_NODE_ENABLED_SUCCESSFULLY:
			case ZM_TYPE_ZSM_NODE_DISABLED_SUCCESSFULLY:
			case ZM_TYPE_ZSM_RESTART_FAILED:
				return $this->zscmIssueEventGroups($eventGroups, $issueType);
				break;
			case ZM_TYPE_CUSTOM:
			case ZM_TYPE_FUNCTION_SLOW_EXEC:
			case ZM_TYPE_FUNCTION_ERROR:
			case ZM_TYPE_REQUEST_SLOW_EXEC:
			case ZM_TYPE_REQUEST_RELATIVE_SLOW_EXEC:
			case ZM_TYPE_REQUEST_LARGE_MEM_USAGE:
			case ZM_TYPE_REQUEST_RELATIVE_LARGE_MEM_USAGE:
			case ZM_TYPE_REQUEST_RELATIVE_LARGE_OUT_SIZE:
			case ZM_TYPE_ZEND_ERROR:
			case ZM_TYPE_JAVA_EXCEPTION:
			case ZM_TYPE_JQ_JOB_EXEC_ERROR:
			case ZM_TYPE_JQ_JOB_LOGICAL_FAILURE:
			case ZM_TYPE_JQ_JOB_EXEC_DELAY:
			case ZM_TYPE_JQ_DAEMON_HIGH_CONCURRENCY_LEVEL:
			case ZM_TYPE_TRACER_FILE_WRITE_FAIL:
			default:
				return $this->nodeIssueEventGroups($eventGroups, $issueType);
		}
	}
	
	private function zscmIssueEventGroups(ZwasComponents_MonitorUi_Issue_Groups $eventGroups, $issueType) {
		$thTime				= Zwas_Translate::_('Last Time');
		$thOccurrences		= Zwas_Translate::_('Count');
		
		$tableString = "<div id=\"mui-event-groups-div\">
						<table class=\"extensions\" id=\"mui-event-groups\">
							<thead>
								<tr class=\"header\">
									<th>{$thTime}</th>
									<th>{$thOccurrences}</th>
								</tr>
								<tr class=\"header-separator\" style=\"background:none;\">
									<td colspan=\"2\" style=\"border:none;\"></td>
								</tr>
							</thead>
							<tbody>";
		
		$issueId = $eventGroups->getIssueId();
		
		foreach ($eventGroups as $row) {
			$url 		= $this->getTabLoadUrl($issueId, $row[ZM_DATA_EVENT_ID]);
			$link		= "issueDetails.selectGroupData(this, '{$url}');";
			$time		= date(ApplicationModel::getDateFormat(ApplicationModel::DATE_FORMAT_MEDIUM), $row[ZM_DATA_FIRST_TIMESTAMP]);
			$repeats	= $row[ZM_DATA_REPEATS];

			$tableString.= "<tr onclick=\"{$link}\" class=\"hand mui-hover\">
								<td>{$time}</td>
								<td>{$repeats}</td>
							</tr>";
		}
		
		$tableString.= '</tbody></table></div>';
		return $tableString;
	}
	
	private function nodeIssueEventGroups(ZwasComponents_MonitorUi_Issue_Groups $eventGroups, $issueType) {
		$thNode				= Zwas_Translate::_('Server');
		$thTime				= Zwas_Translate::_('Last Time');
		$thOccurrences		= Zwas_Translate::_('Count');
		
		$hasAdditionalData	= $this->hasAdditionalData($issueType);
		$additionalDataKeys	= $this->getAdditionalDataKey($issueType);
		
		$colspan = ($hasAdditionalData) ? 5 : 4;	// numbers of cols
		$additionalHeaderCol = ($hasAdditionalData) ? "<th>{$this->additionalHeaders($issueType)}</th>" : '';
		
		$tableString = "<div id=\"mui-event-groups-div\">
						<table class=\"extensions\" id=\"mui-event-groups\">
							<thead>
								<tr class=\"header\">
									<th>{$thNode}</th>
									<th>{$thTime}</th>
									<th>{$thOccurrences}</th>
									<th></th>
									{$additionalHeaderCol}
								</tr>
								<tr class=\"header-separator\" style=\"background:none;\">
									<td colspan=\"{$colspan}\" style=\"border:none;\"></td>
								</tr>
							</thead>
							<tbody>";
		
		$issueId = $eventGroups->getIssueId();
		
		foreach ($eventGroups as $row) {
			$url 		= $this->getTabLoadUrl($issueId, $row[ZM_DATA_EVENT_ID]);
			$link		= "issueDetails.selectGroupData(this, '{$url}');";
			$time		= date(ApplicationModel::getDateFormat(ApplicationModel::DATE_FORMAT_MEDIUM), $row[ZM_DATA_FIRST_TIMESTAMP]);
			$repeats	= $row[ZM_DATA_REPEATS];
			$node 		= $this->view->nodeName($row[ZM_DATA_NODE_ID]);
			$trace		= $this->getTraceIcon($row);

			$additionalRowCol	= ($hasAdditionalData) ? "<td>{$this->getAdditionalRow($additionalDataKeys, $row)}</td>" : '';
			
			$tableString.= "<tr onclick=\"{$link}\" class=\"hand mui-hover\">
								<td>{$node}</td>
								<td>{$time}</td>
								<td>{$repeats}</td>
								<td>{$trace}</td>
								{$additionalRowCol}
							</tr>";
		}
		
		$tableString.= '</tbody></table></div>';
		return $tableString;
	}
	
}