<?php
/**
 * Zwas_View_Helper_ServersList
 * @uses viewHelper Zend_View_Helper
 */
class Zwas_View_Helper_ServersList extends Zend_View_Helper_Abstract {
	
	const ICON_ONLINE		= 'led-green.gif';
	const ICON_OFFLINE		= 'led-red-na.gif';
	const ICON_DISABLED		= 'led-grey.gif';
	const ICON_NOTICE		= 'led-green-notice.gif';
	const ICON_SC_JOIN		= 'led-grey-up-arrow.gif';
	const ICON_SC_SHUTDOWN	= 'led-green-down-arrow.gif';
	
	/**
	 * @var Zwas_Text|string
	 */
	private $message = '';
	/**
	 * @var string
	 */
	private $iconImage = '';
	/**
	 * @var Nodes_Element_Mapper
	 */
	private $node;
	/**
	 * @var string
	 */
	private $jobQueueAddress;
	/**
	 * @var array
	 */
	private $actions;
	/**
	 * @var boolean
	 */
	private $disableActions;
	/**
	 * @var boolean
	 */
	private $clusterHasDifferentVersions;
	/**
	 * @param Nodes_Element_Mapper $node
	 * @param boolean $disableActions
	 * @param string $jobqueueAddress
	 * @return Zwas_View_Helper_ServersList
	 */
	public function serversList(Nodes_Element_Mapper $node, $disableActions = false, $jobqueueAddress = null) {
		$this->node							= $node;
		$this->jobQueueAddress				= $jobqueueAddress;
		$this->disableActions				= $disableActions;
		$this->clusterHasDifferentVersions	= $this->hasDifferentEnvironmentId();
		
		$nodeStatus		= $this->node->getStatus();
		$nodeTransition	= $this->node->getTransition();
		
		switch (true) {
			case ($node->isDisabled()):
				$this->setFields(
					// TRANSLATE
					Zwas_Translate::_('This server is disabled'),
					self::ICON_DISABLED,
					$this->renderDisabledActions()
				);
				break;

			case (Nodes_Element::SERVER_TRANSITION_TO_ADD === $nodeTransition):
				$this->setFields(
					// TRANSLATE
					Zwas_Translate::_('This server is in process of being added to the cluster'),
					self::ICON_SC_JOIN,
					array()
				);
				break;
				
			case (Nodes_Element::SERVER_TRANSITION_TO_ENABLE === $nodeTransition):
				$this->setFields(
					// TRANSLATE
					Zwas_Translate::_('This server is in process of being enabled'),
					self::ICON_SC_JOIN,
					array()
				);
				break;
				
			case (Nodes_Element::SERVER_TRANSITION_TO_REFRESH === $nodeTransition):
				$this->setFields(
					// TRANSLATE
					Zwas_Translate::_('This server information is being updated'),
					self::ICON_ONLINE,
					array()
				);
				break;
				
			case (Nodes_Element::STATUS_OFFLINE == $nodeStatus):
				$this->setFields(
					Zwas_Translate::_('This server is not responding'),
					self::ICON_OFFLINE,
					$this->renderActiveActions()
				);
				break;
				
			case (ZwasComponents_SessionClustering_Model::SCD_STATUS_SHUTDOWN_IN_PROCESS == $this->node->getScStatus()):
				$this->setScShutdownInProcess();
				break;
			
			case (ZwasComponents_SessionClustering_Model::SCD_STATUS_STARTING_UP == $this->node->getScStatus()):
				$this->setFields(
					// TRANSLATE
					Zwas_Translate::_('This server\'s Session Clustering service is currently in the process of initialization'),
					self::ICON_SC_JOIN,
					array()
				);
				break;
				
			case ($this->node->awaitsRestart()):
				$this->setFields(
					Zwas_Translate::_('This server\'s PHP needs to be restarted'),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
				break;
			
			case ($this->hasLowerZendServerVersion()):
				$serverVersion = $this->node->getZendServerVersion();
				$this->setFields(
					// TRANSLATE
					new Zwas_Text(Zwas_Translate::_('This server is running with version %s'), array($serverVersion)),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
				break;
					
			case (Nodes_Element::STATUS_CONFIG_MISMATCH == $nodeStatus):
				$this->setMismatch();
				break;
				
			case (Nodes_Element::STATUS_ERROR == $nodeStatus):
				$this->setFields(
					Zwas_Translate::_('An application error has occured. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
				break;
			
			case (Nodes_Element::STATUS_ONLINE == $nodeStatus):
				$this->setFields(
					'',
					self::ICON_ONLINE,
					$this->renderActiveActions()
				);
				break;
			default:
				$this->setFields(
					Zwas_Translate::_('The system has encountered an unexpected error. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
				break;
		}
		
		return $this;
	}
	
	/**
	 * @return string
	 * @throws Zwas_Exception
	 */
	public function getStatusIcon() {
		if ('' == $this->iconImage) {
			throw new Zwas_Exception('Icon was not set', Zwas_Exception::ASSERT);
		}
		return '<img src="' . $this->view->baseurl("/images/EE/nodes-status/{$this->iconImage}") . '" />';
	}
		
	/**
	 * @return string
	 */
	public function getMessage() {
		return (string)$this->message;
	}
	
	/**
	 * @return string
	 */
	public function nodeActions() {
		if (($this->disableActions) || (! is_array($this->actions))) {
			return '';
		}
		return implode('&nbsp;', $this->actions);
	}
	
	/**
	 * @return array
	 */
	public function getActions() {
		return $this->actions;
	}
	
	/**
	 * Generate a set of action links for a disabled node
	 * @return array
	 */
	private function renderDisabledActions() {
		$actions = array();
		if ($this->isNodeAlsoJobQueue()) {
			$actions[]= "<a onclick=\"nodesList.removeNodeJqd({$this->node->getId()})\">Remove</a>";
		} else {
			$actions[]= "<a onclick=\"nodesList.removeNode({$this->node->getId()})\">Remove</a>";
		}
		$actions[] = "<a onclick=\"nodesList.enableNode({$this->node->getId()})\">Enable</a>";
		return $actions;
	}
	
	/**
	 * Generate a set of action links for a stable node
	 * @return array
	 */
	private function renderActiveActions() {
		$actions = array();
		if ($this->isNodeAlsoJobQueue()) {
			$actions[]= "<a onclick=\"nodesList.removeNodeJqd({$this->node->getId()})\">Remove</a>";
			$actions[]= "<a onclick=\"nodesList.disableNodeJqd({$this->node->getId()})\">Disable</a>";
		} else {
			$actions[]= "<a onclick=\"nodesList.removeNode({$this->node->getId()})\">Remove</a>";
			$actions[]= "<a onclick=\"nodesList.disableNode({$this->node->getId()})\">Disable</a>";
		}
		return $actions;
	}
	
	/**
	 * @return boolean
	 */
	private function isNodeAlsoJobQueue() {
		return (false !== strpos($this->node->getAddress(), $this->jobQueueAddress));
	}
	
	private function setMismatch() {
		$nodeStatus = $this->node->getStatus();
		
		if ($this->clusterHasDifferentVersions) {
				
			$this->setFields(
				// TRANSLATE
				Zwas_Translate::_('This server\'s configuration is different. Finish upgrading the cluster members before making any additional changes'),
				self::ICON_NOTICE,
				$this->renderActiveActions()
			);
			return;
		}
		
		if ((! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_DIRECTIVES_FILE))
				|| (! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_EXTENSIONS_FILE))
				|| (! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_DAEMONS_FILE))
			) {
				
			$this->setFields(
				new Zwas_Text(
					Zwas_Translate::_('This server\'s configuration is different. Click %shere%s to reconfigure it to match the cluster'),
					array("<a onclick=\"nodesList.reconfigureNode({$this->node->getId()});\">", '</a>')
				),
				self::ICON_NOTICE,
				$this->renderActiveActions()
			);
			return;
		}
		
		if ((! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_DAEMONS_RUNNING))) {
			if ($this->node->isScStatusMatching()) {
				$this->setFields(
					new Zwas_Text(
					// TRANSLATE
						Zwas_Translate::_('State of services on this server is inconsistent with the rest of the cluster. Click %shere%s for more information'),
						array(
							"<a href=\"javascript:void(0)\" onclick=\"{$this->view->contentLoader('Configuration', 'Zend-Server-Components')}\">",
							'</a>'
						)
					),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
			} else {
				$this->setFields(
					new Zwas_Text(
						// TRANSLATE
						Zwas_Translate::_('State of the Session Clustering service is inconsistent with the rest of the cluster. Click %shere%s for more information'),
						array(
							"<a href=\"javascript:void(0)\" onclick=\"{$this->view->contentLoader('Configuration', 'Zend-Server-Components')}\">",
							'</a>'
						)
					),
					self::ICON_NOTICE,
					$this->renderActiveActions()
				);
			}
			return;
		}
		
		if (! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_COMPONENTS_MEMORY)) {
			$this->setFields(
				new Zwas_Text(
				// TRANSLATE
					Zwas_Translate::_('Some of the Zend Components on the server failed to load. Click %shere%s for more details'),
					array(
						"<a href=\"javascript:void(0)\" onclick=\"{$this->view->contentLoader('Configuration', 'Zend-Server-Components')}\">",
						'</a>'
					)
				),
				self::ICON_NOTICE,
					$this->renderActiveActions()
			);
			return;
		}
		
		if (! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_EXTENSIONS_MEMORY)) {
			$this->setFields(
				new Zwas_Text(
				// TRANSLATE
					Zwas_Translate::_('Some of the PHP extensions on the server failed to load. Click %shere%s for more details'),
					array(
						"<a href=\"javascript:void(0)\" onclick=\"{$this->view->contentLoader('Configuration', 'Extensions')}\">",
						'</a>'
					)
				),			
				self::ICON_NOTICE,
				$this->renderActiveActions()
			);
			return;
		}
		
		if (! $this->node->isSignatureMatchingCluster(Node_HeartbeatGenerator::SIGNATURE_NAME_DIRECTIVES_MEMORY)) {
			$this->setFields(
				Zwas_Translate::_('A conflict has been detected between file and memory values of some directives. Restart your PHP and if this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'),			
				self::ICON_NOTICE,
				$this->renderActiveActions()
			);
			return;
		}
		
		$this->setFields(
			Zwas_Translate::_('This server configuration is different. Try to rollback any recent changes. If this problem persists, go to the Zend Support Center at: http://www.zend.com/support-center'),			
			self::ICON_NOTICE,
			$this->renderActiveActions()
		);
	}
	
	private function setScShutdownInProcess() {
		$linkField = '';
				
		if ($this->node->isNodeInRemovalProcess()) {
			$linkField = Zwas_Translate::_('This server is currently in the process of being removed from the cluster');
		} elseif ($this->node->isNodeInDisableProcess()) {
			// TRANSLATE
			$linkField = Zwas_Translate::_('This server is currently in the process of being disabled');
		} else {
			// TRANSLATE
			$linkField = Zwas_Translate::_('This server is currently in the process of shutting down the Session Clustering component');
		}
		
		if ((! GracefulShutdown::isInitialized()) || (0 == GracefulShutdown::getTimeLeft())) {
			
			if ($this->node->isNodeInRemovalProcess()) {
				$linkField = new Zwas_Text( 
					Zwas_Translate::_('%s. Click %shere%s to force its immediate removal'),
					array($linkField, "<a onclick=\"nodesList.forceRemoveNode({$this->node->getId()});\">", '</a>')
				);
			}
		}
		
		$this->setFields(
			$linkField, 
			self::ICON_SC_SHUTDOWN,
			array()
		);		
	}
	
	/**
	 * @param Zwas_Text|string $message
	 * @param string $iconImage
	 * @param array $actions
	 */
	private function setFields($message, $iconImage, $actions) {
		$this->message		= $message;
		$this->iconImage	= $iconImage;
		$this->actions		= $actions;
	}
	
	/**
	 * @return boolean
	 */
	private function hasDifferentEnvironmentId() {
		$mapper = new Nodes_Mapper();
		return $mapper->hasDifferentEnvironmentId();
	}
	
	
	/**
	 * @return boolean 
	 */
	private function hasLowerZendServerVersion() {
		$nodesMapper = new Nodes_Mapper();
		
		$nodeVersion = $this->node->getZendServerVersion();
		$commonVersion = $nodesMapper->getMaxServerVersion();
		
		if (('' == $nodeVersion) || ('' == $commonVersion)) {
			return false;
		}
		return (version_compare($nodeVersion, $commonVersion, '<'));
	}
}
