<?php

class Zwas_Log {
	
	const LOGFILE = 'zend_server_ui.log';
	
	/**
	 * @var Zend_Log
	 */
	private static $logger = null;
	
	/**
	 * @var integer
	 */
	private static $logVerbosityLevel = Zend_Log::ERR; 
	
	/**
	 * @var boolean
	 */
	private static $active = false;
	
	/**
	 * Save a string in the log file
	 * @param string|Zwas_Text $msg
	 * @param integer $code - one of Zend_Log constants
	 * @return boolean
	 */
	public static function logMessage($msg, $code=Zend_Log::INFO) {
		if (! is_null(self::$logger)) {
			try {
				$msg = (string)$msg;
				self::$logger->log(PHP_EOL . $msg, $code);
				return true;
			} catch (Zend_Log_Exception $e) {
				// do nothing
			}
		}
		return false;
	}
	
	/**
	 * Save an exception as an error in the log file
	 * @param string|Zwas_Text $title
	 * @param Exception $e
	 * @return boolean true
	 */
	public static function logException($title, Exception $e) {
		if ($e instanceof Zwas_Exception) {
			$exceptionMessage = (string)$e->getMessageObject();
		} else {
			$exceptionMessage = (string)$e->getMessage();
		}
			
		$content = 	(string)$title . PHP_EOL .
					'Exception of type \'' . get_class($e) . '\': ' .
 					$exceptionMessage;

		if ((self::$logVerbosityLevel == Zend_Log::INFO) || (self::$logVerbosityLevel == Zend_Log::DEBUG)) {
			$content .= PHP_EOL . $e->getTraceAsString();
		}
 					
		self::err($content);
		return true;
	}

	/**
	 * Log a debug message for internal use
	 * @param string $message
	 * @param array $extras
	 */
	public static function debug($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->debug($message, $extras);
		}
	}

	/**
	 * Log an info message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function info($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->info($message, $extras);
		}
	}
	
	/**
	 * Log a notice message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function notice($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->notice($message, $extras);
		}
	}
	
	/**
	 * Log a warning message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function warn($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->warn($message, $extras);
		}
	}
	
	/**
	 * Log an error message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function err($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->err($message, $extras);
		}
	}
	
	/**
	 * Log a critical message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function crit($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->crit($message, $extras);
		}
	}
	
	/**
	 * Log an alert message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function alert($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->alert($message, $extras);
		}
	}
	
	/**
	 * Log an emergency message for external consumption
	 * @param string $message
	 * @param array $extras
	 */
	public static function emerg($message, $extras = array()) {
		if (self::$logger) {
			self::$logger->emerg($message, $extras);
		}
	}
	
	/**
	 * @param integer $logVerbosity
	 */
	public static function setLogVerbosityLevel($logVerbosity) {
		self::$logVerbosityLevel = $logVerbosity;
		if (self::$logger) {
			self::$logger->addFilter(new Zend_Log_Filter_Priority(self::$logVerbosityLevel));
		}
	}
	
	/**
	 * @param Zend_Log_Writer_Abstract $stream
	 */
	public static function setLoggerWriter(Zend_Log_Writer_Abstract $stream) {
		self::$active = (! ($stream instanceof Zend_Log_Writer_Null));
		self::$logger = new Zend_Log($stream);
	}
	
	public static function isLogActive() {
		return self::$active;
	}
	
	public static function resetInstance() {
		self::$logger = null;
		self::$logVerbosityLevel = null;
	}
	
	private function __construct() {
	}
	
	private function __clone() {
	}
	
}